@@ -31,11 +31,7 @@ public class ClassUtils {
 			name = name.substring(index + 1, name.length());
 		}
 
-		// inner classes contain a "$" as in Outer$Inner. As "$" is not allowed
-		// as part of a CSS selector
-		// we translate a "$" into a "-" here.
-		name = name.replace('$', '-');
-		return name;
+		return name.replace('$', '-');
 	}
 
 	/**
