@@ -15,7 +15,7 @@
  *******************************************************************************/
 package org.eclipse.e4.ui.internal.css.swt;
 
-import org.eclipse.core.runtime.Platform;
+import org.eclipse.core.runtime.ILog;
 import org.eclipse.swt.graphics.Color;
 
 public interface ICTabRendering {
@@ -41,14 +41,14 @@ public interface ICTabRendering {
 
 	@Deprecated(forRemoval = true)
 	default void setShadowColor(Color color) {
-		Platform.getLog(ICTabRendering.class).info("setShadowColor not supported anymore in platform renderer");
+		ILog.of(ICTabRendering.class).info("setShadowColor not supported anymore in platform renderer");
 	}
 
 	void setCornerRadius(int radius);
 
 	@Deprecated(forRemoval = true)
 	default void setShadowVisible(boolean visible) {
-		Platform.getLog(ICTabRendering.class).info("setShadowVisible not supported anymore in platform renderer");
+		ILog.of(ICTabRendering.class).info("setShadowVisible not supported anymore in platform renderer");
 	}
 
 	/**
