@@ -36,7 +36,6 @@ import org.eclipse.e4.ui.model.application.descriptor.basic.impl.BasicPackageImp
 import org.eclipse.e4.ui.model.application.ui.MContext;
 import org.eclipse.e4.ui.model.application.ui.MSnippetContainer;
 import org.eclipse.e4.ui.model.application.ui.MUIElement;
-import org.eclipse.e4.ui.model.application.ui.basic.MDialog;
 import org.eclipse.e4.ui.model.application.ui.basic.MWindow;
 import org.eclipse.e4.ui.model.application.ui.impl.ElementContainerImpl;
 import org.eclipse.e4.ui.model.application.ui.impl.UiPackageImpl;
@@ -85,13 +84,11 @@ import org.eclipse.emf.ecore.util.InternalEList;
  *   <li>{@link org.eclipse.e4.ui.model.application.impl.ApplicationImpl#getCommands <em>Commands</em>}</li>
  *   <li>{@link org.eclipse.e4.ui.model.application.impl.ApplicationImpl#getAddons <em>Addons</em>}</li>
  *   <li>{@link org.eclipse.e4.ui.model.application.impl.ApplicationImpl#getCategories <em>Categories</em>}</li>
- *   <li>{@link org.eclipse.e4.ui.model.application.impl.ApplicationImpl#getDialogs <em>Dialogs</em>}</li>
  * </ul>
  *
  * @since 1.0
  * @generated
  */
-@SuppressWarnings("deprecation")
 public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MApplication {
 	/**
 	 * The default value of the '{@link #getContext() <em>Context</em>}' attribute.
@@ -253,20 +250,6 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	 */
 	protected EList<MCategory> categories;
 
-	/**
-	 * The cached value of the '{@link #getDialogs() <em>Dialogs</em>}' reference list.
-	 * <!-- begin-user-doc -->
-	 * <!-- end-user-doc -->
-	 * @see #getDialogs()
-	 * @since 1.1
-	 * @deprecated
-	 * @noreference See {@link org.eclipse.e4.ui.model.application.MApplication#getDialogs() model documentation} for details.
-	 * @generated
-	 * @ordered
-	 */
-	@Deprecated
-	protected EList<MDialog> dialogs;
-
 	protected Map<String, MCommand> elementIdToCommandMap;
 
 	/**
@@ -297,7 +280,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MWindow> getChildren() {
 		if (children == null) {
-			children = new EObjectContainmentWithInverseEList<MWindow>(MWindow.class, this,
+			children = new EObjectContainmentWithInverseEList<>(MWindow.class, this,
 					ApplicationPackageImpl.APPLICATION__CHILDREN, UiPackageImpl.UI_ELEMENT__PARENT) {
 				private static final long serialVersionUID = 1L;
 
@@ -353,7 +336,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<String> getVariables() {
 		if (variables == null) {
-			variables = new EDataTypeUniqueEList<String>(String.class, this,
+			variables = new EDataTypeUniqueEList<>(String.class, this,
 					ApplicationPackageImpl.APPLICATION__VARIABLES);
 		}
 		return variables;
@@ -367,7 +350,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public Map<String, String> getProperties() {
 		if (properties == null) {
-			properties = new EcoreEMap<String, String>(ApplicationPackageImpl.Literals.STRING_TO_STRING_MAP,
+			properties = new EcoreEMap<>(ApplicationPackageImpl.Literals.STRING_TO_STRING_MAP,
 					StringToStringMapImpl.class, this, ApplicationPackageImpl.APPLICATION__PROPERTIES);
 		}
 		return properties.map();
@@ -381,7 +364,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MHandler> getHandlers() {
 		if (handlers == null) {
-			handlers = new EObjectContainmentEList<MHandler>(MHandler.class, this,
+			handlers = new EObjectContainmentEList<>(MHandler.class, this,
 					ApplicationPackageImpl.APPLICATION__HANDLERS);
 		}
 		return handlers;
@@ -395,7 +378,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MBindingTable> getBindingTables() {
 		if (bindingTables == null) {
-			bindingTables = new EObjectContainmentEList<MBindingTable>(MBindingTable.class, this,
+			bindingTables = new EObjectContainmentEList<>(MBindingTable.class, this,
 					ApplicationPackageImpl.APPLICATION__BINDING_TABLES);
 		}
 		return bindingTables;
@@ -409,7 +392,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MBindingContext> getRootContext() {
 		if (rootContext == null) {
-			rootContext = new EObjectContainmentEList<MBindingContext>(MBindingContext.class, this,
+			rootContext = new EObjectContainmentEList<>(MBindingContext.class, this,
 					ApplicationPackageImpl.APPLICATION__ROOT_CONTEXT);
 		}
 		return rootContext;
@@ -423,7 +406,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MPartDescriptor> getDescriptors() {
 		if (descriptors == null) {
-			descriptors = new EObjectContainmentEList<MPartDescriptor>(MPartDescriptor.class, this,
+			descriptors = new EObjectContainmentEList<>(MPartDescriptor.class, this,
 					ApplicationPackageImpl.APPLICATION__DESCRIPTORS);
 		}
 		return descriptors;
@@ -437,7 +420,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MBindingContext> getBindingContexts() {
 		if (bindingContexts == null) {
-			bindingContexts = new EObjectResolvingEList<MBindingContext>(MBindingContext.class, this,
+			bindingContexts = new EObjectResolvingEList<>(MBindingContext.class, this,
 					ApplicationPackageImpl.APPLICATION__BINDING_CONTEXTS);
 		}
 		return bindingContexts;
@@ -451,7 +434,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MMenuContribution> getMenuContributions() {
 		if (menuContributions == null) {
-			menuContributions = new EObjectContainmentEList<MMenuContribution>(MMenuContribution.class, this,
+			menuContributions = new EObjectContainmentEList<>(MMenuContribution.class, this,
 					ApplicationPackageImpl.APPLICATION__MENU_CONTRIBUTIONS);
 		}
 		return menuContributions;
@@ -465,7 +448,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MToolBarContribution> getToolBarContributions() {
 		if (toolBarContributions == null) {
-			toolBarContributions = new EObjectContainmentEList<MToolBarContribution>(MToolBarContribution.class, this,
+			toolBarContributions = new EObjectContainmentEList<>(MToolBarContribution.class, this,
 					ApplicationPackageImpl.APPLICATION__TOOL_BAR_CONTRIBUTIONS);
 		}
 		return toolBarContributions;
@@ -479,7 +462,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MTrimContribution> getTrimContributions() {
 		if (trimContributions == null) {
-			trimContributions = new EObjectContainmentEList<MTrimContribution>(MTrimContribution.class, this,
+			trimContributions = new EObjectContainmentEList<>(MTrimContribution.class, this,
 					ApplicationPackageImpl.APPLICATION__TRIM_CONTRIBUTIONS);
 		}
 		return trimContributions;
@@ -493,7 +476,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MUIElement> getSnippets() {
 		if (snippets == null) {
-			snippets = new EObjectContainmentEList<MUIElement>(MUIElement.class, this,
+			snippets = new EObjectContainmentEList<>(MUIElement.class, this,
 					ApplicationPackageImpl.APPLICATION__SNIPPETS);
 		}
 		return snippets;
@@ -507,7 +490,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MCommand> getCommands() {
 		if (commands == null) {
-			commands = new EObjectContainmentEList<MCommand>(MCommand.class, this,
+			commands = new EObjectContainmentEList<>(MCommand.class, this,
 					ApplicationPackageImpl.APPLICATION__COMMANDS) {
 
 				private static final long serialVersionUID = 1L;
@@ -530,7 +513,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MAddon> getAddons() {
 		if (addons == null) {
-			addons = new EObjectContainmentEList<MAddon>(MAddon.class, this,
+			addons = new EObjectContainmentEList<>(MAddon.class, this,
 					ApplicationPackageImpl.APPLICATION__ADDONS);
 		}
 		return addons;
@@ -544,30 +527,12 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public List<MCategory> getCategories() {
 		if (categories == null) {
-			categories = new EObjectContainmentEList<MCategory>(MCategory.class, this,
+			categories = new EObjectContainmentEList<>(MCategory.class, this,
 					ApplicationPackageImpl.APPLICATION__CATEGORIES);
 		}
 		return categories;
 	}
 
-	/**
-	 * <!-- begin-user-doc -->
-	 * <!-- end-user-doc -->
-	 * @since 1.1
-	 * @deprecated
-	 * @noreference See {@link org.eclipse.e4.ui.model.application.MApplication#getDialogs() model documentation} for details.
-	 * @generated
-	 */
-	@Deprecated
-	@Override
-	public List<MDialog> getDialogs() {
-		if (dialogs == null) {
-			dialogs = new EObjectResolvingEList<MDialog>(MDialog.class, this,
-					ApplicationPackageImpl.APPLICATION__DIALOGS);
-		}
-		return dialogs;
-	}
-
 	/**
 	 * <!-- begin-user-doc -->
 	 * <!-- end-user-doc -->
@@ -577,7 +542,7 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 	@Override
 	public MCommand getCommand(final String elementId) {
 		if (elementIdToCommandMap == null) {
-			Map<String, MCommand> result = new HashMap<String, MCommand>();
+			Map<String, MCommand> result = new HashMap<>();
 			for (MCommand command : getCommands()) {
 				MCommand otherCommand = result.put(command.getElementId(), command);
 				if (otherCommand != null) {
@@ -623,8 +588,9 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 			return ((InternalEList<?>) getAddons()).basicRemove(otherEnd, msgs);
 		case ApplicationPackageImpl.APPLICATION__CATEGORIES:
 			return ((InternalEList<?>) getCategories()).basicRemove(otherEnd, msgs);
+		default:
+			return super.eInverseRemove(otherEnd, featureID, msgs);
 		}
-		return super.eInverseRemove(otherEnd, featureID, msgs);
 	}
 
 	/**
@@ -668,10 +634,9 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 			return getAddons();
 		case ApplicationPackageImpl.APPLICATION__CATEGORIES:
 			return getCategories();
-		case ApplicationPackageImpl.APPLICATION__DIALOGS:
-			return getDialogs();
+		default:
+			return super.eGet(featureID, resolve, coreType);
 		}
-		return super.eGet(featureID, resolve, coreType);
 	}
 
 	/**
@@ -742,12 +707,10 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 			getCategories().clear();
 			getCategories().addAll((Collection<? extends MCategory>) newValue);
 			return;
-		case ApplicationPackageImpl.APPLICATION__DIALOGS:
-			getDialogs().clear();
-			getDialogs().addAll((Collection<? extends MDialog>) newValue);
+		default:
+			super.eSet(featureID, newValue);
 			return;
 		}
-		super.eSet(featureID, newValue);
 	}
 
 	/**
@@ -803,11 +766,10 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 		case ApplicationPackageImpl.APPLICATION__CATEGORIES:
 			getCategories().clear();
 			return;
-		case ApplicationPackageImpl.APPLICATION__DIALOGS:
-			getDialogs().clear();
+		default:
+			super.eUnset(featureID);
 			return;
 		}
-		super.eUnset(featureID);
 	}
 
 	/**
@@ -848,10 +810,9 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 			return addons != null && !addons.isEmpty();
 		case ApplicationPackageImpl.APPLICATION__CATEGORIES:
 			return categories != null && !categories.isEmpty();
-		case ApplicationPackageImpl.APPLICATION__DIALOGS:
-			return dialogs != null && !dialogs.isEmpty();
+		default:
+			return super.eIsSet(featureID);
 		}
-		return super.eIsSet(featureID);
 	}
 
 	/**
@@ -1040,8 +1001,9 @@ public class ApplicationImpl extends ElementContainerImpl<MWindow> implements MA
 		switch (operationID) {
 		case ApplicationPackageImpl.APPLICATION___GET_COMMAND__STRING:
 			return getCommand((String) arguments.get(0));
+		default:
+			return super.eInvoke(operationID, arguments);
 		}
-		return super.eInvoke(operationID, arguments);
 	}
 
 	/**
