@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2017 IBM Corporation and others.
+ * Copyright (c) 2003, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,20 +10,25 @@
  *
  * Contributors:
  *     IBM - Initial API and implementation
+ *     Hannes Wellmann - Add static factories and handle cancel by OperationCanceledException
  *******************************************************************************/
 package org.eclipse.e4.ui.progress;
 
 import org.eclipse.core.runtime.Assert;
 import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.ICoreRunnable;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.OperationCanceledException;
 import org.eclipse.core.runtime.Status;
+import org.eclipse.core.runtime.jobs.IJobFunction;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.e4.ui.di.UISynchronize;
 import org.eclipse.e4.ui.progress.internal.ProgressMessages;
 import org.eclipse.e4.ui.progress.internal.Services;
 import org.eclipse.e4.ui.progress.internal.legacy.PlatformUI;
 import org.eclipse.e4.ui.progress.internal.legacy.StatusUtil;
+import org.eclipse.e4.ui.workbench.swt.DisplayUISynchronize;
 import org.eclipse.swt.widgets.Display;
 
 /**
@@ -32,6 +37,53 @@ import org.eclipse.swt.widgets.Display;
  * @since 3.0
  */
 public abstract class UIJob extends Job {
+
+	/**
+	 * Creates a new UIJob that will execute the provided function in the UI thread
+	 * when it runs.
+	 *
+	 * Prefer using {@link UIJob#create(String, ICoreRunnable)}.
+	 *
+	 * @param name     The name of the job
+	 * @param function The function to execute
+	 * @return A UIJob that encapsulates the provided function
+	 * @see IJobFunction
+	 * @since 0.3.600
+	 */
+	public static UIJob create(String name, IJobFunction function) {
+		return new UIJob(name) {
+			@Override
+			public IStatus runInUIThread(IProgressMonitor monitor) {
+				return function.run(monitor);
+			}
+		};
+	}
+
+	/**
+	 * Creates a new UIJob that will execute the provided runnable in the UI thread
+	 * when it runs.
+	 *
+	 * @param name     the name of the job
+	 * @param runnable the runnable to execute
+	 * @return a UIJob that encapsulates the provided runnable
+	 * @see ICoreRunnable
+	 * @since 0.3.600
+	 */
+	public static UIJob create(String name, ICoreRunnable runnable) {
+		return new UIJob(name) {
+			@Override
+			public IStatus runInUIThread(IProgressMonitor monitor) {
+				try {
+					runnable.run(monitor);
+				} catch (CoreException e) {
+					IStatus st = e.getStatus();
+					return new Status(st.getSeverity(), st.getPlugin(), st.getCode(), st.getMessage(), e);
+				}
+				return Status.OK_STATUS;
+			}
+		};
+	}
+
 	private Display cachedDisplay;
 
 	/**
@@ -39,9 +91,7 @@ public abstract class UIJob extends Job {
 	 * used will be the one from the workbench if this is available. UIJobs with
 	 * this constructor will determine their display at runtime.
 	 *
-	 * @param name
-	 *            the job name
-	 *
+	 * @param name the job name
 	 */
 	public UIJob(String name) {
 		super(name);
@@ -64,7 +114,7 @@ public abstract class UIJob extends Job {
 	/**
 	 * Convenience method to return a status for an exception.
 	 *
-	 * @param exception
+	 * @param exception the thrown exception
 	 * @return IStatus an error status built from the exception
 	 * @see Job
 	 */
@@ -73,9 +123,10 @@ public abstract class UIJob extends Job {
 	}
 
 	/**
+	 * Note: this message is marked final. Implementors should use runInUIThread()
+	 * instead.
+	 *
 	 * @see org.eclipse.core.runtime.jobs.Job#run(org.eclipse.core.runtime.IProgressMonitor)
-	 *      Note: this message is marked final. Implementors should use
-	 *      runInUIThread() instead.
 	 */
 	@Override
 	public final IStatus run(final IProgressMonitor monitor) {
@@ -100,15 +151,15 @@ public abstract class UIJob extends Job {
 					// UIStats.start(UIStats.UI_JOB, getName());
 					result = runInUIThread(monitor);
 				}
-
+			} catch (OperationCanceledException e) {
+				result = Status.CANCEL_STATUS;
 			} catch (Throwable t) {
 				throwable = t;
 			} finally {
 				// TODO E4 - missing e4 replacement
 				// UIStats.end(UIStats.UI_JOB, UIJob.this, getName());
 				if (result == null) {
-					result = new Status(IStatus.ERROR, IProgressConstants.PLUGIN_ID, IStatus.ERROR,
-							ProgressMessages.InternalError, throwable);
+					result = Status.error(ProgressMessages.InternalError, throwable);
 				}
 				done(result);
 			}
@@ -119,8 +170,9 @@ public abstract class UIJob extends Job {
 	/**
 	 * Run the job in the UI Thread.
 	 *
-	 * @param monitor
-	 * @return IStatus
+	 * @param monitor the monitor to be used for reporting progress and responding
+	 *                to cancellation. The monitor is never <code>null</code>
+	 * @return resulting status of the run. The result must not be <code>null</code>
 	 */
 	public abstract IStatus runInUIThread(IProgressMonitor monitor);
 
@@ -148,7 +200,10 @@ public abstract class UIJob extends Job {
 	 */
 	public Display getDisplay() {
 		if (cachedDisplay == null) {
-			cachedDisplay = Services.getInstance().getDisplay();
+			Services instance = Services.getInstance();
+			if (instance != null) {
+				cachedDisplay = instance.getDisplay();
+			}
 		}
 		if (cachedDisplay == null) {
 			cachedDisplay = Display.getCurrent();
@@ -159,12 +214,25 @@ public abstract class UIJob extends Job {
 		return cachedDisplay;
 	}
 
+	/**
+	 * Convenience method to return a status for a throwable.
+	 *
+	 * @param t the thrown throwable
+	 * @return IStatus an error status built from the exception
+	 */
 	public static IStatus getStatus(Throwable t) {
 		String message = StatusUtil.getLocalizedMessage(t);
 
 		return newError(message, t);
 	}
 
+	/**
+	 * Convenience method to return a status for a throwable including a message.
+	 *
+	 * @param message error message
+	 * @param t       the thrown throwable
+	 * @return IStatus an error status built from the exception
+	 */
 	public static IStatus newError(String message, Throwable t) {
 		String pluginId = IProgressConstants.PLUGIN_ID;
 		int errorCode = IStatus.OK;
@@ -177,12 +245,20 @@ public abstract class UIJob extends Job {
 			errorCode = ce.getStatus().getCode();
 		}
 
-		return new Status(IStatus.ERROR, pluginId, errorCode, message,
-				StatusUtil.getCause(t));
+		return new Status(IStatus.ERROR, pluginId, errorCode, message, StatusUtil.getCause(t));
 	}
 
+	/**
+	 * Returns UI synchronizer
+	 *
+	 * @return UI synchronizer
+	 */
 	protected UISynchronize getUiSynchronize() {
-		return Services.getInstance().getUISynchronize();
+		Services instance = Services.getInstance();
+		if (instance == null) {
+			return new DisplayUISynchronize(getDisplay());
+		}
+		return instance.getUISynchronize();
 	}
 
 }
