@@ -27,7 +27,7 @@ import java.util.Objects;
 import org.eclipse.core.expressions.EvaluationResult;
 import org.eclipse.core.expressions.Expression;
 import org.eclipse.core.expressions.ExpressionInfo;
-import org.eclipse.core.internal.expressions.ReferenceExpression;
+import org.eclipse.core.expressions.ReferenceExpression;
 import org.eclipse.e4.core.commands.ExpressionContext;
 import org.eclipse.e4.core.contexts.ContextInjectionFactory;
 import org.eclipse.e4.core.contexts.EclipseContextFactory;
@@ -59,6 +59,7 @@ import org.eclipse.e4.ui.model.application.ui.menu.MToolBarContribution;
 import org.eclipse.e4.ui.model.application.ui.menu.MToolBarElement;
 import org.eclipse.e4.ui.model.application.ui.menu.MToolBarSeparator;
 import org.eclipse.e4.ui.model.application.ui.menu.MTrimContribution;
+import org.eclipse.e4.ui.workbench.IWorkbench;
 import org.eclipse.emf.ecore.EObject;
 import org.eclipse.emf.ecore.util.EcoreUtil;
 
@@ -81,33 +82,28 @@ public final class ContributionsAnalyzer {
 	public static void gatherTrimContributions(MTrimBar trimModel,
 			List<MTrimContribution> trimContributions, String elementId,
 			ArrayList<MTrimContribution> toContribute, ExpressionContext eContext) {
-		if (elementId == null || elementId.length() == 0) {
+		if (elementId == null || elementId.isEmpty()) {
 			return;
 		}
 		for (MTrimContribution contribution : trimContributions) {
 			String parentId = contribution.getParentId();
-			boolean filtered = isFiltered(trimModel, contribution);
-			if (filtered || !elementId.equals(parentId) || !contribution.isToBeRendered()) {
+			if (!elementId.equals(parentId) || !contribution.isToBeRendered()) {
 				continue;
 			}
 			toContribute.add(contribution);
 		}
 	}
 
-	static boolean isFiltered(MTrimBar trimModel, MTrimContribution contribution) {
-		return false;
-	}
 
 	public static void XXXgatherToolBarContributions(final MToolBar toolbarModel,
 			final List<MToolBarContribution> toolbarContributionList, final String id,
 			final ArrayList<MToolBarContribution> toContribute) {
-		if (id == null || id.length() == 0) {
+		if (id == null || id.isEmpty()) {
 			return;
 		}
 		for (MToolBarContribution toolBarContribution : toolbarContributionList) {
 			String parentID = toolBarContribution.getParentId();
-			boolean filtered = isFiltered(toolbarModel, toolBarContribution);
-			if (filtered || !id.equals(parentID) || !toolBarContribution.isToBeRendered()) {
+			if (!id.equals(parentID) || !toolBarContribution.isToBeRendered()) {
 				continue;
 			}
 			toContribute.add(toolBarContribution);
@@ -117,28 +113,23 @@ public final class ContributionsAnalyzer {
 	public static void gatherToolBarContributions(final MToolBar toolbarModel,
 			final List<MToolBarContribution> toolbarContributionList, final String id,
 			final ArrayList<MToolBarContribution> toContribute, final ExpressionContext eContext) {
-		if (id == null || id.length() == 0) {
+		if (id == null || id.isEmpty()) {
 			return;
 		}
 		for (MToolBarContribution toolBarContribution : toolbarContributionList) {
 			String parentID = toolBarContribution.getParentId();
-			boolean filtered = isFiltered(toolbarModel, toolBarContribution);
-			if (filtered || !id.equals(parentID) || !toolBarContribution.isToBeRendered()) {
+			if (!id.equals(parentID) || !toolBarContribution.isToBeRendered()) {
 				continue;
 			}
 			toContribute.add(toolBarContribution);
 		}
 	}
 
-	static boolean isFiltered(MToolBar toolbarModel, MToolBarContribution toolBarContribution) {
-		return false;
-	}
-
 	public static void XXXgatherMenuContributions(final MMenu menuModel,
 			final List<MMenuContribution> menuContributionList, final String id,
 			final ArrayList<MMenuContribution> toContribute, final ExpressionContext eContext,
 			boolean includePopups) {
-		if (id == null || id.length() == 0) {
+		if (id == null || id.isEmpty()) {
 			return;
 		}
 		ArrayList<String> popupIds = new ArrayList<>();
@@ -182,7 +173,7 @@ public final class ContributionsAnalyzer {
 			final List<MMenuContribution> menuContributionList, final String id,
 			final ArrayList<MMenuContribution> toContribute, final ExpressionContext eContext,
 			boolean includePopups) {
-		if (id == null || id.length() == 0) {
+		if (id == null || id.isEmpty()) {
 			return;
 		}
 		boolean menuBar = (((MUIElement) ((EObject) menuModel).eContainer()) instanceof MWindow);
@@ -450,6 +441,7 @@ public final class ContributionsAnalyzer {
 				continue;
 			}
 			MTrimElement copy = (MTrimElement) EcoreUtil.copy((EObject) item);
+			copy.getPersistedState().put(IWorkbench.PERSIST_STATE, Boolean.FALSE.toString());
 			if (DEBUG) {
 				trace("addTrimContribution " + copy, trimBar.getWidget(), trimBar); //$NON-NLS-1$
 			}
@@ -785,7 +777,7 @@ public final class ContributionsAnalyzer {
 	}
 
 	public static int indexForId(MElementContainer<MMenuElement> parentMenu, String id) {
-		if (id == null || id.length() == 0) {
+		if (id == null || id.isEmpty()) {
 			return -1;
 		}
 		int i = 0;
