@@ -28,12 +28,12 @@ import org.eclipse.swt.widgets.Display;
  */
 public class DisplayRealm extends Realm {
 
-	private static List<DisplayRealm> realms = new ArrayList<DisplayRealm>();
+	private static List<DisplayRealm> realms = new ArrayList<>();
 
 	/**
 	 * Returns the realm representing the UI thread for the given display.
 	 *
-	 * @param display
+	 * @param display the display to get realm for
 	 * @return the realm representing the UI thread for the given display
 	 */
 	public static Realm getRealm(final Display display) {
