@@ -20,23 +20,25 @@ import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.widgets.Control;
 
 /**
+ * @param <S> type of the source object
+ *
  * @since 3.3
  *
  */
-public class ControlForegroundProperty extends WidgetValueProperty {
+public class ControlForegroundProperty<S extends Control> extends WidgetValueProperty<S, Color> {
 	@Override
 	public Object getValueType() {
 		return Color.class;
 	}
 
 	@Override
-	protected Object doGetValue(Object source) {
-		return ((Control) source).getForeground();
+	protected Color doGetValue(S source) {
+		return source.getForeground();
 	}
 
 	@Override
-	protected void doSetValue(Object source, Object value) {
-		((Control) source).setForeground((Color) value);
+	protected void doSetValue(S source, Color value) {
+		source.setForeground(value);
 	}
 
 	@Override
