@@ -90,7 +90,7 @@ public final class BindingManager extends HandleObjectManager implements
 	private Map currentConflicts = null;
 
 	/**
-	 * </p>
+	 * <p>
 	 * A utility method for adding entries to a map. The map is checked for
 	 * entries at the key. If such an entry exists, it is expected to be a
 	 * <code>Collection</code>. The value is then appended to the collection.
@@ -266,7 +266,7 @@ public final class BindingManager extends HandleObjectManager implements
 	/**
 	 * The array of platforms, starting with the active platform and moving up
 	 * through less specific representations of the platform. For example,
-	 * ["gtk", "", null]. This value will never be <code>null,/code>.
+	 * ["gtk", "", null]. This value will never be <code>null</code>.
 	 */
 	private String[] platforms = expand(platform, Util.ZERO_LENGTH_STRING);
 
@@ -624,50 +624,48 @@ public final class BindingManager extends HandleObjectManager implements
 					}
 				}
 
-			} else {
-				// We are building the flat map of trigger to commands.
-				if (match instanceof Binding) {
-					final Binding binding = (Binding) match;
-					bindingsByTrigger.put(trigger, binding);
-					addReverseLookup(triggersByCommandId, binding
-							.getParameterizedCommand(), trigger);
+			} else // We are building the flat map of trigger to commands.
+			if (match instanceof Binding) {
+				final Binding binding = (Binding) match;
+				bindingsByTrigger.put(trigger, binding);
+				addReverseLookup(triggersByCommandId, binding
+						.getParameterizedCommand(), trigger);
 
-				} else if (match instanceof Collection) {
-					final Binding winner = resolveConflicts((Collection) match,
-							activeContextTree);
-					if (winner == null) {
-						// warn once ... so as not to flood the logs
-						conflictsByTrigger.put(trigger, match);
-						if (triggerConflicts.add(trigger)) {
-							final StringWriter sw = new StringWriter();
-							final BufferedWriter buffer = new BufferedWriter(sw);
-							try {
-								buffer.write("A conflict occurred for "); //$NON-NLS-1$
-								buffer.write(trigger.toString());
-								buffer.write(':');
-								Iterator i = ((Collection) match).iterator();
-								while (i.hasNext()) {
-									buffer.newLine();
-									buffer.write(i.next().toString());
-								}
-								buffer.flush();
-							} catch (IOException e) {
-								// we should not get this
+			} else if (match instanceof Collection) {
+				final Binding winner = resolveConflicts((Collection) match,
+						activeContextTree);
+				if (winner == null) {
+					// warn once ... so as not to flood the logs
+					conflictsByTrigger.put(trigger, match);
+					if (triggerConflicts.add(trigger)) {
+						final StringWriter sw = new StringWriter();
+						final BufferedWriter buffer = new BufferedWriter(sw);
+						try {
+							buffer.write("A conflict occurred for "); //$NON-NLS-1$
+							buffer.write(trigger.toString());
+							buffer.write(':');
+							Iterator i = ((Collection) match).iterator();
+							while (i.hasNext()) {
+								buffer.newLine();
+								buffer.write(i.next().toString());
 							}
-							conflicts.add(new Status(IStatus.WARNING,
-									"org.eclipse.jface", //$NON-NLS-1$
-									sw.toString()));
+							buffer.flush();
+						} catch (IOException e) {
+							// we should not get this
 						}
-						if (DEBUG) {
-							Tracing.printTrace("BINDINGS", //$NON-NLS-1$
-									"A conflict occurred for " + trigger); //$NON-NLS-1$
-							Tracing.printTrace("BINDINGS", "    " + match); //$NON-NLS-1$ //$NON-NLS-2$
-						}
-					} else {
-						bindingsByTrigger.put(trigger, winner);
-						addReverseLookup(triggersByCommandId, winner
-								.getParameterizedCommand(), trigger);
+						conflicts.add(new Status(IStatus.WARNING,
+								"org.eclipse.jface", //$NON-NLS-1$
+								sw.toString()));
 					}
+					if (DEBUG) {
+						Tracing.printTrace("BINDINGS", //$NON-NLS-1$
+								"A conflict occurred for " + trigger); //$NON-NLS-1$
+						Tracing.printTrace("BINDINGS", "    " + match); //$NON-NLS-1$ //$NON-NLS-2$
+					}
+				} else {
+					bindingsByTrigger.put(trigger, winner);
+					addReverseLookup(triggersByCommandId, winner
+							.getParameterizedCommand(), trigger);
 				}
 			}
 		}
@@ -1268,7 +1266,7 @@ public final class BindingManager extends HandleObjectManager implements
 	}
 
 	/**
-	 * @param command
+	 * @param command the command to get trigger for sequence
 	 * @return
 	 * 		a trigger sequence, or <code>null</code>
 	 * @since 3.4
