@@ -327,10 +327,8 @@ public class ControlDecoration {
 				if (!hoverShell.isVisible()) {
 					hoverShell.setVisible(true);
 				}
-			} else {
-				if (hoverShell.isVisible()) {
-					hoverShell.setVisible(false);
-				}
+			} else if (hoverShell.isVisible()) {
+				hoverShell.setVisible(false);
 			}
 		}
 
