@@ -160,7 +160,6 @@ import org.eclipse.swt.widgets.Scrollable;
 		// with a constant
 		if (hScroll) {
 			hHint = defaultSize.x;
-		} else {
 			// For wrapping controls, there are two cases.
 			// 1. For controls that contain text (like wrapping labels,
 			// read-only text boxes,
@@ -170,12 +169,10 @@ import org.eclipse.swt.widgets.Scrollable;
 			// 2. For non-text controls (like wrapping toolbars), assume that
 			// their non-wrapped
 			// size is best.
-
-			if (wrapping) {
-				if (containsText) {
-					hHint = wrapSize;
-					grabHorizontal = true;
-				}
+		} else if (wrapping) {
+			if (containsText) {
+				hHint = wrapSize;
+				grabHorizontal = true;
 			}
 		}
 
@@ -195,9 +192,7 @@ import org.eclipse.swt.widgets.Scrollable;
 		Class<? extends Control> c = control.getClass();
 		try {
 			c.getMethod(name, parameterTypes);
-		} catch (SecurityException e) {
-			return false;
-		} catch (NoSuchMethodException e) {
+		} catch (SecurityException | NoSuchMethodException e) {
 			return false;
 		}
 		return true;
