@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2015 IBM Corporation and others.
+ * Copyright (c) 2004, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Stefan Nöbauer - Bug 553765
  *******************************************************************************/
 package org.eclipse.jface.resource;
 
@@ -23,13 +24,13 @@ import org.eclipse.swt.graphics.ImageDataProvider;
  */
 class ImageDataImageDescriptor extends ImageDescriptor {
 
-	private ImageDataProvider dataProvider;
+	private final ImageDataProvider dataProvider;
 
 	/**
 	 * Original image being described, or null if this image is described
 	 * completely using its ImageData
 	 */
-	private Image originalImage = null;
+	private final Image originalImage;
 
 	/**
 	 * Creates an image descriptor, given an image and the device it was created on.
@@ -37,7 +38,7 @@ class ImageDataImageDescriptor extends ImageDescriptor {
 	 * @param originalImage
 	 */
 	ImageDataImageDescriptor(Image originalImage) {
-		this(originalImage::getImageData);
+		this.dataProvider = originalImage::getImageData;
 		this.originalImage = originalImage;
 	}
 
@@ -59,6 +60,7 @@ class ImageDataImageDescriptor extends ImageDescriptor {
 	 */
 	ImageDataImageDescriptor(ImageDataProvider provider) {
 		dataProvider = provider;
+		originalImage = null;
 	}
 
 	@Override
@@ -66,23 +68,18 @@ class ImageDataImageDescriptor extends ImageDescriptor {
 
 		// If this descriptor is based on an existing image, then we can return the original image
 		// if this is the same device.
-		if (originalImage != null) {
+		if (originalImage != null && originalImage.getDevice() == device) {
 			// If we're allocating on the same device as the original image, return the original.
-			if (originalImage.getDevice() == device) {
-				return originalImage;
-			}
+			return originalImage;
 		}
-
 		return super.createResource(device);
 	}
 
 	@Override
 	public void destroyResource(Object previouslyCreatedObject) {
-		if (previouslyCreatedObject == originalImage) {
-			return;
+		if (previouslyCreatedObject != originalImage) {
+			super.destroyResource(previouslyCreatedObject);
 		}
-
-		super.destroyResource(previouslyCreatedObject);
 	}
 
 	@Override
@@ -95,25 +92,21 @@ class ImageDataImageDescriptor extends ImageDescriptor {
 		if (originalImage != null) {
 			return System.identityHashCode(originalImage);
 		}
-		return dataProvider.getImageData(100).hashCode();
+		return dataProvider.hashCode();
 	}
 
 	@Override
 	public boolean equals(Object obj) {
-		if (!(obj instanceof ImageDataImageDescriptor)) {
+		if (!(obj instanceof ImageDataImageDescriptor imgWrap)) {
 			return false;
 		}
-
-		ImageDataImageDescriptor imgWrap = (ImageDataImageDescriptor) obj;
-
 		//Intentionally using == instead of equals() as Image.hashCode() changes
 		//when the image is disposed and so leaks may occur with equals()
 
 		if (originalImage != null) {
 			return imgWrap.originalImage == originalImage;
 		}
-
-		return (imgWrap.originalImage == null && dataProvider.equals(imgWrap.dataProvider));
+		return imgWrap.originalImage == null && dataProvider.equals(imgWrap.dataProvider);
 	}
 
 }
