@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -12,6 +12,7 @@
  *     IBM Corporation - initial API and implementation
  *     Tom Schindl <tom.schindl@bestsolution.at> - initial API and implementation bug 154329
  *                                               - fixes in bug 170381, 198665, 200731
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 548314
  *******************************************************************************/
 
 package org.eclipse.jface.viewers;
@@ -21,7 +22,9 @@ import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
+
 import org.eclipse.core.runtime.Assert;
+import org.eclipse.jface.viewers.internal.ExpandableNode;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.DisposeEvent;
 import org.eclipse.swt.widgets.Control;
@@ -267,8 +270,21 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 			return;
 		Object[] filtered = filter(elements);
 
+		final int itemsLimit = getItemsLimit();
 		for (Object element : filtered) {
 			int index = indexForElement(element);
+			// 1. Cost is negligible if you don't set limit.
+			// 2. Fast way to check if items have reached the limit.
+			if (itemsLimit > 0) {
+				if (doGetItemCount() == itemsLimit) {
+					createExpandableNode(element, index);
+					continue;
+				}
+				if (getLastElement() instanceof ExpandableNode expNode) {
+					addElementAtIndex(element, index, expNode);
+					continue;
+				}
+			}
 			createItem(element, index);
 		}
 	}
@@ -281,7 +297,7 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 	 *
 	 * @since 3.1
 	 */
-	private void createItem(Object element, int index) {
+	void createItem(Object element, int index) {
 		if (virtualManager == null) {
 			updateItem(internalCreateNewRowPart(SWT.NONE, index).getItem(),
 					element);
@@ -382,6 +398,12 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 				// Also enter loop if no columns added. See 1G9WWGZ: JFUIF:WINNT -
 				// TableViewer with 0 columns does not work
 				for (int column = 0; column < columnCount || column == 0; column++) {
+
+					// ExpandableNode is shown in first column only.
+					if (element instanceof ExpandableNode && column != 0) {
+						continue;
+					}
+
 					ViewerColumn columnViewer = getViewerColumn(column);
 					ViewerCell cellToUpdate = updateCell(viewerRowFromItem,
 							column, element);
@@ -463,13 +485,14 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 		return super.getLabelProvider();
 	}
 
+	@SuppressWarnings("rawtypes")
 	@Override
 	protected List getSelectionFromWidget() {
 		if (virtualManager != null) {
 			return getVirtualSelection();
 		}
 		Widget[] items = doGetSelection();
-		ArrayList list = new ArrayList(items.length);
+		List<Object> list = new ArrayList<>(items.length);
 		for (Widget item : items) {
 			Object e = item.getData();
 			if (e != null) {
@@ -486,9 +509,9 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 	 * @return List of Object
 	 */
 
-	private List getVirtualSelection() {
+	private List<Object> getVirtualSelection() {
 
-		List result = new ArrayList();
+		List<Object> result = new ArrayList<>();
 		int[] selectionIndices = doGetSelectionIndices();
 		if (getContentProvider() instanceof ILazyContentProvider) {
 			ILazyContentProvider lazy = (ILazyContentProvider) getContentProvider();
@@ -594,6 +617,14 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 			add(element);
 			return;
 		}
+
+		// if limit is set and still some elements are not populated.Assumption that
+		// user has already updated the model and needs addition of item.
+		if (getItemsLimit() > 0 && getLastElement() instanceof ExpandableNode) {
+			internalRefreshAll(false);
+			return;
+		}
+
 		if (position == -1) {
 			position = doGetItemCount();
 		}
@@ -663,9 +694,11 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 		// e.g. if (a, b) is replaced by (b, a), the disassociate of b to
 		// item 1 could undo
 		// the associate of b to item 0.
-
-		Object[] children = getSortedChildren(getRoot());
 		Item[] items = doGetItems();
+		Object[] children = getChildrenWithLimitApplied(getRoot(), items);
+		if (children == null) {
+			children = getSortedChildren(getRoot());
+		}
 		int min = Math.min(children.length, items.length);
 		for (int i = 0; i < min; ++i) {
 
@@ -744,6 +777,14 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 				return;
 			}
 		}
+
+		// if limit is set and still some elements are not populated.Assumption that
+		// user has already updated the model and needs removal of an item.
+		if (getItemsLimit() > 0 && getLastElement() instanceof ExpandableNode) {
+			internalRefreshAll(false);
+			return;
+		}
+
 		// use remove(int[]) rather than repeated TableItem.dispose() calls
 		// to allow SWT to optimize multiple removals
 		int[] indices = new int[elements.length];
@@ -776,6 +817,32 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 		}
 	}
 
+	/**
+	 * Returns the data of the last item on the viewer.
+	 *
+	 * @return may return null
+	 */
+	Object getLastElement() {
+		Item lastItem;
+		try {
+			// fast path first
+			int itemCount = doGetItemCount();
+			if (itemCount == 0) {
+				return null;
+			}
+			lastItem = doGetItem(itemCount - 1);
+		} catch (Exception e) {
+			// something went wrong with indexes
+			Item[] items = doGetItems();
+			int length = items.length;
+			if (length == 0) {
+				return null;
+			}
+			lastItem = items[length - 1];
+		}
+		return lastItem == null ? null : lastItem.getData();
+	}
+
 	/**
 	 * Removes the given elements from this table viewer. The selection is
 	 * updated if required.
@@ -822,13 +889,29 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 	public void reveal(Object element) {
 		Assert.isNotNull(element);
 		Widget w = findItem(element);
+
+		if (w == null && getItemsLimit() > 0) {
+			// if limited elements are populated, element to reveal may be inside
+			// ExpandableNode.
+			if (getLastElement() instanceof ExpandableNode node) {
+				Item[] items = doGetItems();
+				Object[] remEles = node.getRemainingElements();
+				for (Object object : remEles) {
+					if (equals(object, element)) {
+						w = items[items.length - 1];
+						break;
+					}
+				}
+			}
+		}
+
 		if (w instanceof Item) {
 			doShowItem((Item) w);
 		}
 	}
 
 	@Override
-	protected void setSelectionToWidget(List list, boolean reveal) {
+	protected void setSelectionToWidget(@SuppressWarnings("rawtypes") List list, boolean reveal) {
 		if (list == null) {
 			doDeselectAll();
 			return;
@@ -862,7 +945,7 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 			if( ! list.isEmpty() ) {
 				int[] indices = new int[list.size()];
 
-				Iterator it = list.iterator();
+				Iterator<?> it = list.iterator();
 				Item[] items = doGetItems();
 				Object modelElement;
 
@@ -882,6 +965,30 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 					System.arraycopy(indices, 0, indices = new int[count], 0, count);
 				}
 
+				// item to select may be hidden inside expandable node.
+				if (getItemsLimit() > 0 && indices.length < list.size()
+						&& getLastElement() instanceof ExpandableNode expNode) {
+
+					// extract only non found items already.
+					List<Object> notFoundItems = new ArrayList<Object>(list);
+					for (int index : indices) {
+						notFoundItems.remove(doGetItem(index).getData());
+					}
+
+					Object[] remEles = expNode.getRemainingElements();
+					OuterLoop : for (Object searchItem : notFoundItems) {
+						for (Object remEle : remEles) {
+							if (equals(remEle, searchItem)) {
+								int[] placeHolder = new int[indices.length + 1];
+								System.arraycopy(indices, 0, placeHolder, 0, indices.length);
+								placeHolder[placeHolder.length - 1] = items.length - 1;
+								indices = placeHolder;
+								break OuterLoop;
+							}
+						}
+					}
+				}
+
 				doSelect(indices);
 			}
 		}
@@ -895,13 +1002,13 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 	 * @param reveal
 	 *            Whether or not reveal the first item.
 	 */
-	private void virtualSetSelectionToWidget(List list, boolean reveal) {
+	private void virtualSetSelectionToWidget(@SuppressWarnings("rawtypes") List list, boolean reveal) {
 		int size = list.size();
 		int[] indices = new int[list.size()];
 
 		Item firstItem = null;
 		int count = 0;
-		HashSet virtualElements = new HashSet();
+		HashSet<Object> virtualElements = new HashSet<>();
 		for (int i = 0; i < size; ++i) {
 			Object o = list.get(i);
 			Widget w = findItem(o);
@@ -935,21 +1042,18 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 					}
 				}
 			}
-		} else {
-
-			if (count != list.size()) {// As this is expensive skip it if all
-				// have been found
-				// If it is not lazy we can use the cache
-				for (int i = 0; i < virtualManager.cachedElements.length; i++) {
-					Object element = virtualManager.cachedElements[i];
-					if (virtualElements.contains(element)) {
-						Item item = doGetItem(i);
-						item.getText();// Be sure to fire the update
-						indices[count++] = i;
-						virtualElements.remove(element);
-						if (firstItem == null) {
-							firstItem = item;
-						}
+		} else if (count != list.size()) {// As this is expensive skip it if all
+			// have been found
+			// If it is not lazy we can use the cache
+			for (int i = 0; i < virtualManager.cachedElements.length; i++) {
+				Object element = virtualManager.cachedElements[i];
+				if (virtualElements.contains(element)) {
+					Item item = doGetItem(i);
+					item.getText();// Be sure to fire the update
+					indices[count++] = i;
+					virtualElements.remove(element);
+					if (firstItem == null) {
+						firstItem = item;
 					}
 				}
 			}
@@ -1001,8 +1105,8 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 	 * method will not call the content provider to verify. <strong>Note that
 	 * this method will materialize a TableItem the given index.</strong>.
 	 *
-	 * @param element
-	 * @param index
+	 * @param element the new element
+	 * @param index the index of the table item to replace
 	 * @see ILazyContentProvider
 	 *
 	 * @since 3.1
@@ -1057,6 +1161,83 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 				|| provider instanceof ILazyContentProvider);
 	}
 
+	private void createExpandableNode(Object element, int index) {
+		// case2 : if ExpNode absent. Create an ExpNode
+		Item[] items = doGetItems();
+		// there is an extra element being added.
+		Object[] allEles = new Object[items.length + 1];
+
+		// case2.1 : new element goes inside ExpNode and a new ExpNode is created
+		if (index >= doGetItemCount()) {
+			for (int i = 0; i < items.length; i++) {
+				allEles[i] = items[i].getData();
+			}
+			allEles[allEles.length - 1] = element;
+			ExpandableNode expNode = new ExpandableNode(allEles, items.length, getItemsLimit(), this);
+			createItem(expNode, -1);
+		} else {
+			// case2.2 : insert the element at it's appropriate position. update all
+			// elements until last element and create an ExpNode.
+
+			// copy data until index
+			for (int i = 0; i < index; i++) {
+				allEles[i] = items[i].getData();
+
+			}
+			// copy new element at it's index
+			allEles[index] = element;
+
+			Object temp = items[index].getData();
+			// update the index with new element.
+			doUpdateItem(items[index], element, true);
+
+			Object temp1 = null;
+
+			// move all elements one position ahead from index(including)
+			// after the loop 'temp' will contain last element which will go inside ExpNode.
+			for (int i = index; i < items.length - 1; i++) {
+				temp1 = items[i + 1].getData();
+				doUpdateItem(items[i + 1], temp, true);
+				allEles[i + 1] = temp;
+				temp = temp1;
+			}
+
+			allEles[allEles.length - 1] = temp;
+
+			ExpandableNode expNode = new ExpandableNode(allEles, items.length, getItemsLimit(), this);
+			createItem(expNode, -1);
+		}
+	}
+
+	private void addElementAtIndex(Object element, int index, ExpandableNode expNode) {
+		final int itemCount = doGetItemCount();
+		if (index >= itemCount - 1) {
+			// case 1.2 : this element belongs to hidden elements in the expandable node
+			expNode.addElement(element);
+			doUpdateItem(doGetItem(itemCount - 1), expNode, true);
+		} else {
+			// case 1.1 : element need to be inserted in the visible items.
+			Item[] items = doGetItems();
+			// we know last element is ExpNode and last but one now must go into this node.
+			Item visibleLast = items[items.length - 2];
+			expNode.addElement(visibleLast.getData());
+			doUpdateItem(doGetItem(itemCount - 1), expNode, true);
+
+			// backup index element and update it with new element being added.
+			Object temp = items[index].getData();
+			doUpdateItem(items[index], element, true);
+
+			Object temp1 = items[index + 1].getData();
+
+			// update all the items to one position next from the index.
+			for (int i = index + 1; i < items.length - 1; i++) {
+				temp1 = items[i].getData();
+				doUpdateItem(items[i], temp, true);
+				temp = temp1;
+			}
+		}
+	}
+
 	/**
 	 * Searches the receiver's list starting at the first item (index 0) until
 	 * an item is found that is equal to the argument, and returns the index of
@@ -1321,4 +1502,28 @@ public abstract class AbstractTableViewer extends ColumnViewer {
 	 */
 	protected abstract void doSelect(int[] indices);
 
+	/**
+	 * Returns true if the element is present in the viewer. If the viewer has
+	 * incremental display set then the element is searched inside expandable node
+	 * also. i.e. it searches inside the remaining elements to be populated.
+	 *
+	 * @param element model element
+	 * @return if given model element is contained in the viewer
+	 * @since 3.31
+	 */
+	public boolean contains(Object element) {
+		if (findItem(element) != null) {
+			return true;
+		}
+
+		if (getItemsLimit() <= 0) {
+			return false;
+		}
+
+		if (getLastElement() instanceof ExpandableNode node) {
+			return node.contains(element);
+		}
+		return false;
+	}
+
 }
