@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -12,6 +12,7 @@
  *     IBM Corporation - initial API and implementation
  *     Brad Reynolds - bug 141435
  *     Tom Schindl <tom.schindl@bestsolution.at> - bug 157309, 177619
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 548314
  *******************************************************************************/
 
 package org.eclipse.jface.viewers;
@@ -183,29 +184,27 @@ public class ListViewer extends AbstractListViewer {
 	}
 
 	@Override
-	protected void setSelectionToWidget(List in, boolean reveal) {
+	protected void setSelectionToWidget(@SuppressWarnings("rawtypes") List in, boolean reveal) {
 		if( reveal ) {
 			super.setSelectionToWidget(in, reveal);
+		} else if (in == null || in.isEmpty()) { // clear selection
+			list.deselectAll();
 		} else {
-			if (in == null || in.isEmpty()) { // clear selection
-				list.deselectAll();
-			} else {
-				int n = in.size();
-				int[] ixs = new int[n];
-				int count = 0;
-				for (int i = 0; i < n; ++i) {
-					Object el = in.get(i);
-					int ix = getElementIndex(el);
-					if (ix >= 0) {
-						ixs[count++] = ix;
-					}
+			int n = in.size();
+			int[] ixs = new int[n];
+			int count = 0;
+			for (int i = 0; i < n; ++i) {
+				Object el = in.get(i);
+				int ix = getElementIndex(el);
+				if (ix >= 0) {
+					ixs[count++] = ix;
 				}
-				if (count < n) {
-					System.arraycopy(ixs, 0, ixs = new int[count], 0, count);
-				}
-				list.deselectAll();
-				list.select(ixs);
 			}
+			if (count < n) {
+				System.arraycopy(ixs, 0, ixs = new int[count], 0, count);
+			}
+			list.deselectAll();
+			list.select(ixs);
 		}
 	}
 
