@@ -42,7 +42,7 @@ import org.eclipse.core.runtime.Assert;
  * @since 3.1
  */
 public class LazySortedCollection {
-	private final int MIN_CAPACITY = 8;
+	private static final int MIN_CAPACITY = 8;
 	private Object[] contents = new Object[MIN_CAPACITY];
 	private int[] leftSubTree = new int[MIN_CAPACITY];
 	private int[] rightSubTree = new int[MIN_CAPACITY];
@@ -848,10 +848,11 @@ public class LazySortedCollection {
 	/**
 	 * Retains the n smallest items in the collection, removing the rest. When
 	 * this method returns, the size of the collection will be n. Note that
-	 * this is a no-op if n > the current size of the collection.
-	 *
+	 * this is a no-op if n &gt; the current size of the collection.
+	 * <p>
 	 * Temporarily package visibility until the implementation of FastProgressReporter
 	 * is finished.
+	 * </p>
 	 *
 	 * @param n number of items to retain
 	 * @param mon progress monitor
