@@ -65,10 +65,14 @@ public abstract class AbstractWidgetFactory<F extends AbstractWidgetFactory<?, ?
 	 */
 	public final W create(P parent) {
 		W widget = widgetCreator.create(parent);
-		properties.forEach(p -> p.apply(widget));
+		applyProperties(widget);
 		return widget;
 	}
 
+	void applyProperties(W widget) {
+		properties.forEach(p -> p.apply(widget));
+	}
+
 	/**
 	 * Adds a property like image, text, enabled, listeners, ... to the widget.
 	 *
