@@ -14,10 +14,12 @@
 package org.eclipse.jface.widgets;
 
 
+import org.eclipse.swt.browser.Browser;
 import org.eclipse.swt.custom.SashForm;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.DateTime;
+import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Sash;
 import org.eclipse.swt.widgets.Shell;
@@ -193,11 +195,33 @@ public final class WidgetFactory {
 	/**
 	 * @param style SWT style applicable for Shell. Refer to
 	 *              {@link Shell#Shell(Shell, int)} for supported styles.
-	 * @return SashFormFactory
+	 * @return ShellFactory
 	 *
 	 * @since 3.21
 	 */
 	public static ShellFactory shell(int style) {
 		return ShellFactory.newShell(style);
 	}
+
+	/**
+	 * @param style SWT style applicable for Group. Refer to
+	 *              {@link Group#Group(Composite, int)} for supported styles.
+	 * @return GroupFactory
+	 *
+	 * @since 3.24
+	 */
+	public static GroupFactory group(int style) {
+		return GroupFactory.newGroup(style);
+	}
+
+	/**
+	 * @param style SWT style applicable for Browser. Refer to
+	 *              {@link Browser#Browser(Composite, int)} for supported styles.
+	 * @return BrowserFactory
+	 *
+	 * @since 3.25
+	 */
+	public static BrowserFactory browser(int style) {
+		return BrowserFactory.newBrowser(style);
+	}
 }
\ No newline at end of file
