@@ -1004,7 +1004,6 @@ public class FormText extends Canvas {
 
 	/**
 	 * Removes the specified selection listener.
-	 * <p>
 	 *
 	 * @param listener
 	 *            the listener
@@ -1031,7 +1030,6 @@ public class FormText extends Canvas {
 
 	/**
 	 * Returns the selected text.
-	 * <p>
 	 *
 	 * @return selected text, or an empty String if there is no selection.
 	 * @exception SWTException
@@ -1391,33 +1389,31 @@ public class FormText extends Canvas {
 				entered = null;
 			}
 			setCursor(null);
-		} else {
-			if (segmentUnder instanceof IHyperlinkSegment) {
-				IHyperlinkSegment linkUnder = (IHyperlinkSegment) segmentUnder;
-				if (entered!=null && linkUnder!=entered) {
-					// Special case: links are so close that there are 0 pixels between.
-					// Must exit the link before entering the next one.
-					exitLink(entered, e.stateMask);
-					paintLinkHover(entered, false);
-					entered = null;
-				}
-				if (entered == null) {
-					entered = linkUnder;
-					enterLink(linkUnder, e.stateMask);
-					paintLinkHover(entered, true);
-					setCursor(model.getHyperlinkSettings().getHyperlinkCursor());
-				}
-			} else {
-				if (entered != null) {
-					exitLink(entered, e.stateMask);
-					paintLinkHover(entered, false);
-					entered = null;
-				}
-				if (segmentUnder instanceof TextSegment)
-					setCursor(model.getHyperlinkSettings().getTextCursor());
-				else
-					setCursor(null);
+		} else if (segmentUnder instanceof IHyperlinkSegment) {
+			IHyperlinkSegment linkUnder = (IHyperlinkSegment) segmentUnder;
+			if (entered!=null && linkUnder!=entered) {
+				// Special case: links are so close that there are 0 pixels between.
+				// Must exit the link before entering the next one.
+				exitLink(entered, e.stateMask);
+				paintLinkHover(entered, false);
+				entered = null;
 			}
+			if (entered == null) {
+				entered = linkUnder;
+				enterLink(linkUnder, e.stateMask);
+				paintLinkHover(entered, true);
+				setCursor(model.getHyperlinkSettings().getHyperlinkCursor());
+			}
+		} else {
+			if (entered != null) {
+				exitLink(entered, e.stateMask);
+				paintLinkHover(entered, false);
+				entered = null;
+			}
+			if (segmentUnder instanceof TextSegment)
+				setCursor(model.getHyperlinkSettings().getTextCursor());
+			else
+				setCursor(null);
 		}
 	}
 
