@@ -16,7 +16,6 @@ package org.eclipse.ui.internal.forms.css.dom;
 import org.eclipse.e4.ui.css.core.dom.CSSStylableElement;
 import org.eclipse.e4.ui.css.core.engine.CSSEngine;
 import org.eclipse.e4.ui.css.swt.dom.CompositeElement;
-import org.eclipse.swt.graphics.Color;
 import org.eclipse.ui.forms.widgets.Section;
 
 /**
@@ -26,26 +25,16 @@ import org.eclipse.ui.forms.widgets.Section;
 public class SectionElement extends CompositeElement {
 
 
-	private Color titleBarForeground;
-	private Color titleBarBackground;
-	private Color titleBarBorderColor;
-	private Color titleBarGradientBackground;
-
 	public SectionElement(Section section, CSSEngine engine) {
 		super(section, engine);
-		titleBarForeground = section.getTitleBarForeground();
-		titleBarBackground = section.getTitleBarBackground();
-		titleBarBorderColor = section.getTitleBarBorderColor();
-		titleBarGradientBackground = section.getTitleBarGradientBackground();
 	}
 
 	@Override
 	public void reset() {
 		Section section = (Section) getWidget();
-		section.setTitleBarForeground(titleBarForeground);
-		section.setTitleBarBackground(titleBarBackground);
-		section.setTitleBarBorderColor(titleBarBorderColor);
-		section.setTitleBarGradientBackground(titleBarGradientBackground);
+		section.setTitleBarForeground(null);
+		section.setToggleColor(null);
+		section.setActiveToggleColor(null);
 		super.reset();
 	}
 
