@@ -573,7 +573,7 @@ public class ResourceListSelectionDialog extends SelectionDialog {
 				match = true;
 			} else {
 				int compare = descriptors[index].compareTo(desc);
-				if (compare == -1) {
+				if (compare < 0) {
 					low = index;
 				} else {
 					high = index;
@@ -660,7 +660,7 @@ public class ResourceListSelectionDialog extends SelectionDialog {
 				match = true;
 			} else {
 				int compare = descriptors[index].compareTo(desc);
-				if (compare == -1) {
+				if (compare < 0) {
 					low = index;
 				} else {
 					high = index;
