@@ -42,7 +42,6 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.OperationCanceledException;
-import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Preferences;
 import org.eclipse.core.runtime.SubMonitor;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
@@ -210,7 +209,7 @@ public class WizardNewFileCreationPage extends WizardPage implements Listener {
 					String resourceName = resourceGroup.getResource();
 					if (resourceName.length() > 0) {
 						try {
-							return ((IContainer) resource).getFile(Path.fromOSString(resourceName));
+							return ((IContainer) resource).getFile(IPath.fromOSString(resourceName));
 						} catch (IllegalArgumentException e) {
 							// continue below.
 						}
@@ -383,14 +382,7 @@ public class WizardNewFileCreationPage extends WizardPage implements Listener {
 							return null;
 					}
 				}
-			} catch (CoreException e) {
-				MessageDialog.open(MessageDialog.ERROR, getContainer().getShell(),
-						IDEWorkbenchMessages.WizardNewFileCreationPage_internalErrorTitle,
-						NLS.bind(IDEWorkbenchMessages.WizardNewFileCreationPage_internalErrorMessage, e.getMessage()),
-						SWT.SHEET);
-
-				return null;
-			} catch (IOException e) {
+			} catch (CoreException | IOException e) {
 				MessageDialog.open(MessageDialog.ERROR, getContainer().getShell(),
 						IDEWorkbenchMessages.WizardNewFileCreationPage_internalErrorTitle,
 						NLS.bind(IDEWorkbenchMessages.WizardNewFileCreationPage_internalErrorMessage, e.getMessage()),
@@ -761,7 +753,20 @@ public class WizardNewFileCreationPage extends WizardPage implements Listener {
 
 		String resourceName = resourceGroup.getResource();
 		IWorkspace workspace = ResourcesPlugin.getWorkspace();
-		IStatus result = workspace.validateName(resourceName, IResource.FILE);
+
+		IStatus result = null;
+		if (resourceName.isEmpty() || IPath.ROOT.isValidSegment(resourceName)) { // just a file (no subfolder(s))
+			result = workspace.validateName(resourceName, IResource.FILE);
+		} else {
+			IPath containerPath = resourceGroup.getContainerFullPath();
+			if (containerPath == null) {
+				result = workspace.validatePath(resourceName, IResource.FILE);
+			} else {
+				result = workspace.validatePath(containerPath.toString() + IPath.SEPARATOR + resourceName,
+						IResource.FILE);
+			}
+		}
+
 		if (!result.isOK()) {
 			setErrorMessage(result.getMessage());
 			return false;
