@@ -24,7 +24,6 @@ import org.eclipse.ui.IWorkbenchPreferenceConstants;
 import org.eclipse.ui.ide.IDE;
 import org.eclipse.ui.internal.ide.handlers.ShowInSystemExplorerHandler;
 import org.eclipse.ui.internal.ide.registry.SystemEditorOrTextEditorStrategy;
-import org.eclipse.ui.internal.views.markers.MarkerSupportInternalUtilities;
 
 /**
  * The IDEPreferenceInitializer is the preference initializer for the IDE
@@ -53,7 +52,7 @@ public class IDEPreferenceInitializer extends AbstractPreferenceInitializer {
 		node.putBoolean(IDEInternalPreferences.REFRESH_WORKSPACE_ON_STARTUP,
 				false);
 		node.putBoolean(
-				IDEInternalPreferences.EXIT_PROMPT_ON_CLOSE_LAST_WINDOW, true);
+				IDEInternalPreferences.EXIT_PROMPT_ON_CLOSE_LAST_WINDOW, false);
 		node.put(IDEInternalPreferences.PROJECT_SWITCH_PERSP_MODE,
 				IDEInternalPreferences.PSPM_PROMPT);
 		node.put(IDEInternalPreferences.OPEN_REQUIRED_PROJECTS,
@@ -77,11 +76,6 @@ public class IDEPreferenceInitializer extends AbstractPreferenceInitializer {
 		node.put(IDEInternalPreferences.IMPORT_FILES_AND_FOLDERS_TYPE, ""); //$NON-NLS-1$
 		node.putBoolean(IDEInternalPreferences.IMPORT_FILES_AND_FOLDERS_RELATIVE, true);
 
-		//Filter migration
-		node.putBoolean(MarkerSupportInternalUtilities.MIGRATE_BOOKMARK_FILTERS, false);
-		node.putBoolean(MarkerSupportInternalUtilities.MIGRATE_TASK_FILTERS, false);
-		node.putBoolean(MarkerSupportInternalUtilities.MIGRATE_PROBLEM_FILTERS, false);
-
 		node.put(IDEInternalPreferences.IMPORT_FILES_AND_FOLDERS_MODE, IDEInternalPreferences.IMPORT_FILES_AND_FOLDERS_MODE_PROMPT);
 		node.put(IDEInternalPreferences.IMPORT_FILES_AND_FOLDERS_VIRTUAL_FOLDER_MODE, IDEInternalPreferences.IMPORT_FILES_AND_FOLDERS_MODE_PROMPT);
 
