@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2017 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -11,10 +11,12 @@
  * Contributors:
  *     IBM Corporation - initial API and implementation
  *     Patrik Suzzi <psuzzi@gmail.com> - Bug 489250
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 548799
  *******************************************************************************/
 
 package org.eclipse.ui.internal.ide;
 
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -32,6 +34,7 @@ import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.resource.LocalResourceManager;
+import org.eclipse.jface.resource.ResourceLocator;
 import org.eclipse.jface.resource.ResourceManager;
 import org.eclipse.swt.custom.BusyIndicator;
 import org.eclipse.swt.widgets.Display;
@@ -49,8 +52,6 @@ import org.eclipse.ui.plugin.AbstractUIPlugin;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * This internal class represents the top of the IDE workbench.
  *
@@ -114,15 +115,15 @@ public class IDEWorkbenchPlugin extends AbstractUIPlugin {
 		super();
 		inst = this;
 	}
+
 	/**
-	 * Creates an extension.  If the extension plugin has not
-	 * been loaded a busy cursor will be activated during the duration of
-	 * the load.
+	 * Creates an extension. If the extension plugin has not been loaded a busy
+	 * cursor will be activated during the duration of the load.
 	 *
-	 * @param element the config element defining the extension
+	 * @param element        the config element defining the extension
 	 * @param classAttribute the name of the attribute carrying the class
 	 * @return Object the extension object
-	 * @throws CoreException
+	 * @throws CoreException if extension creation failed
 	 */
 	public static Object createExtension(final IConfigurationElement element,
 			final String classAttribute) throws CoreException {
@@ -309,18 +310,21 @@ public class IDEWorkbenchPlugin extends AbstractUIPlugin {
 
 		return infos.toArray(new AboutInfo[infos.size()]);
 	}
+
 	/**
-	 * Get the workbench image with the given path relative to
-	 * ICON_PATH.
-	 * @param relativePath
-	 * @return ImageDescriptor
+	 * Get the workbench image with the given path relative to ICON_PATH.
+	 *
+	 * @param relativePath relative path of image
+	 * @return ImageDescriptor or <code>null</code>
 	 */
 	public static ImageDescriptor getIDEImageDescriptor(String relativePath){
-		return imageDescriptorFromPlugin(IDE_WORKBENCH, ICONS_PATH + relativePath);
+		return ResourceLocator.imageDescriptorFromBundle(IDE_WORKBENCH, ICONS_PATH + relativePath).orElse(null);
 	}
+
 	/**
 	 * Return the resourceManager used by this plug-in.
-	 * @return
+	 *
+	 * @return the resource manager
 	 */
 	public ResourceManager getResourceManager() {
 		if(resourceManager == null){
