@@ -243,6 +243,9 @@ public final class EmptyWorkspaceHelper {
 			return;
 		}
 		IWorkbenchPage page = win.getActivePage();
+		if (page == null) {
+			return;
+		}
 		String[] wizardIds = page.getNewWizardShortcuts();
 		projectWizardActions.clear();
 		for (String wizardId : wizardIds) {
@@ -271,7 +274,7 @@ public final class EmptyWorkspaceHelper {
 			ISharedImages images = PlatformUI.getWorkbench().getSharedImages();
 			imageDesc = images.getImageDescriptor(ISharedImages.IMG_TOOL_NEW_WIZARD);
 		}
-		addLabel.setImage(resourceManager.createImage(imageDesc));
+		addLabel.setImage(resourceManager.create(imageDesc));
 
 		Hyperlink addLink = toolkit.createHyperlink(optionsArea, text, SWT.WRAP);
 		addLink.setForeground(linkColor);
