@@ -24,7 +24,6 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.eclipse.core.resources.IMarker;
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.resources.ResourcesPlugin;
@@ -117,10 +116,6 @@ class MarkerFieldFilterGroup {
 	private String name;
 	private String id;
 
-	/**
-	 * The entry for testing filters. Cached to prevent garbage.
-	 */
-	private MarkerEntry testEntry = new MarkerEntry(null);
 	private IWorkingSet workingSet;
 	private IResource[] wSetResources;
 
@@ -144,7 +139,7 @@ class MarkerFieldFilterGroup {
 			enabled = false;
 		}
 		stringValue = configurationElement.getAttribute(MarkerSupportRegistry.FILTER_LIMIT);
-		if (stringValue == null || stringValue.length() == 0) {
+		if (stringValue == null || stringValue.isEmpty()) {
 			limit = -1;
 		}
 	}
@@ -220,7 +215,7 @@ class MarkerFieldFilterGroup {
 	public String getID() {
 		if (id == null) {
 			if (element == null) {
-				id = USER + String.valueOf(System.currentTimeMillis());
+				id = USER + System.currentTimeMillis();
 			} else {
 				id = element.getAttribute(MarkerSupportInternalUtilities.ATTRIBUTE_ID);
 			}
@@ -574,17 +569,6 @@ class MarkerFieldFilterGroup {
 		}
 	}
 
-	/**
-	 * Return whether or not this IMarker is being shown.
-	 *
-	 * @param marker
-	 * @return <code>true</code> if it is being shown
-	 */
-	public boolean select(IMarker marker) {
-		testEntry.setMarker(marker);
-		return select(testEntry);
-	}
-
 	/**
 	 * Return whether or not this MarkerEntry can be shown.
 	 *
