@@ -66,8 +66,7 @@ public class MarkersViewColumnsDialog extends ViewerColumnsDialog<FieldEntry> {
 
 	@Override
 	protected Control createDialogArea(Composite parent) {
-		Control control = super.createDialogArea(parent);
-		return control;
+		return super.createDialogArea(parent);
 	}
 
 	@Override
@@ -155,7 +154,7 @@ public class MarkersViewColumnsDialog extends ViewerColumnsDialog<FieldEntry> {
 	@Override
 	protected IColumnInfoProvider<FieldEntry> getColumnInfoProvider() {
 
-		return new IColumnInfoProvider<FieldEntry>() {
+		return new IColumnInfoProvider<>() {
 			@Override
 			public int getColumnIndex(FieldEntry columnObj) {
 				return getVisible().indexOf(columnObj);
@@ -190,7 +189,7 @@ public class MarkersViewColumnsDialog extends ViewerColumnsDialog<FieldEntry> {
 	@Override
 	protected IColumnUpdater<FieldEntry> getColumnUpdater() {
 
-		return new IColumnUpdater<FieldEntry>() {
+		return new IColumnUpdater<>() {
 			@Override
 			public void setColumnVisible(FieldEntry columnObj, boolean visible) {
 				columnObj.visible = visible;
