@@ -231,19 +231,18 @@ public class BasicNewProjectResourceWizard extends BasicNewResourceWizard
 
 		// create the new project operation
 		IRunnableWithProgress op = monitor -> {
-CreateProjectOperation op1 = new CreateProjectOperation(
-			description, ResourceMessages.NewProject_windowTitle);
-try {
-		// see bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=219901
-		// directly execute the operation so that the undo state is
-		// not preserved.  Making this undoable resulted in too many
-		// accidental file deletions.
-		op1.execute(monitor, WorkspaceUndoUtil
-			.getUIInfoAdapter(getShell()));
-} catch (ExecutionException e) {
-		throw new InvocationTargetException(e);
-}
-};
+			CreateProjectOperation op1 = new CreateProjectOperation(description,
+					ResourceMessages.NewProject_windowTitle);
+			try {
+				// see bug https://bugs.eclipse.org/bugs/show_bug.cgi?id=219901
+				// directly execute the operation so that the undo state is
+				// not preserved. Making this undoable resulted in too many
+				// accidental file deletions.
+				op1.execute(monitor, WorkspaceUndoUtil.getUIInfoAdapter(getShell()));
+			} catch (ExecutionException e) {
+				throw new InvocationTargetException(e);
+			}
+		};
 
 		// run the new project creation operation
 		try {
