@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2015 IBM Corporation and others.
+ * Copyright (c) 2003, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -231,9 +231,17 @@ public class CommonActionProviderDescriptor implements
 			}
 		} else {
 			IEvaluationContext parentContext = NavigatorPlugin.getApplicationContext();
+			boolean isEnabled = true;
 			for (Object element : aStructuredSelection) {
 				IEvaluationContext context = new EvaluationContext(parentContext, element);
 				context.setAllowPluginActivation(true);
+				if (NavigatorPlugin.safeEvaluate(enablement, context) != EvaluationResult.TRUE) {
+					isEnabled = false;
+				}
+			}
+			if (!isEnabled) {
+				IEvaluationContext context = new EvaluationContext(parentContext, aStructuredSelection);
+				context.setAllowPluginActivation(true);
 				if (NavigatorPlugin.safeEvaluate(enablement, context) != EvaluationResult.TRUE) {
 					return false;
 				}
