@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2019 IBM Corporation and others.
+ * Copyright (c) 2003, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -225,8 +225,8 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 
 		commonActionGroup = createCommonActionGroup();
 		commonActionGroup.fillActionBars(getViewSite().getActionBars());
-		if (memento != null && commonActionGroup instanceof IMementoAware) {
-			((IMementoAware) commonActionGroup).restoreState(memento);
+		if (memento != null && commonActionGroup instanceof IMementoAware mementoAware) {
+			mementoAware.restoreState(memento);
 		}
 
 		ISaveablesLifecycleListener saveablesLifecycleListener = new ISaveablesLifecycleListener() {
@@ -356,8 +356,8 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 		super.saveState(aMemento);
 		commonManager.saveState(aMemento);
 		commonViewer.getNavigatorContentService().saveState(aMemento);
-		if (commonActionGroup instanceof IMementoAware) {
-			((IMementoAware) commonActionGroup).saveState(aMemento);
+		if (commonActionGroup instanceof IMementoAware mementoAware) {
+			mementoAware.saveState(aMemento);
 		}
 	}
 
@@ -687,9 +687,9 @@ public class CommonNavigator extends ViewPart implements ISetSelectionTarget, IS
 			}
 		}
 		Object input = context.getInput();
-		if (input instanceof IEditorInput) {
+		if (input instanceof IEditorInput editorInput) {
 			LinkHelperService lhs = getLinkHelperService();
-			selection = lhs.getSelectionFor((IEditorInput) input);
+			selection = lhs.getSelectionFor(editorInput);
 			if (selection != null && !selection.isEmpty()) {
 				selectReveal(selection);
 				return true;
