@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2016 IBM Corporation and others.
+ * Copyright (c) 2003, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -122,7 +122,7 @@ public class CommonViewer extends TreeViewer {
 	/**
 	 * Sets the {@link ICommonViewerMapper} to work with this viewer.
 	 *
-	 * @param mapper
+	 * @param mapper the mapper
 	 * @since 3.4
 	 */
 	public void setMapper(ICommonViewerMapper mapper) {
@@ -218,7 +218,7 @@ public class CommonViewer extends TreeViewer {
 
 		Object[] changed = event.getElements();
 		if (changed != null) {
-			List<Object> others = new ArrayList<Object>();
+			List<Object> others = new ArrayList<>();
 			for (Object changedElement : changed) {
 				if (changedElement == null)
 					continue;
@@ -268,8 +268,8 @@ public class CommonViewer extends TreeViewer {
 	 */
 	@Override
 	public void setSorter(ViewerSorter sorter) {
-		if (sorter != null && sorter instanceof CommonViewerSorter) {
-			((CommonViewerSorter) sorter).setContentService(contentService);
+		if (sorter != null && sorter instanceof CommonViewerSorter commonSorter) {
+			commonSorter.setContentService(contentService);
 		}
 
 		super.setSorter(sorter);
@@ -289,7 +289,7 @@ public class CommonViewer extends TreeViewer {
 	}
 
 	@Override
-	public void add(Object parentElement, Object[] childElements) {
+	public void add(Object parentElement, Object... childElements) {
 		NavigatorPipelineService pipeDream = (NavigatorPipelineService) contentService
 				.getPipelineService();
 
@@ -314,7 +314,7 @@ public class CommonViewer extends TreeViewer {
 	 * @see org.eclipse.jface.viewers.AbstractTreeViewer#remove(java.lang.Object[])
 	 */
 	@Override
-	public void remove(Object[] elements) {
+	public void remove(Object... elements) {
 		NavigatorPipelineService pipeDream = (NavigatorPipelineService) contentService
 				.getPipelineService();
 
@@ -356,9 +356,7 @@ public class CommonViewer extends TreeViewer {
 	@Override
 	public void setSelection(ISelection selection, boolean reveal) {
 
-		if(selection instanceof IStructuredSelection) {
-			IStructuredSelection sSelection = (IStructuredSelection) selection;
-
+		if (selection instanceof IStructuredSelection sSelection) {
 			INavigatorPipelineService pipeDream = contentService
 					.getPipelineService();
 
@@ -410,8 +408,8 @@ public class CommonViewer extends TreeViewer {
 	@Override
 	protected void mapElement(Object element, Widget item) {
 		super.mapElement(element, item);
-		if (_mapper != null && item instanceof Item) {
-			_mapper.addToMap(element, (Item) item);
+		if (_mapper != null && item instanceof Item it) {
+			_mapper.addToMap(element, it);
 		}
 	}
 
@@ -420,8 +418,8 @@ public class CommonViewer extends TreeViewer {
 	 */
 	@Override
 	protected void unmapElement(Object element, Widget item) {
-		if (_mapper != null && item instanceof Item) {
-			_mapper.removeFromMap(element, (Item) item);
+		if (_mapper != null && item instanceof Item it) {
+			_mapper.removeFromMap(element, it);
 		}
 		super.unmapElement(element, item);
 	}
@@ -521,7 +519,7 @@ public class CommonViewer extends TreeViewer {
 
 	@Override
 	public String toString() {
-		return contentService.toString() + " Viewer"; //$NON-NLS-1$
+		return contentService + " Viewer"; //$NON-NLS-1$
 	}
 
 	@Override
