@@ -158,8 +158,10 @@ public interface IWorkbenchPreferenceConstants {
 	 * {@link #TOP_LEFT}, or {@link #LEFT}.
 	 * </p>
 	 *
+	 * @deprecated not used anymore by platform
 	 * @since 3.0
 	 */
+	@Deprecated
 	String DOCK_PERSPECTIVE_BAR = "DOCK_PERSPECTIVE_BAR"; //$NON-NLS-1$
 
 	/**
@@ -194,16 +196,20 @@ public interface IWorkbenchPreferenceConstants {
 	 * Constant to be used when referring to the top right of the workbench window.
 	 *
 	 * @see #DOCK_PERSPECTIVE_BAR
+	 * @deprecated not used anymore by platform
 	 * @since 3.0
 	 */
+	@Deprecated
 	String TOP_RIGHT = "topRight"; //$NON-NLS-1$
 
 	/**
 	 * Constant to be used when referring to the top left of the workbench window.
 	 *
 	 * @see #DOCK_PERSPECTIVE_BAR
+	 * @deprecated not used anymore by platform
 	 * @since 3.0
 	 */
+	@Deprecated
 	String TOP_LEFT = "topLeft"; //$NON-NLS-1$
 
 	/**
@@ -255,8 +261,10 @@ public interface IWorkbenchPreferenceConstants {
 	 * The default value for this preference is: <code>true</code>
 	 * </p>
 	 *
+	 * @deprecated not supported since the 4.x migration
 	 * @since 3.0
 	 */
+	@Deprecated
 	String SHOW_TRADITIONAL_STYLE_TABS = "SHOW_TRADITIONAL_STYLE_TABS"; //$NON-NLS-1$
 
 	/**
@@ -274,6 +282,22 @@ public interface IWorkbenchPreferenceConstants {
 	 */
 	String SHOW_TEXT_ON_PERSPECTIVE_BAR = "SHOW_TEXT_ON_PERSPECTIVE_BAR"; //$NON-NLS-1$
 
+	/**
+	 * A named preference for whether the workbench should show text on the find
+	 * actions bar.
+	 *
+	 * Boolean-valued: <code>true</code>, if the application should show text on the
+	 * find action bar, <code>false</code> otherwise.
+	 * <p>
+	 * The default value for this preference is: <code>false</code> (do not show
+	 * text on the find actions bar)
+	 * </p>
+	 *
+	 * @since 3.117
+	 */
+
+	String SHOW_TEXT_ON_QUICK_ACCESS = "SHOW_TEXT_ON_QUICK_ACCESS"; //$NON-NLS-1$
+
 	/**
 	 * A named preference for whether the workbench should show the "open
 	 * perspective" button on the perspective bar.
@@ -348,9 +372,27 @@ public interface IWorkbenchPreferenceConstants {
 	 * </p>
 	 *
 	 * @since 3.1
+	 *
+	 * @deprecated not supported by the platform anymore
 	 */
+	@Deprecated
 	String ENABLE_ANIMATIONS = "ENABLE_ANIMATIONS"; //$NON-NLS-1$
 
+	/**
+	 * A named preference for setting CTabFolder's to be rendered with rounded
+	 * corners
+	 * <p>
+	 * The default value for this preference is: <code>false</code> (render
+	 * CTabFolder's with square corners)
+	 * </p>
+	 *
+	 * @deprecated No longer in use. Use swt-corner-radius CSS property to override
+	 *             when round or square corners are desired.
+	 * @since 3.120
+	 */
+	@Deprecated
+	String USE_ROUND_TABS = "USE_ROUND_TABS"; //$NON-NLS-1$
+
 	/**
 	 * A named preference that view implementors can used to determine whether or
 	 * not they should utilize colored labels.
@@ -372,7 +414,7 @@ public interface IWorkbenchPreferenceConstants {
 	 * <p>
 	 * The default value for this preference is
 	 * <code>"org.eclipse.ui.defaultAcceleratorConfiguration"</code>.
-	 * <p>
+	 * </p>
 	 *
 	 * @since 3.1
 	 */
@@ -602,4 +644,65 @@ public interface IWorkbenchPreferenceConstants {
 	 * @since 3.112
 	 */
 	String HIDE_QUICK_ACCESS_PER_DEFAULT = "hideQuickAccessPerDefault"; //$NON-NLS-1$
+
+	/**
+	 * <p>
+	 * Whether to use inline or dialog rename on resources.
+	 * </p>
+	 *
+	 * @since 3.118
+	 */
+	String RESOURCE_RENAME_MODE = "RESOURCE_RENAME_MODE"; //$NON-NLS-1$
+
+	/**
+	 * <p>
+	 * Preference value for {@link #RESOURCE_RENAME_MODE}, indicating that inline
+	 * rename should be used.
+	 * </p>
+	 *
+	 * @since 3.118
+	 */
+	String RESOURCE_RENAME_MODE_INLINE = "inline"; //$NON-NLS-1$
+
+	/**
+	 * <p>
+	 * Preference value for {@link #RESOURCE_RENAME_MODE}, indicating that dialog
+	 * rename should be used.
+	 * </p>
+	 *
+	 * @since 3.118
+	 */
+	String RESOURCE_RENAME_MODE_DIALOG = "dialog"; //$NON-NLS-1$
+
+	/**
+	 * Preference for the <i>advised</i> time (in ms) after a closed browser hover
+	 * is to be disposed.
+	 * <p>
+	 * The integer default value for this preference is: <code>-1</code>.
+	 * Non-positive values indicate closed hovers are not disposed automatically.
+	 * </p>
+	 *
+	 * @since 3.129
+	 */
+	String DISPOSE_CLOSED_BROWSER_HOVER_TIMEOUT = "disposeClosedBrowserHoverTimeout"; //$NON-NLS-1$
+
+	/**
+	 * <p>
+	 * <strong>EXPERIMENTAL</strong>. This class or interface has been added as part
+	 * of a work in progress. There is no guarantee that this API will work or that
+	 * it will remain the same. Please do not use this API without consulting with
+	 * the API development team.
+	 * </p>
+	 *
+	 * This preference specifies the limit for number of children that can be shown
+	 * per parent element without expanding.
+	 * <p>
+	 * This preference is an <code>int</code> value that defines how many child
+	 * elements a parent viewer element can show before workbench will create
+	 * "expand" item that hides all remaining child elements.
+	 * </p>
+	 *
+	 * @since 3.130
+	 */
+	String LARGE_VIEW_LIMIT = "largeViewLimit"; //$NON-NLS-1$
 }
