@@ -42,7 +42,6 @@ import org.eclipse.osgi.util.NLS;
 import org.eclipse.osgi.util.TextProcessor;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Font;
-import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.layout.RowLayout;
@@ -68,6 +67,7 @@ import org.eclipse.ui.internal.registry.EditorRegistry;
 import org.eclipse.ui.internal.registry.FileEditorMapping;
 import org.eclipse.ui.progress.IProgressService;
 import org.eclipse.ui.statushandlers.StatusManager;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * This class is used to allow the user to select a dialog from the set of
@@ -278,7 +278,7 @@ public class EditorSelectionDialog extends Dialog {
 			return TextProcessor.process(d.getLabel(), "."); //$NON-NLS-1$
 		}, element -> {
 			IEditorDescriptor d = (IEditorDescriptor) element;
-			return (Image) resourceManager.get(d.getImageDescriptor());
+			return resourceManager.get(d.getImageDescriptor());
 		}));
 
 		browseExternalEditorsButton = new Button(contents, SWT.PUSH);
@@ -397,7 +397,8 @@ public class EditorSelectionDialog extends Dialog {
 	 * Return the dialog store to cache values into
 	 */
 	protected IDialogSettings getDialogSettings() {
-		IDialogSettings workbenchSettings = WorkbenchPlugin.getDefault().getDialogSettings();
+		IDialogSettings workbenchSettings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(EditorSelectionDialog.class)).getDialogSettings();
 		IDialogSettings section = workbenchSettings.getSection("EditorSelectionDialog");//$NON-NLS-1$
 		if (section == null) {
 			section = workbenchSettings.addNewSection("EditorSelectionDialog");//$NON-NLS-1$
@@ -635,12 +636,9 @@ public class EditorSelectionDialog extends Dialog {
 					hasMapping = true;
 					break;
 				}
-			} else {
-				if (fileType.equals(mapping.getExtension())) {
-					hasMapping = true;
-					break;
-				}
-
+			} else if (fileType.equals(mapping.getExtension())) {
+				hasMapping = true;
+				break;
 			}
 		}
 		if (hasMapping) {
