@@ -15,9 +15,8 @@ package org.eclipse.ui.dialogs;
 
 import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
-import com.ibm.icu.text.MessageFormat;
+import java.text.MessageFormat;
 import java.util.Iterator;
-
 import org.eclipse.jface.preference.IPreferenceNode;
 import org.eclipse.jface.preference.PreferenceManager;
 import org.eclipse.osgi.util.NLS;
@@ -76,10 +75,11 @@ public class PreferenceLinkArea extends Object {
 	 * @return IPreferenceNode
 	 */
 	private IPreferenceNode getPreferenceNode(String pageId) {
-		Iterator iterator = PlatformUI.getWorkbench().getPreferenceManager().getElements(PreferenceManager.PRE_ORDER)
+		Iterator<IPreferenceNode> iterator = PlatformUI.getWorkbench().getPreferenceManager().getElements(
+				PreferenceManager.PRE_ORDER)
 				.iterator();
 		while (iterator.hasNext()) {
-			IPreferenceNode next = (IPreferenceNode) iterator.next();
+			IPreferenceNode next = iterator.next();
 			if (next.getId().equals(pageId)) {
 				return next;
 			}
