@@ -249,7 +249,7 @@ public abstract class AbstractWorkingSetManager extends EventManager
 
 	@Override
 	public IWorkingSet[] getWorkingSets() {
-		SortedSet<IWorkingSet> visibleSubset = new TreeSet<IWorkingSet>(WorkingSetComparator.getInstance());
+		SortedSet<IWorkingSet> visibleSubset = new TreeSet<>(WorkingSetComparator.getInstance());
 		for (IWorkingSet workingSet : workingSets) {
 			if (workingSet.isVisible()) {
 				visibleSubset.add(workingSet);
@@ -446,9 +446,9 @@ public abstract class AbstractWorkingSetManager extends EventManager
 	 * @param list    the working sets to save
 	 * @since 3.2
 	 */
-	private void saveWorkingSetState(final IMemento memento, List list) {
-		for (Iterator i = list.iterator(); i.hasNext();) {
-			final IPersistableElement persistable = (IWorkingSet) i.next();
+	private void saveWorkingSetState(final IMemento memento, List<IWorkingSet> list) {
+		for (Iterator<IWorkingSet> i = list.iterator(); i.hasNext();) {
+			final IPersistableElement persistable = i.next();
 			SafeRunner.run(new WorkingSetRunnable() {
 
 				@Override
@@ -528,12 +528,8 @@ public abstract class AbstractWorkingSetManager extends EventManager
 	 * @param memento the persistence store
 	 */
 	protected void saveMruList(IMemento memento) {
-		Iterator iterator = recentWorkingSets.iterator();
-
-		while (iterator.hasNext()) {
-			IWorkingSet workingSet = (IWorkingSet) iterator.next();
+		for (IWorkingSet workingSet : recentWorkingSets) {
 			IMemento mruMemento = memento.createChild(IWorkbenchConstants.TAG_MRU_LIST);
-
 			mruMemento.putString(IWorkbenchConstants.TAG_NAME, workingSet.getName());
 		}
 	}
@@ -683,10 +679,10 @@ public abstract class AbstractWorkingSetManager extends EventManager
 	}
 
 	private static List<WorkingSetDescriptor> getUniqueDescriptors(String symbolicName) {
-		final List<WorkingSetDescriptor> descriptors = WorkbenchPlugin.getDefault().getWorkingSetRegistry()
-				.getUpdaterDescriptorsForNamespace(symbolicName);
+
 		// Note: WorkingSetRegistry never contains descriptors with same id
-		return descriptors;
+		return WorkbenchPlugin.getDefault().getWorkingSetRegistry()
+				.getUpdaterDescriptorsForNamespace(symbolicName);
 	}
 
 	private List<IWorkingSet> getWorkingSetsForId(String id) {
@@ -719,20 +715,30 @@ public abstract class AbstractWorkingSetManager extends EventManager
 		}
 	}
 
-	private IWorkingSetUpdater getUpdater(WorkingSetDescriptor descriptor) {
-		IWorkingSetUpdater updater = updaters.get(descriptor.getId());
+	IWorkingSetUpdater getUpdater(WorkingSetDescriptor descriptor) {
+		String updaterId = descriptor.getId();
+		IWorkingSetUpdater updater = updaters.get(updaterId);
 		if (updater == null) {
 			updater = descriptor.createWorkingSetUpdater();
+			boolean fireChange = true;
 			if (updater == null) {
 				updater = NULL_UPDATER;
-			} else {
+				fireChange = false;
+			}
+			synchronized (updaters) {
+				IWorkingSetUpdater old = updaters.putIfAbsent(updaterId, updater);
+				if (fireChange) {
+					// don't fire again if already installed
+					fireChange = old == null;
+				}
+			}
+			if (fireChange) {
 				firePropertyChange(CHANGE_WORKING_SET_UPDATER_INSTALLED, null, updater);
 				PlatformUI.getWorkbench().getExtensionTracker().registerObject(
 						descriptor.getConfigurationElement().getDeclaringExtension(), updater,
 						IExtensionTracker.REF_WEAK);
 
 			}
-			updaters.put(descriptor.getId(), updater);
 		}
 		return updater;
 	}
