@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 548799
  *******************************************************************************/
 package org.eclipse.ui.internal;
 
@@ -17,6 +18,7 @@ import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.ActionContributionItem;
 import org.eclipse.jface.action.IAction;
+import org.eclipse.jface.resource.ResourceLocator;
 import org.eclipse.ui.IEditorPart;
 import org.eclipse.ui.IPluginContribution;
 import org.eclipse.ui.IViewPart;
@@ -24,7 +26,6 @@ import org.eclipse.ui.IWorkbenchActionConstants;
 import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants;
-import org.eclipse.ui.plugin.AbstractUIPlugin;
 
 /**
  * When 'action' tag is found in the registry, an object of this class is
@@ -214,14 +215,15 @@ public class ActionDescriptor implements IPluginContribution {
 		String extendingPluginId = actionElement.getDeclaringExtension().getContributor().getName();
 
 		if (icon != null) {
-			action.setImageDescriptor(AbstractUIPlugin.imageDescriptorFromPlugin(extendingPluginId, icon));
+			ResourceLocator.imageDescriptorFromBundle(extendingPluginId, icon).ifPresent(action::setImageDescriptor);
 		}
 		if (hoverIcon != null) {
-			action.setHoverImageDescriptor(AbstractUIPlugin.imageDescriptorFromPlugin(extendingPluginId, hoverIcon));
+			ResourceLocator.imageDescriptorFromBundle(extendingPluginId, hoverIcon)
+					.ifPresent(action::setHoverImageDescriptor);
 		}
 		if (disabledIcon != null) {
-			action.setDisabledImageDescriptor(
-					AbstractUIPlugin.imageDescriptorFromPlugin(extendingPluginId, disabledIcon));
+			ResourceLocator.imageDescriptorFromBundle(extendingPluginId, disabledIcon)
+					.ifPresent(action::setDisabledImageDescriptor);
 		}
 
 		if (accelerator != null) {
@@ -237,14 +239,21 @@ public class ActionDescriptor implements IPluginContribution {
 			String style) {
 		int actionStyle = IAction.AS_UNSPECIFIED;
 		if (style != null) {
-			if (style.equals(STYLE_RADIO)) {
+			switch (style) {
+			case STYLE_RADIO:
 				actionStyle = IAction.AS_RADIO_BUTTON;
-			} else if (style.equals(STYLE_TOGGLE)) {
+				break;
+			case STYLE_TOGGLE:
 				actionStyle = IAction.AS_CHECK_BOX;
-			} else if (style.equals(STYLE_PULLDOWN)) {
+				break;
+			case STYLE_PULLDOWN:
 				actionStyle = IAction.AS_DROP_DOWN_MENU;
-			} else if (style.equals(STYLE_PUSH)) {
+				break;
+			case STYLE_PUSH:
 				actionStyle = IAction.AS_PUSH_BUTTON;
+				break;
+			default:
+				break;
 			}
 		}
 
@@ -337,14 +346,14 @@ public class ActionDescriptor implements IPluginContribution {
 	 */
 	private void processAccelerator(IAction action, String acceleratorText) {
 
-		if (acceleratorText.length() == 0) {
+		if (acceleratorText.isEmpty()) {
 			return;
 		}
 
 		// Is it a numeric definition?
 		if (Character.isDigit(acceleratorText.charAt(0))) {
 			try {
-				action.setAccelerator(Integer.valueOf(acceleratorText).intValue());
+				action.setAccelerator(Integer.parseInt(acceleratorText));
 			} catch (NumberFormatException e) {
 				WorkbenchPlugin.log("Invalid accelerator declaration for action: " + id, e); //$NON-NLS-1$
 			}
