@@ -103,16 +103,16 @@ public abstract class PartSite implements IWorkbenchPartSite {
 	 */
 	public static final void registerContextMenu(final String menuId, final MenuManager menuManager,
 			final ISelectionProvider selectionProvider, final boolean includeEditorInput, final IWorkbenchPart part,
-			IEclipseContext context, final Collection menuExtenders) {
+			IEclipseContext context, final Collection<PopupMenuExtender> menuExtenders) {
 		/*
 		 * Check to see if the same menu manager and selection provider have already
 		 * been used. If they have, then we can just add another menu identifier to the
 		 * existing PopupMenuExtender.
 		 */
-		final Iterator extenderItr = menuExtenders.iterator();
+		final Iterator<PopupMenuExtender> extenderItr = menuExtenders.iterator();
 		boolean foundMatch = false;
 		while (extenderItr.hasNext()) {
-			final PopupMenuExtender existingExtender = (PopupMenuExtender) extenderItr.next();
+			final PopupMenuExtender existingExtender = extenderItr.next();
 			if (existingExtender.matches(menuManager, selectionProvider, part)) {
 				existingExtender.addMenuId(menuId);
 				foundMatch = true;
@@ -146,7 +146,7 @@ public abstract class PartSite implements IWorkbenchPartSite {
 
 	private SlaveMenuService menuService;
 
-	protected ArrayList menuExtenders;
+	protected ArrayList<PopupMenuExtender> menuExtenders;
 
 	private WorkbenchSiteProgressService progressService;
 
@@ -167,7 +167,6 @@ public abstract class PartSite implements IWorkbenchPartSite {
 	 *
 	 * @param ref  the part reference
 	 * @param part the part
-	 * @param page the page it belongs to
 	 */
 	public PartSite(MPart model, IWorkbenchPart part, IWorkbenchPartReference ref, IConfigurationElement element) {
 		this.model = model;
@@ -302,15 +301,13 @@ public abstract class PartSite implements IWorkbenchPartSite {
 	 */
 	public void dispose() {
 		if (menuExtenders != null) {
-			HashSet managers = new HashSet(menuExtenders.size());
-			for (int i = 0; i < menuExtenders.size(); i++) {
-				PopupMenuExtender ext = (PopupMenuExtender) menuExtenders.get(i);
+			HashSet<MenuManager> managers = new HashSet<>(menuExtenders.size());
+			for (PopupMenuExtender ext : menuExtenders) {
 				managers.add(ext.getManager());
 				ext.dispose();
 			}
 			if (managers.size() > 0) {
-				for (Iterator iterator = managers.iterator(); iterator.hasNext();) {
-					MenuManager mgr = (MenuManager) iterator.next();
+				for (MenuManager mgr : managers) {
 					mgr.dispose();
 				}
 			}
@@ -452,7 +449,7 @@ public abstract class PartSite implements IWorkbenchPartSite {
 		// If someone works with disposed parts, we can't help, it is a bug
 		if (e4Context == null) {
 			WorkbenchPlugin.log(new IllegalStateException(
-					"IWorkbenchSite.getShell() was called after part disposal: " + toString())); //$NON-NLS-1$
+					"IWorkbenchSite.getShell() was called after part disposal: " + this)); //$NON-NLS-1$
 			return PlatformUI.getWorkbench().getDisplay().getActiveShell();
 		}
 
@@ -492,7 +489,7 @@ public abstract class PartSite implements IWorkbenchPartSite {
 	@Override
 	public void registerContextMenu(String menuID, MenuManager menuMgr, ISelectionProvider selProvider) {
 		if (menuExtenders == null) {
-			menuExtenders = new ArrayList(1);
+			menuExtenders = new ArrayList<>(1);
 		}
 
 		registerContextMenu(menuID, menuMgr, selProvider, true, getPart(), e4Context, menuExtenders);
@@ -514,12 +511,11 @@ public abstract class PartSite implements IWorkbenchPartSite {
 		if (menuExtenders == null) {
 			return new String[0];
 		}
-		ArrayList menuIds = new ArrayList(menuExtenders.size());
-		for (Iterator iter = menuExtenders.iterator(); iter.hasNext();) {
-			final PopupMenuExtender extender = (PopupMenuExtender) iter.next();
+		ArrayList<String> menuIds = new ArrayList<>(menuExtenders.size());
+		for (PopupMenuExtender extender : menuExtenders) {
 			menuIds.addAll(extender.getMenuIds());
 		}
-		return (String[]) menuIds.toArray(new String[menuIds.size()]);
+		return menuIds.toArray(new String[menuIds.size()]);
 	}
 
 	/**
