@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -164,6 +164,8 @@ public class PopupMenuExtender implements IMenuListener2, IRegistryChangeListene
 		}
 		if (menuModel == null) {
 			menuModel = MenuFactoryImpl.eINSTANCE.createPopupMenu();
+			menuModel.getPersistedState().put(org.eclipse.e4.ui.workbench.IWorkbench.PERSIST_STATE,
+					Boolean.FALSE.toString());
 			menuModel.setElementId(id);
 			menuModel.getTags().add(ContributionsAnalyzer.MC_POPUP);
 			modelPart.getMenus().add(menuModel);
@@ -350,7 +352,7 @@ public class PopupMenuExtender implements IMenuListener2, IRegistryChangeListene
 			}
 		}
 
-		addMenuContributions(mgr);
+		addMenuContributions();
 
 		readStaticActions();
 		// test for additions removed to comply with menu contributions
@@ -368,10 +370,8 @@ public class PopupMenuExtender implements IMenuListener2, IRegistryChangeListene
 
 	/**
 	 * well, this goes to the renderer.
-	 *
-	 * @param mgr
 	 */
-	private void addMenuContributions(IMenuManager mgr) {
+	private void addMenuContributions() {
 		IRendererFactory factory = modelPart.getContext().get(IRendererFactory.class);
 		AbstractPartRenderer obj = factory.getRenderer(menuModel, null);
 		if (obj instanceof MenuManagerRenderer) {
@@ -575,7 +575,7 @@ public class PopupMenuExtender implements IMenuListener2, IRegistryChangeListene
 				}
 
 				if (clearPopups) {
-					display.syncExec(() -> clearStaticActions());
+					display.syncExec(this::clearStaticActions);
 				}
 			}
 		}
