@@ -34,9 +34,6 @@ import org.eclipse.swt.SWT;
 import org.eclipse.swt.dnd.DropTargetListener;
 import org.eclipse.swt.dnd.Transfer;
 import org.eclipse.swt.graphics.Point;
-import org.eclipse.swt.widgets.Composite;
-import org.eclipse.swt.widgets.Control;
-import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.ui.IMemento;
 import org.eclipse.ui.IWorkbenchWindow;
@@ -103,7 +100,7 @@ public final class WorkbenchWindowConfigurer implements IWorkbenchWindowConfigur
 	/**
 	 * Table to hold arbitrary key-data settings (key type: <code>String</code>,
 	 * value type: <code>Object</code>).
-	 * 
+	 *
 	 * @see #setData
 	 */
 	private Map extraData = new HashMap(1);
@@ -318,16 +315,6 @@ public final class WorkbenchWindowConfigurer implements IWorkbenchWindowConfigur
 		// @issue need to be able to reconfigure after window's controls created
 	}
 
-	@Override
-	public boolean getShowFastViewBars() {
-		// not supported anymore
-		return false;
-	}
-
-	@Override
-	public void setShowFastViewBars(boolean show) {
-		// not supported anymore
-	}
 
 	@Override
 	public boolean getShowPerspectiveBar() {
@@ -462,26 +449,6 @@ public final class WorkbenchWindowConfigurer implements IWorkbenchWindowConfigur
 
 	}
 
-	@Override
-	public Menu createMenuBar() {
-		return null;
-	}
-
-	@Override
-	public Control createCoolBarControl(Composite parent) {
-
-		return null;
-	}
-
-	@Override
-	public Control createStatusLineControl(Composite parent) {
-		return null;
-	}
-
-	@Override
-	public Control createPageComposite(Composite parent) {
-		return null;
-	}
 
 	@Override
 	public IStatus saveState(IMemento memento) {
