@@ -27,8 +27,6 @@ public class ActivityMessages extends NLS {
 	public static String ActivityEnabler_categories;
 	public static String ActivityEnabler_selectAll;
 	public static String ActivityEnabler_deselectAll;
-	public static String ActivitiesPreferencePage_advancedDialogTitle;
-	public static String ActivitiesPreferencePage_advancedButton;
 	public static String ActivitiesPreferencePage_lockedMessage;
 	public static String ActivitiesPreferencePage_captionMessage;
 	public static String ActivitiesPreferencePage_requirements;
