@@ -70,7 +70,7 @@ public class DefaultWebBrowser extends AbstractWebBrowser {
 			Program.launch(localHref);
 		} else if (Util.isMac()) {
 			try {
-				Runtime.getRuntime().exec("/usr/bin/open " + localHref); //$NON-NLS-1$
+				Runtime.getRuntime().exec(new String[] { "/usr/bin/open", localHref }); //$NON-NLS-1$
 			} catch (IOException e) {
 				throw new PartInitException(WorkbenchMessages.ProductInfoDialog_unableToOpenWebBrowser, e);
 			}
@@ -85,7 +85,8 @@ public class DefaultWebBrowser extends AbstractWebBrowser {
 						 */
 						String encodedLocalHref = urlEncodeForSpaces(localHref.toCharArray());
 						if (webBrowserOpened) {
-							Runtime.getRuntime().exec(webBrowser + " -remote openURL(" + encodedLocalHref + ")"); //$NON-NLS-1$ //$NON-NLS-2$
+							Runtime.getRuntime()
+									.exec(new String[] { webBrowser, "-remote", "openURL(" + encodedLocalHref + ")" }); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 						} else {
 							Process p = openWebBrowser(encodedLocalHref);
 							webBrowserOpened = true;
@@ -137,7 +138,7 @@ public class DefaultWebBrowser extends AbstractWebBrowser {
 		if (webBrowser == null) {
 			try {
 				webBrowser = "firefox"; //$NON-NLS-1$
-				p = Runtime.getRuntime().exec(webBrowser + "  " + href); //$NON-NLS-1$ ;
+				p = Runtime.getRuntime().exec(new String[] { webBrowser, href });
 			} catch (IOException e) {
 				p = null;
 				webBrowser = "mozilla"; //$NON-NLS-1$
@@ -146,7 +147,7 @@ public class DefaultWebBrowser extends AbstractWebBrowser {
 
 		if (p == null) {
 			try {
-				p = Runtime.getRuntime().exec(webBrowser + " " + href); //$NON-NLS-1$ ;
+				p = Runtime.getRuntime().exec(new String[] { webBrowser, href });
 			} catch (IOException e) {
 				p = null;
 				webBrowser = "netscape"; //$NON-NLS-1$
@@ -155,7 +156,7 @@ public class DefaultWebBrowser extends AbstractWebBrowser {
 
 		if (p == null) {
 			try {
-				p = Runtime.getRuntime().exec(webBrowser + " " + href); //$NON-NLS-1$ ;
+				p = Runtime.getRuntime().exec(new String[] { webBrowser, href });
 			} catch (IOException e) {
 				p = null;
 				throw e;
