@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, 2015 IBM Corporation and others.
+ * Copyright (c) 2005, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -103,7 +103,7 @@ public class WorkbenchBrowserSupport extends AbstractWorkbenchBrowserSupport {
 	}
 
 	private IWorkbenchBrowserSupport getActiveSupport() {
-		if (initialized == false) {
+		if (!initialized) {
 			loadActiveSupport();
 		}
 		// ensure we always have an active instance
@@ -177,11 +177,9 @@ public class WorkbenchBrowserSupport extends AbstractWorkbenchBrowserSupport {
 							if (defaultElement == null) {
 								defaultElement = element;
 							}
-						} else {
-							// non-default
-							if (choice == null) {
-								choice = element;
-							}
+						} else // non-default
+						if (choice == null) {
+							choice = element;
 						}
 					}
 				}
