@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2018 IBM Corporation and others.
+ * Copyright (c) 2003, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -122,7 +122,7 @@ public abstract class FilteredPreferenceDialog extends PreferenceDialog implemen
 		 * @param filter    the PatternFilter to use for the TreeViewer
 		 */
 		PreferenceFilteredTree(Composite parent, int treeStyle, PatternFilter filter) {
-			super(parent, treeStyle, filter, true);
+			super(parent, treeStyle, filter, true, true);
 		}
 
 		/**
@@ -144,11 +144,6 @@ public abstract class FilteredPreferenceDialog extends PreferenceDialog implemen
 			getShell().setText(NLS.bind(WorkbenchMessages.FilteredTree_FilteredDialogTitle, cachedTitle));
 		}
 
-		@Override
-		protected void updateToolbar(boolean visible) {
-			super.updateToolbar(viewerFilter != null || visible);
-		}
-
 		@Override
 		protected void clearText() {
 			setFilterText(""); //$NON-NLS-1$
@@ -232,7 +227,7 @@ public abstract class FilteredPreferenceDialog extends PreferenceDialog implemen
 
 		tree.addFilter(new CapabilityFilter());
 
-		tree.addSelectionChangedListener(event -> handleTreeSelectionChanged(event));
+		tree.addSelectionChangedListener(this::handleTreeSelectionChanged);
 
 		super.addListeners(tree);
 		return tree;
@@ -478,7 +473,7 @@ public abstract class FilteredPreferenceDialog extends PreferenceDialog implemen
 					msg = WorkbenchMessages.FilteredPreferenceDialog_PreferenceSaveFailed;
 				}
 				StatusUtil.handleStatus(WorkbenchMessages.PreferencesExportDialog_ErrorDialogTitle + ": " + msg, e, //$NON-NLS-1$
-						StatusManager.SHOW, getShell());
+						StatusManager.SHOW);
 			}
 		}
 
@@ -698,10 +693,8 @@ public abstract class FilteredPreferenceDialog extends PreferenceDialog implemen
 		if (hasAtMostOnePage()) {
 			Composite composite = getTreeViewer().getTree();
 			applyDialogFont(composite, dialogFont);
-			composite.layout(true);
 		} else {
 			applyDialogFont(filteredTree, dialogFont);
-			filteredTree.layout(true);
 		}
 	}
 
