@@ -17,10 +17,15 @@
 package org.eclipse.ui.internal.e4.compatibility;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
+import java.util.function.Function;
+import java.util.function.Predicate;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.e4.ui.model.application.MApplication;
+import org.eclipse.e4.ui.model.application.commands.MBindingTable;
+import org.eclipse.e4.ui.model.application.commands.MKeyBinding;
 import org.eclipse.e4.ui.model.application.descriptor.basic.MPartDescriptor;
 import org.eclipse.e4.ui.model.application.ui.MElementContainer;
 import org.eclipse.e4.ui.model.application.ui.MUIElement;
@@ -35,6 +40,8 @@ import org.eclipse.e4.ui.model.application.ui.basic.MWindow;
 import org.eclipse.e4.ui.workbench.IPresentationEngine;
 import org.eclipse.e4.ui.workbench.modeling.EModelService;
 import org.eclipse.e4.ui.workbench.modeling.EPartService;
+import org.eclipse.jface.bindings.keys.KeySequence;
+import org.eclipse.jface.bindings.keys.ParseException;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.ui.IFolderLayout;
 import org.eclipse.ui.IPageLayout;
@@ -69,6 +76,11 @@ public class ModeledPageLayout implements IPageLayout {
 	public static final String HIDDEN_TOOLBAR_PREFIX = "persp.hideToolbarSC:"; //$NON-NLS-1$
 	public static final String HIDDEN_ACTIONSET_PREFIX = "persp.hideActionSetSC:"; //$NON-NLS-1$
 	public static final String HIDDEN_ITEMS_KEY = "persp.hiddenItems"; //$NON-NLS-1$
+	public static final String EDITOR_ONBOARDING = "persp.editorOnboarding"; //$NON-NLS-1$
+	public static final String EDITOR_ONBOARDING_TEXT = EDITOR_ONBOARDING + "Text:"; //$NON-NLS-1$
+	public static final String EDITOR_ONBOARDING_IMAGE = EDITOR_ONBOARDING + "ImageUri:"; //$NON-NLS-1$
+	public static final String EDITOR_ONBOARDING_COMMAND = EDITOR_ONBOARDING + "Command:"; //$NON-NLS-1$
+	public static final String EDITOR_ONBOARDING_COMMAND_SEPARATOR = "$$$"; //$NON-NLS-1$
 
 	public static List<String> getIds(MPerspective model, String tagPrefix) {
 		if (model == null) {
@@ -409,7 +421,7 @@ public class ModeledPageLayout implements IPageLayout {
 		if (viewModel != null) {
 			if (withStack) {
 				String stackId = viewId + "MStack"; // Default id...basically unusable //$NON-NLS-1$
-				MPartStack stack = insertStack(stackId, relationship, ratio, refId, visible & !isFiltered);
+				MPartStack stack = insertStack(stackId, relationship, ratio, refId, visible && !isFiltered);
 				stack.getChildren().add(viewModel);
 				retVal = stack;
 			} else {
@@ -536,8 +548,7 @@ public class ModeledPageLayout implements IPageLayout {
 		if (found.size() > 0)
 			return (MUIElement) found.get(0);
 
-		MUIElement foundElement = modelService.find(id, toSearch);
-		return foundElement;
+		return modelService.find(id, toSearch);
 	}
 
 	private MPart findPart(MUIElement toSearch, String id) {
@@ -616,4 +627,36 @@ public class ModeledPageLayout implements IPageLayout {
 		}
 	}
 
+	@Override
+	public void setEditorOnboardingText(String text) {
+		perspModel.getTags().add(EDITOR_ONBOARDING_TEXT + text);
+	}
+
+	@Override
+	public void setEditorOnboardingImageUri(String iconUri) {
+		perspModel.getTags().add(EDITOR_ONBOARDING_IMAGE + iconUri);
+	}
+
+	@Override
+	public void addEditorOnboardingCommandId(String commandId) {
+		long numberOfOnboardingCommands = perspModel.getTags().stream()
+				.filter(t -> t.startsWith(EDITOR_ONBOARDING_COMMAND)).count();
+		if (numberOfOnboardingCommands >= 5)
+			return;
+
+		Predicate<MKeyBinding> commandWithEqualId = b -> b.getCommand().getElementId().equals(commandId);
+		Function<MKeyBinding, String> toCommandText = b -> {
+			try {
+				return b.getCommand().getCommandName() + EDITOR_ONBOARDING_COMMAND_SEPARATOR
+						+ KeySequence.getInstance(b.getKeySequence()).format();
+			} catch (ParseException e) {
+				return b.getCommand().getCommandName() + EDITOR_ONBOARDING_COMMAND_SEPARATOR + b.getKeySequence();
+			}
+		};
+
+		application.getBindingTables().stream().map(MBindingTable::getBindings).flatMap(Collection::stream)
+				.filter(commandWithEqualId).findFirst().map(toCommandText)
+				.ifPresent(text -> perspModel.getTags().add(EDITOR_ONBOARDING_COMMAND + text));
+	}
+
 }
