@@ -70,15 +70,14 @@ public class CyclePageHandler extends FilteredTableBaseHandler {
 	protected Object getInput(WorkbenchPage page) {
 		List<FilteredTableItem> rows = new ArrayList<>();
 
-		for (int i = 0; i < pageSwitcher.getPages().length; i++) {
-			Object viewPage = pageSwitcher.getPages()[i];
+		for (Object viewPage : pageSwitcher.getPages()) {
 			FilteredTableItem item = new FilteredTableItem();
 			ImageDescriptor imageDescriptor = pageSwitcher.getImageDescriptor(viewPage);
 			if (imageDescriptor != null) {
 				if (lrm == null) {
 					lrm = new LocalResourceManager(JFaceResources.getResources());
 				}
-				item.setImage(lrm.createImage(imageDescriptor));
+				item.setImage(lrm.create(imageDescriptor));
 			}
 			item.putData(K_PAGE, viewPage);
 			String name = pageSwitcher.getName(viewPage);
@@ -100,16 +99,14 @@ public class CyclePageHandler extends FilteredTableBaseHandler {
 	protected ParameterizedCommand getBackwardCommand() {
 		final ICommandService commandService = window.getWorkbench().getService(ICommandService.class);
 		final Command command = commandService.getCommand(IWorkbenchCommandConstants.NAVIGATE_PREVIOUS_PAGE);
-		ParameterizedCommand commandF = new ParameterizedCommand(command, null);
-		return commandF;
+		return new ParameterizedCommand(command, null);
 	}
 
 	@Override
 	protected ParameterizedCommand getForwardCommand() {
 		final ICommandService commandService = window.getWorkbench().getService(ICommandService.class);
 		final Command command = commandService.getCommand(IWorkbenchCommandConstants.NAVIGATE_NEXT_PAGE);
-		ParameterizedCommand commandF = new ParameterizedCommand(command, null);
-		return commandF;
+		return new ParameterizedCommand(command, null);
 	}
 
 	@Override
