@@ -34,6 +34,7 @@ import org.eclipse.core.commands.NotEnabledException;
 import org.eclipse.core.commands.NotHandledException;
 import org.eclipse.core.commands.ParameterizedCommand;
 import org.eclipse.core.commands.common.NotDefinedException;
+import org.eclipse.core.expressions.AndExpression;
 import org.eclipse.core.expressions.ElementHandler;
 import org.eclipse.core.expressions.EvaluationContext;
 import org.eclipse.core.expressions.Expression;
@@ -64,7 +65,6 @@ import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.handlers.IHandlerActivation;
 import org.eclipse.ui.handlers.IHandlerService;
 import org.eclipse.ui.internal.WorkbenchPlugin;
-import org.eclipse.ui.internal.expressions.AndExpression;
 import org.eclipse.ui.internal.expressions.WorkbenchWindowExpression;
 import org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants;
 import org.eclipse.ui.internal.services.EvaluationService;
@@ -291,7 +291,7 @@ public class LegacyHandlerService implements IHandlerService {
 
 	@Override
 	public IHandlerActivation activateHandler(String commandId, IHandler handler) {
-		return activateHandler(commandId, handler, defaultExpression, false);
+		return activateHandler(commandId, handler, null, false);
 	}
 
 	@Override
@@ -326,15 +326,13 @@ public class LegacyHandlerService implements IHandlerService {
 	@Override
 	public ExecutionEvent createExecutionEvent(Command command, Event event) {
 		EvaluationContext legacy = new EvaluationContext(evalContext, evalContext.getDefaultVariable());
-		ExecutionEvent e = new ExecutionEvent(command, Collections.EMPTY_MAP, event, legacy);
-		return e;
+		return new ExecutionEvent(command, Collections.EMPTY_MAP, event, legacy);
 	}
 
 	@Override
 	public ExecutionEvent createExecutionEvent(ParameterizedCommand command, Event event) {
 		EvaluationContext legacy = new EvaluationContext(evalContext, evalContext.getDefaultVariable());
-		ExecutionEvent e = new ExecutionEvent(command.getCommand(), command.getParameterMap(), event, legacy);
-		return e;
+		return new ExecutionEvent(command.getCommand(), command.getParameterMap(), event, legacy);
 	}
 
 	@Override
@@ -349,14 +347,13 @@ public class LegacyHandlerService implements IHandlerService {
 
 	@Override
 	public void deactivateHandlers(Collection activations) {
-		Object[] array = activations.toArray();
 		// set all activations to not be participating first so that they ignore
 		// the upcoming context change events
-		for (int i = 0; i < array.length; i++) {
-			((HandlerActivation) array[i]).participating = false;
+		for (Object activation : activations) {
+			((HandlerActivation) activation).participating = false;
 		}
 
-		for (Object element : array) {
+		for (Object element : activations) {
 			deactivateHandler((IHandlerActivation) element);
 		}
 	}
@@ -491,9 +488,7 @@ public class LegacyHandlerService implements IHandlerService {
 		if (vars != null) {
 			try {
 				return (Map<?, ?>) vars.get(ctx);
-			} catch (IllegalArgumentException e) {
-
-			} catch (IllegalAccessException e) {
+			} catch (IllegalArgumentException | IllegalAccessException e) {
 
 			}
 		}
@@ -507,9 +502,7 @@ public class LegacyHandlerService implements IHandlerService {
 			try {
 				contextFVariables = EvaluationContext.class.getField("fVariables"); //$NON-NLS-1$
 				contextFVariables.setAccessible(true);
-			} catch (SecurityException e) {
-
-			} catch (NoSuchFieldException e) {
+			} catch (SecurityException | NoSuchFieldException e) {
 
 			}
 		}
@@ -592,7 +585,7 @@ public class LegacyHandlerService implements IHandlerService {
 		IConfigurationElement[] elements = extPoint.getConfigurationElements();
 		for (IConfigurationElement configElement : elements) {
 			String commandId = configElement.getAttribute(IWorkbenchRegistryConstants.ATT_COMMAND_ID);
-			if (commandId == null || commandId.length() == 0) {
+			if (commandId == null || commandId.isEmpty()) {
 				continue;
 			}
 			String defaultHandler = configElement.getAttribute(IWorkbenchRegistryConstants.ATT_CLASS);
@@ -657,7 +650,7 @@ public class LegacyHandlerService implements IHandlerService {
 		IConfigurationElement[] elements = extPoint.getConfigurationElements();
 		for (IConfigurationElement configElement : elements) {
 			String id = configElement.getAttribute(IWorkbenchRegistryConstants.ATT_ID);
-			if (id == null || id.length() == 0) {
+			if (id == null || id.isEmpty()) {
 				continue;
 			}
 			String defaultHandler = configElement.getAttribute(IWorkbenchRegistryConstants.ATT_DEFAULT_HANDLER);
