@@ -1,12 +1,12 @@
 /*******************************************************************************
  * Copyright (c) 2017 Patrik Suzzi.
  *
- * This program
- * and the accompanying materials are made available under the terms of the
- * Eclipse Public License 2.0 which accompanies this distribution, and is
-t https://www.eclipse.org/legal/epl-2.0/
-t
-t SPDX-License-Identifier: EPL-2.0
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
+ * which accompanies this distribution, and is available at
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  * 	Patrik Suzzi <psuzzi@gmail.com> - initial API and implementation;
@@ -32,7 +32,6 @@ import org.eclipse.ui.internal.WorkbenchWindow;
 import org.eclipse.ui.internal.services.IWorkbenchLocationService;
 import org.eclipse.ui.menus.UIElement;
 import org.eclipse.ui.services.IServiceScopes;
-import org.osgi.service.event.Event;
 import org.osgi.service.event.EventHandler;
 
 /**
@@ -75,18 +74,15 @@ public class ToggleStatusBarHandler extends AbstractHandler implements IElementU
 	private void initializeEventHandler(IWorkbenchWindow window) {
 		final IEventBroker eventBroker = window.getService(IEventBroker.class);
 		eventBrokers.put(window, eventBroker);
-		EventHandler eventHandler = new EventHandler() {
-			@Override
-			public void handleEvent(Event event) {
-				Object element = event.getProperty(UIEvents.EventTags.ELEMENT);
-				// if the current-window trim is the event element
-				if (element != null && element == getTrimStatus((WorkbenchWindow) window)) {
-					// refresh menu item label, triggering updateElement()
-					ICommandService commandService = window.getService(ICommandService.class);
-					Map<String, WorkbenchWindow> filter = new HashMap<>();
-					filter.put(IServiceScopes.WINDOW_SCOPE, (WorkbenchWindow) window);
-					commandService.refreshElements(COMMAND_ID_TOGGLE_STATUSBAR, filter);
-				}
+		EventHandler eventHandler = event -> {
+			Object element = event.getProperty(UIEvents.EventTags.ELEMENT);
+			// if the current-window trim is the event element
+			if (element != null && element == getTrimStatus((WorkbenchWindow) window)) {
+				// refresh menu item label, triggering updateElement()
+				ICommandService commandService = window.getService(ICommandService.class);
+				Map<String, WorkbenchWindow> filter = new HashMap<>();
+				filter.put(IServiceScopes.WINDOW_SCOPE, (WorkbenchWindow) window);
+				commandService.refreshElements(COMMAND_ID_TOGGLE_STATUSBAR, filter);
 			}
 		};
 		eventHandlers.put(window, eventHandler);
