@@ -163,8 +163,7 @@ public final class BindingService implements IBindingService {
 
 	@Override
 	public TriggerSequence getBestActiveBindingFor(ParameterizedCommand command) {
-		TriggerSequence seq = bindingService.getBestSequenceFor(command);
-		return seq;
+		return bindingService.getBestSequenceFor(command);
 	}
 
 	@Override
@@ -421,7 +420,7 @@ public final class BindingService implements IBindingService {
 	 *
 	 * @param current  the existing binding
 	 * @param addition the incoming binding
-	 * @return an int indicating current > addition
+	 * @return an int indicating current &gt; addition
 	 */
 	private int compareTo(Binding current, Binding addition) {
 		final Scheme s1 = manager.getScheme(current.getSchemeId());
@@ -516,7 +515,7 @@ public final class BindingService implements IBindingService {
 	 */
 	public void addBinding(final Binding binding) {
 		MBindingTable table = getMTable(binding.getContextId());
-		createORupdateMKeyBinding(application, table, binding);
+		createOrUpdateMKeyBinding(application, table, binding);
 	}
 
 	/**
@@ -582,7 +581,7 @@ public final class BindingService implements IBindingService {
 	// Add some sort of timestamp on the source files and update
 	// only when it changes
 	// TBD placement: this should be in the "3.x bridge" code
-	static public MKeyBinding createORupdateMKeyBinding(MApplication application, MBindingTable table,
+	static public MKeyBinding createOrUpdateMKeyBinding(MApplication application, MBindingTable table,
 			Binding binding) {
 		boolean addToTable = false;
 
