@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2016 IBM Corporation and others.
+ * Copyright (c) 2010, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -117,9 +117,8 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 	@Override
 	public void addContributionFactory(final AbstractContributionFactory factory) {
 		MenuLocationURI location = new MenuLocationURI(factory.getLocation());
-		if (location.getPath() == null || location.getPath().length() == 0) {
-			WorkbenchPlugin
-					.log("WorkbenchMenuService.addContributionFactory: Invalid menu URI: " + location); //$NON-NLS-1$
+		if (location.getPath() == null || location.getPath().isEmpty()) {
+			WorkbenchPlugin.log("WorkbenchMenuService.addContributionFactory: Invalid menu URI: " + location); //$NON-NLS-1$
 			return;
 		}
 
@@ -129,7 +128,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 				// configElement);
 			} else {
 				String query = location.getQuery();
-				if (query == null || query.length() == 0) {
+				if (query == null || query.isEmpty()) {
 					query = "after=additions"; //$NON-NLS-1$
 				}
 				processToolbarChildren(factory, location, location.getPath(), query);
@@ -137,6 +136,8 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 			return;
 		}
 		MMenuContribution menuContribution = MenuFactoryImpl.eINSTANCE.createMenuContribution();
+		menuContribution.getPersistedState().put(org.eclipse.e4.ui.workbench.IWorkbench.PERSIST_STATE,
+				Boolean.FALSE.toString());
 		menuContribution.setElementId(factory.getNamespace() + ":" + factory.hashCode()); //$NON-NLS-1$
 
 		if ("org.eclipse.ui.popup.any".equals(location.getPath())) { //$NON-NLS-1$
@@ -145,7 +146,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 			menuContribution.setParentId(location.getPath());
 		}
 		String query = location.getQuery();
-		if (query == null || query.length() == 0) {
+		if (query == null || query.isEmpty()) {
 			query = "after=additions"; //$NON-NLS-1$
 		}
 		menuContribution.setPositionInParent(query);
@@ -163,10 +164,11 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 
 	}
 
-	private void processToolbarChildren(AbstractContributionFactory factory,
-			MenuLocationURI location, String parentId, String position) {
-		MToolBarContribution toolBarContribution = MenuFactoryImpl.eINSTANCE
-				.createToolBarContribution();
+	private void processToolbarChildren(AbstractContributionFactory factory, MenuLocationURI location, String parentId,
+			String position) {
+		MToolBarContribution toolBarContribution = MenuFactoryImpl.eINSTANCE.createToolBarContribution();
+		toolBarContribution.getPersistedState().put(org.eclipse.e4.ui.workbench.IWorkbench.PERSIST_STATE,
+				Boolean.FALSE.toString());
 		toolBarContribution.setElementId(factory.getNamespace() + ":" + factory.hashCode()); //$NON-NLS-1$
 		toolBarContribution.setParentId(parentId);
 		toolBarContribution.setPositionInParent(position);
@@ -229,8 +231,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 		populateContributionManager(model, mgr, location);
 	}
 
-	public void populateContributionManager(MApplicationElement model, ContributionManager mgr,
-			String location) {
+	public void populateContributionManager(MApplicationElement model, ContributionManager mgr, String location) {
 		MenuLocationURI uri = new MenuLocationURI(location);
 
 		// Now handle registering dynamic additions by querying E4 model
@@ -247,8 +248,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 				MenuManagerRenderer renderer = (MenuManagerRenderer) obj;
 				mMenu.setRenderer(renderer);
 				renderer.reconcileManagerToModel(menu, mMenu);
-				renderer.processContributions(mMenu, uri.getPath(), false,
-						"popup".equals(uri.getScheme())); //$NON-NLS-1$
+				renderer.processContributions(mMenu, uri.getPath(), false, "popup".equals(uri.getScheme())); //$NON-NLS-1$
 				// double cast because we're bad people
 				renderer.processContents((MElementContainer<MUIElement>) ((Object) mMenu));
 				final IEclipseContext evalContext;
@@ -257,8 +257,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 				} else {
 					evalContext = modelService.getContainingContext(mMenu);
 				}
-				MenuManagerRendererFilter.updateElementVisibility(mMenu, renderer, menu,
-						evalContext, 2, true);
+				MenuManagerRendererFilter.updateElementVisibility(mMenu, renderer, menu, evalContext, 2, true);
 			}
 		} else if (mgr instanceof ToolBarManager) {
 			ToolBarManager toolbar = (ToolBarManager) mgr;
@@ -285,8 +284,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 	protected MToolBar getToolbarModel(MApplicationElement model, ToolBarManager toolbarManager,
 			MenuLocationURI location) {
 		final IRendererFactory factory = e4Context.get(IRendererFactory.class);
-		final AbstractPartRenderer obj = factory.getRenderer(
-				MenuFactoryImpl.eINSTANCE.createToolBar(), null);
+		final AbstractPartRenderer obj = factory.getRenderer(MenuFactoryImpl.eINSTANCE.createToolBar(), null);
 		if (!(obj instanceof ToolBarManagerRenderer)) {
 			return null;
 		}
@@ -315,8 +313,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 	}
 
 	private void addToolbar(MApplicationElement model, MToolBar tb, IEclipseContext ctx) {
-		ArrayList<MToolBar> toolbars = (ArrayList<MToolBar>) model.getTransientData().get(
-				POPULATED_TOOL_BARS);
+		ArrayList<MToolBar> toolbars = (ArrayList<MToolBar>) model.getTransientData().get(POPULATED_TOOL_BARS);
 		if (toolbars == null) {
 			toolbars = new ArrayList<>();
 			model.getTransientData().put(POPULATED_TOOL_BARS, toolbars);
@@ -343,12 +340,11 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 		((Notifier) menu).eAdapters().add(ctx.get(UIEventPublisher.class));
 	}
 
-	protected MMenu getMenuModel(MApplicationElement model, MenuManager menuManager,
-			MenuLocationURI location) {
+	protected MMenu getMenuModel(MApplicationElement model, MenuManager menuManager, MenuLocationURI location) {
 
 		final IRendererFactory factory = e4Context.get(IRendererFactory.class);
-		final AbstractPartRenderer obj = factory.getRenderer(((WorkbenchWindow) getWindow())
-				.getModel().getMainMenu(), null);
+		final AbstractPartRenderer obj = factory.getRenderer(((WorkbenchWindow) getWindow()).getModel().getMainMenu(),
+				null);
 		if (!(obj instanceof MenuManagerRenderer)) {
 			return null;
 		}
@@ -391,7 +387,6 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 		return mMenu;
 	}
 
-
 	private MPart getPartToExtend() {
 		return (MPart) e4Context.getActiveLeaf().get(IServiceConstants.ACTIVE_PART);
 	}
@@ -414,8 +409,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 	 */
 	private void releaseContributionManager(ToolBarManager toolbarManager) {
 		final IRendererFactory factory = e4Context.get(IRendererFactory.class);
-		final AbstractPartRenderer obj = factory.getRenderer(
-				MenuFactoryImpl.eINSTANCE.createToolBar(), null);
+		final AbstractPartRenderer obj = factory.getRenderer(MenuFactoryImpl.eINSTANCE.createToolBar(), null);
 		if (!(obj instanceof ToolBarManagerRenderer)) {
 			return;
 		}
@@ -424,19 +418,16 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 		if (mToolBar == null) {
 			return;
 		}
-		MApplicationElement model = (MApplicationElement) mToolBar.getTransientData().get(
-				ModelUtils.CONTAINING_PARENT);
+		MApplicationElement model = (MApplicationElement) mToolBar.getTransientData().get(ModelUtils.CONTAINING_PARENT);
 		if (model != null) {
 			((Notifier) mToolBar).eAdapters().clear();
-			ArrayList<MToolBar> toolbars = (ArrayList<MToolBar>) model.getTransientData().get(
-					POPULATED_TOOL_BARS);
+			ArrayList<MToolBar> toolbars = (ArrayList<MToolBar>) model.getTransientData().get(POPULATED_TOOL_BARS);
 			if (toolbars != null) {
 				toolbars.remove(mToolBar);
 			}
 		}
 		final ToolBar widget = toolbarManager.getControl();
-		if (widget != null && !widget.isDisposed()
-				&& widget.getData(AbstractPartRenderer.OWNING_ME) == null) {
+		if (widget != null && !widget.isDisposed() && widget.getData(AbstractPartRenderer.OWNING_ME) == null) {
 			widget.setData(AbstractPartRenderer.OWNING_ME, mToolBar);
 		}
 		final IPresentationEngine engine = e4Context.get(IPresentationEngine.class);
@@ -449,8 +440,8 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 	 */
 	private void releaseContributionManager(MenuManager menuManager) {
 		final IRendererFactory factory = e4Context.get(IRendererFactory.class);
-		final AbstractPartRenderer obj = factory.getRenderer(((WorkbenchWindow) getWindow())
-				.getModel().getMainMenu(), null);
+		final AbstractPartRenderer obj = factory.getRenderer(((WorkbenchWindow) getWindow()).getModel().getMainMenu(),
+				null);
 		if (!(obj instanceof MenuManagerRenderer)) {
 			return;
 		}
@@ -459,19 +450,16 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 		if (mMenu == null) {
 			return;
 		}
-		MApplicationElement model = (MApplicationElement) mMenu.getTransientData().get(
-				ModelUtils.CONTAINING_PARENT);
+		MApplicationElement model = (MApplicationElement) mMenu.getTransientData().get(ModelUtils.CONTAINING_PARENT);
 		if (model != null) {
 			((Notifier) mMenu).eAdapters().clear();
-			ArrayList<MMenu> menus = (ArrayList<MMenu>) model.getTransientData().get(
-					POPULATED_MENUS);
+			ArrayList<MMenu> menus = (ArrayList<MMenu>) model.getTransientData().get(POPULATED_MENUS);
 			if (menus != null) {
 				menus.remove(mMenu);
 			}
 		}
 		final Menu widget = menuManager.getMenu();
-		if (widget != null && !widget.isDisposed()
-				&& widget.getData(AbstractPartRenderer.OWNING_ME) == null) {
+		if (widget != null && !widget.isDisposed() && widget.getData(AbstractPartRenderer.OWNING_ME) == null) {
 			widget.setData(AbstractPartRenderer.OWNING_ME, mMenu);
 		}
 		final IPresentationEngine engine = e4Context.get(IPresentationEngine.class);
@@ -542,8 +530,7 @@ public class WorkbenchMenuService implements IMenuService, IMenuServiceWorkaroun
 	}
 
 	/**
-	 * read in the menu contributions and turn them into model menu
-	 * contributions
+	 * read in the menu contributions and turn them into model menu contributions
 	 */
 	public void readRegistry() {
 		persistence.read();
