@@ -129,10 +129,10 @@ public class QuickAccessEntry {
 		if (imageDescriptor == null) {
 			return null;
 		}
-		Image image = (Image) resourceManager.find(imageDescriptor);
+		Image image = resourceManager.find(imageDescriptor);
 		if (image == null) {
 			try {
-				image = resourceManager.createImage(imageDescriptor);
+				image = resourceManager.create(imageDescriptor);
 			} catch (DeviceResourceException e) {
 				WorkbenchPlugin.log(e);
 			}
