@@ -184,6 +184,17 @@ public interface IWorkbenchRegistryConstants {
 	 */
 	String ATT_EDITOR_ID = "editorId"; //$NON-NLS-1$
 
+
+	/**
+	 * Editor onboarding image attribute. Value <code>editorOnboardingImage</code>.
+	 */
+	String ATT_EDITOR_ONBOARDING_IMAGE = "editorOnboardingImage"; //$NON-NLS-1$
+
+	/**
+	 * Editor onboarding text attribute. Value <code>editorOnboardingText</code>.
+	 */
+	String ATT_EDITOR_ONBOARDING_TEXT = "editorOnboardingText"; //$NON-NLS-1$
+
 	/**
 	 * Enables-for attribute. Value <code>enablesFor</code>.
 	 */
@@ -523,6 +534,11 @@ public interface IWorkbenchRegistryConstants {
 	 */
 	String ATT_TARGET_ID = "targetID";//$NON-NLS-1$
 
+	/**
+	 * Text attribute. Value <code>text</code>.
+	 */
+	String ATT_TEXT = "text"; //$NON-NLS-1$
+
 	/**
 	 * Toolbar path attribute. Value <code>toolbarPath</code>.
 	 */
@@ -567,6 +583,11 @@ public interface IWorkbenchRegistryConstants {
 	 */
 	String AUTOGENERATED_PREFIX = "AUTOGEN:::"; //$NON-NLS-1$
 
+	/**
+	 * The empty editor command id element. Value <code>emptyEditorCommandId</code>.
+	 */
+	String ELEM_EMPTY_EDITOR_COMMAND_ID = "emptyEditorCommandId"; //$NON-NLS-1$
+
 	/**
 	 * The legacy extension point (2.1.x and earlier) for specifying a key binding
 	 * scheme.
@@ -997,6 +1018,11 @@ public interface IWorkbenchRegistryConstants {
 	 */
 	String TAG_EDITOR_CONTRIBUTION = "editorContribution"; //$NON-NLS-1$
 
+	/**
+	 * Editor onboarding command. Value <code>editorOnboardingCommand</code>.
+	 */
+	String TAG_EDITOR_ONBOARDING_COMMAND = "editorOnboardingCommand"; //$NON-NLS-1$
+
 	/**
 	 * The name of the enabled when element, which appears on a handler definition.
 	 */
@@ -1358,4 +1384,11 @@ public interface IWorkbenchRegistryConstants {
 	String ATT_COLOR_AND_FONT_ID = "colorAndFontId"; //$NON-NLS-1$
 
 	String ATT_OS_VERSION = "os_version"; //$NON-NLS-1$
+
+	/**
+	 * See {@link PerspectiveDescriptor#getDefaultShowIn()}
+	 *
+	 * @since 3.123
+	 */
+	String ATT_DEFAULT_SHOW_IN = "defaultShowIn"; //$NON-NLS-1$
 }
