@@ -175,8 +175,8 @@ public class PerspectiveRegistry implements IPerspectiveRegistry, IExtensionChan
 	 * @param perspToDelete
 	 */
 	public void deletePerspectives(ArrayList<IPerspectiveDescriptor> perspToDelete) {
-		for (int i = 0; i < perspToDelete.size(); i++) {
-			deletePerspective(perspToDelete.get(i));
+		for (IPerspectiveDescriptor descriptor : perspToDelete) {
+			deletePerspective(descriptor);
 		}
 	}
 
@@ -212,7 +212,7 @@ public class PerspectiveRegistry implements IPerspectiveRegistry, IExtensionChan
 				.getString(IWorkbenchPreferenceConstants.DEFAULT_PERSPECTIVE_ID);
 		// empty string may be returned but we want to return null if nothing
 		// found
-		if (defaultId.length() == 0 || findPerspectiveWithId(defaultId) == null) {
+		if (defaultId.isEmpty() || findPerspectiveWithId(defaultId) == null) {
 			Workbench instance = Workbench.getInstance();
 			return instance == null ? null : instance.getDefaultPerspectiveId();
 		}
@@ -271,9 +271,6 @@ public class PerspectiveRegistry implements IPerspectiveRegistry, IExtensionChan
 			impExpHandlerContext.dispose();
 		}
 		PlatformUI.getWorkbench().getExtensionTracker().unregisterHandler(this);
-		// FIXME: what was this listener for?
-		// WorkbenchPlugin.getDefault().getPreferenceStore().removePropertyChangeListener(
-		// preferenceListener);
 	}
 
 	@Override
@@ -305,7 +302,7 @@ public class PerspectiveRegistry implements IPerspectiveRegistry, IExtensionChan
 	/**
 	 * Return an id for the new descriptor.
 	 *
-	 * The id must encode the original id. id is of the form <originalId>.label
+	 * The id must encode the original id. id is of the form &lt;originalId&gt;.label
 	 *
 	 * @param label
 	 * @param originalDescriptor
