@@ -19,7 +19,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
 import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.Path;
 import org.eclipse.ui.activities.WorkbenchActivityHelper;
 import org.eclipse.ui.views.IViewCategory;
 import org.eclipse.ui.views.IViewDescriptor;
@@ -34,7 +33,7 @@ public class ViewCategory implements IViewCategory {
 	public ViewCategory(String id, String label) {
 		this.id = id;
 		this.label = label;
-		this.path = new Path(id);
+		this.path = IPath.fromOSString(id);
 	}
 
 	void addDescriptor(IViewDescriptor descriptor) {
