@@ -21,7 +21,7 @@ package org.eclipse.ui.internal.themes;
 import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 import static org.eclipse.ui.internal.themes.WorkbenchThemeManager.EMPTY_COLOR_VALUE;
 
-import com.ibm.icu.text.MessageFormat;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -139,7 +139,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		public Object[] getChildren(Object parentElement) {
 			if (parentElement instanceof ThemeElementCategory) {
 				String categoryId = ((ThemeElementCategory) parentElement).getId();
-				Object[] defintions = (Object[]) categoryMap.get(categoryId);
+				Object[] defintions = categoryMap.get(categoryId);
 				if (defintions == null) {
 					defintions = getCategoryChildren(categoryId);
 					categoryMap.put(categoryId, defintions);
@@ -147,7 +147,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 				return defintions;
 			}
 
-			ArrayList list = new ArrayList();
+			ArrayList<IHierarchalThemeElementDefinition> list = new ArrayList<>();
 			IHierarchalThemeElementDefinition def = (IHierarchalThemeElementDefinition) parentElement;
 			String id = def.getId();
 			IHierarchalThemeElementDefinition[] defs;
@@ -168,49 +168,44 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		}
 
 		private Object[] getCategoryChildren(String categoryId) {
-			ArrayList list = new ArrayList();
+			ArrayList<IThemeElementDefinition> list = new ArrayList<>();
 
 			if (categoryId != null) {
 				for (ThemeElementCategory category : registry.getCategories()) {
 					if (categoryId.equals(category.getParentId())) {
-						Set bindings = themeRegistry.getPresentationsBindingsFor(category);
+						Set<?> bindings = themeRegistry.getPresentationsBindingsFor(category);
 						if (bindings == null) {
 							list.add(category);
 						}
 					}
 				}
 			}
-			{
-				ColorDefinition[] colorDefinitions = themeRegistry.getColorsFor(currentTheme.getId());
-				for (int i = 0; i < colorDefinitions.length; i++) {
-					if (!colorDefinitions[i].isEditable()) {
+			ColorDefinition[] colorDefinitions = themeRegistry.getColorsFor(currentTheme.getId());
+			for (ColorDefinition colorDefinition : colorDefinitions) {
+				if (!colorDefinition.isEditable()) {
+					continue;
+				}
+				String catId = colorDefinition.getCategoryId();
+				if ((catId == null && categoryId == null)
+						|| (catId != null && categoryId != null && categoryId.equals(catId))) {
+					if (colorDefinition.getDefaultsTo() != null && parentIsInSameCategory(colorDefinition)) {
 						continue;
 					}
-					String catId = colorDefinitions[i].getCategoryId();
-					if ((catId == null && categoryId == null)
-							|| (catId != null && categoryId != null && categoryId.equals(catId))) {
-						if (colorDefinitions[i].getDefaultsTo() != null
-								&& parentIsInSameCategory(colorDefinitions[i])) {
-							continue;
-						}
-						list.add(colorDefinitions[i]);
-					}
+					list.add(colorDefinition);
 				}
 			}
-			{
-				FontDefinition[] fontDefinitions = themeRegistry.getFontsFor(currentTheme.getId());
-				for (int i = 0; i < fontDefinitions.length; i++) {
-					if (!fontDefinitions[i].isEditable()) {
+			FontDefinition[] fontDefinitions = themeRegistry.getFontsFor(currentTheme.getId());
+			for (FontDefinition fontDefinition : fontDefinitions) {
+				if (!fontDefinition.isEditable()) {
+					continue;
+				}
+				String catId = fontDefinition.getCategoryId();
+				if ((catId == null && categoryId == null)
+						|| (catId != null && categoryId != null && categoryId.equals(catId))) {
+					if (fontDefinition.getDefaultsTo() != null && parentIsInSameCategory(fontDefinition)) {
 						continue;
 					}
-					String catId = fontDefinitions[i].getCategoryId();
-					if ((catId == null && categoryId == null)
-							|| (catId != null && categoryId != null && categoryId.equals(catId))) {
-						if (fontDefinitions[i].getDefaultsTo() != null && parentIsInSameCategory(fontDefinitions[i])) {
-							continue;
-						}
-						list.add(fontDefinitions[i]);
-					}
+					list.add(fontDefinition);
 				}
 			}
 			return list.toArray(new Object[list.size()]);
@@ -296,12 +291,12 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 		@Override
 		public Object[] getElements(Object inputElement) {
-			ArrayList list = new ArrayList();
+			ArrayList<Object> list = new ArrayList<>();
 			Object[] uncatChildren = getCategoryChildren(null);
 			list.addAll(Arrays.asList(uncatChildren));
 			for (ThemeElementCategory category : ((IThemeRegistry) inputElement).getCategories()) {
 				if (category.getParentId() == null) {
-					Set bindings = themeRegistry.getPresentationsBindingsFor(category);
+					Set<?> bindings = themeRegistry.getPresentationsBindingsFor(category);
 					if (bindings == null) {
 						Object[] children = getChildren(category);
 						if (children != null && children.length > 0) {
@@ -328,9 +323,9 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	private class PresentationLabelProvider extends LabelProvider implements IFontProvider, IColorProvider {
 
-		private HashMap fonts = new HashMap();
+		private HashMap<Font, Font> fonts = new HashMap<>();
 
-		private HashMap images = new HashMap();
+		private HashMap<Color, Image> images = new HashMap<>();
 
 		private int imageSize = -1;
 
@@ -365,8 +360,8 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			super.dispose();
 			colorRegistry.removeListener(listener);
 			fontRegistry.removeListener(listener);
-			for (Iterator i = images.values().iterator(); i.hasNext();) {
-				((Image) i.next()).dispose();
+			for (Image image : images.values()) {
+				image.dispose();
 			}
 			images.clear();
 
@@ -383,8 +378,8 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		 * Clears and disposes all fonts.
 		 */
 		public void clearFontCache() {
-			for (Iterator i = fonts.values().iterator(); i.hasNext();) {
-				((Font) i.next()).dispose();
+			for (Font font : fonts.values()) {
+				font.dispose();
 			}
 			fonts.clear();
 		}
@@ -403,7 +398,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			if (element instanceof FontDefinition) {
 				int parentHeight = tree.getViewer().getControl().getFont().getFontData()[0].getHeight();
 				Font baseFont = fontRegistry.get(((FontDefinition) element).getId());
-				Font font = (Font) fonts.get(baseFont);
+				Font font = fonts.get(baseFont);
 				if (font == null) {
 					FontData[] data = baseFont.getFontData();
 					for (FontData fontData : data) {
@@ -428,7 +423,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 					c = display.getSystemColor(SWT.COLOR_WHITE);
 					foregroundColor = display.getSystemColor(DEFINITION_NOT_AVAIL_COLOR);
 				}
-				Image image = (Image) images.get(c);
+				Image image = images.get(c);
 				if (image == null) {
 					ensureImageSize();
 					image = new Image(display, imageSize, imageSize);
@@ -546,12 +541,12 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	/**
 	 * Map to precalculate category color lists.
 	 */
-	private Map categoryMap = new HashMap(7);
+	private Map<String, Object[]> categoryMap = new HashMap<>(7);
 
 	private Font appliedDialogFont;
 
 	/**
-	 * Map of definition ColorDefinition->RGB capturing the explicit changes made by
+	 * Map of definition ColorDefinition-&gt;RGB capturing the explicit changes made by
 	 * the user. These changes need to be stored into the preference store.
 	 */
 	private Map<ColorDefinition, RGB> colorPreferencesToSet = new HashMap<>(7);
@@ -559,10 +554,10 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	private CascadingColorRegistry colorRegistry;
 
 	/**
-	 * Map of definition id->RGB capturing the temporary changes caused by a
+	 * Map of definition id-&gt;RGB capturing the temporary changes caused by a
 	 * 'defaultsTo' color change.
 	 */
-	private Map colorValuesToSet = new HashMap(7);
+	private Map<String, RGB> colorValuesToSet = new HashMap<>(7);
 
 	/**
 	 * The default color preview composite.
@@ -601,7 +596,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	private String fontSampleText;
 
-	private List dialogFontWidgets = new ArrayList();
+	private List<Control> dialogFontWidgets = new ArrayList<>();
 
 	private Button fontChangeButton;
 
@@ -627,7 +622,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	private Button expandAllButton;
 
 	/**
-	 * Map of definition FontDefinition->FontData[] capturing the changes explicitly
+	 * Map of definition FontDefinition-&gt;FontData[] capturing the changes explicitly
 	 * made by the user. These changes need to be stored into the preference store.
 	 */
 	private Map<FontDefinition, FontData[]> fontPreferencesToSet = new HashMap<>(7);
@@ -639,7 +634,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	private Button fontSystemButton;
 
 	/**
-	 * Map of definition id->FontData[] capturing the temporary changes caused by a
+	 * Map of definition id-&gt;FontData[] capturing the temporary changes caused by a
 	 * 'defaultsTo' font change.
 	 *
 	 * @deprecated in this page, we should only care about preferences, preference
@@ -647,7 +642,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	 *             ThemeAPI and listeners
 	 */
 	@Deprecated
-	private Map fontValuesToSet = new HashMap(7);
+	private Map<String, FontData[]> fontValuesToSet = new HashMap<>(7);
 
 	/**
 	 * The composite that is parent to all previews.
@@ -655,14 +650,14 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	private Composite previewComposite;
 
 	/**
-	 * A mapping from PresentationCategory->Composite for the created previews.
+	 * A mapping from PresentationCategory-&gt;Composite for the created previews.
 	 */
-	private Map previewMap = new HashMap(7);
+	private Map<ThemeElementCategory, Composite> previewMap = new HashMap<>(7);
 
 	/**
 	 * Set containing all IPresentationPreviews created.
 	 */
-	private Set previewSet = new HashSet(7);
+	private Set<IThemePreview> previewSet = new HashSet<>(7);
 
 	/**
 	 * The layout for the previewComposite.
@@ -723,13 +718,14 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	 * {@inheritDoc}
 	 * <p>
 	 * Everything else except the following string patterns is ignored:
+	 * </p>
 	 * <ul>
 	 * <li><strong>selectCategory:</strong>ID - selects and expands the category
 	 * with the given ID</li>
 	 * <li><strong>selectFont:</strong>ID - selects the font with the given ID</li>
-	 * <li><strong>selectColor:</strong>ID - selects the color with the given ID
-	 * </li>
-	 * </p>
+	 * <li><strong>selectColor:</strong>ID - selects the color with the given
+	 * ID</li>
+	 * </ul>
 	 *
 	 * @param data the data to be applied
 	 */
@@ -800,7 +796,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Create a button for the preference page.
-	 * 
+	 *
 	 * @param parent
 	 * @param label
 	 */
@@ -946,30 +942,30 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			}
 
 			private String getText(Object element) {
-				String text = EMPTY;
+				StringBuilder text = new StringBuilder(EMPTY);
 				if (element instanceof ICategorizedThemeElementDefinition) {
-					text += ((ICategorizedThemeElementDefinition) element).getDescription();
+					text.append(((ICategorizedThemeElementDefinition) element).getDescription());
 				}
 				if (element instanceof FontDefinition) {
 					Font font = fontRegistry.get(((FontDefinition) element).getId());
 					if (font != null) {
 						for (FontData data : font.getFontData()) {
-							text += SPACE;
-							text += data.getName() + SPACE;
-							text += data.getHeight() + SPACE;
-							text += data.getStyle() == SWT.NORMAL ? RESOURCE_BUNDLE.getString("normalFont") + SPACE //$NON-NLS-1$
-									: EMPTY;
-							text += (data.getStyle() & SWT.BOLD) == SWT.BOLD
+							text.append(SPACE);
+							text.append(data.getName() + SPACE);
+							text.append(data.getHeight() + SPACE);
+							text.append(data.getStyle() == SWT.NORMAL ? RESOURCE_BUNDLE.getString("normalFont") + SPACE //$NON-NLS-1$
+									: EMPTY);
+							text.append((data.getStyle() & SWT.BOLD) == SWT.BOLD
 									? RESOURCE_BUNDLE.getString("boldFont") + SPACE //$NON-NLS-1$
-									: EMPTY;
-							text += (data.getStyle() & SWT.ITALIC) == SWT.ITALIC
+									: EMPTY);
+							text.append((data.getStyle() & SWT.ITALIC) == SWT.ITALIC
 									? RESOURCE_BUNDLE.getString("italicFont") + SPACE //$NON-NLS-1$
-									: EMPTY;
+									: EMPTY);
 							break;
 						}
 					}
 				}
-				return text;
+				return text.toString();
 			}
 		};
 		filter.setIncludeLeadingWildcard(true);
@@ -1035,13 +1031,12 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		if (cascadingTheme != null)
 			cascadingTheme.dispose();
 
-		for (Iterator i = previewSet.iterator(); i.hasNext();) {
-			IThemePreview preview = (IThemePreview) i.next();
+		for (IThemePreview preview : previewSet) {
 			try {
 				preview.dispose();
 			} catch (RuntimeException e) {
 				WorkbenchPlugin.log(RESOURCE_BUNDLE.getString("errorDisposePreviewLog"), //$NON-NLS-1$
-						StatusUtil.newStatus(IStatus.ERROR, e.getMessage(), e));
+					StatusUtil.newStatus(IStatus.ERROR, e.getMessage(), e));
 			}
 		}
 		previewSet.clear();
@@ -1085,7 +1080,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		String id = definition.getId();
 		RGB updatedRGB = colorPreferencesToSet.get(definition);
 		if (updatedRGB == null) {
-			updatedRGB = (RGB) colorValuesToSet.get(id);
+			updatedRGB = colorValuesToSet.get(id);
 			if (updatedRGB == null)
 				updatedRGB = currentTheme.getColorRegistry().getRGB(id);
 		}
@@ -1100,7 +1095,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	 *         defaultsTo attribute.
 	 */
 	private ColorDefinition[] getDescendantColors(ColorDefinition definition) {
-		List list = new ArrayList(5);
+		List<ColorDefinition> list = new ArrayList<>(5);
 		String id = definition.getId();
 
 		ColorDefinition[] colors = themeRegistry.getColors();
@@ -1113,11 +1108,11 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			if (id.equals(colorDefinition.getDefaultsTo()))
 				list.add(colorDefinition);
 		}
-		return (ColorDefinition[]) list.toArray(new ColorDefinition[list.size()]);
+		return list.toArray(new ColorDefinition[list.size()]);
 	}
 
 	private FontDefinition[] getDescendantFonts(FontDefinition definition) {
-		List list = new ArrayList(5);
+		List<FontDefinition> list = new ArrayList<>(5);
 		String id = definition.getId();
 
 		FontDefinition[] fonts = themeRegistry.getFonts();
@@ -1130,7 +1125,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			if (id.equals(fontDefinition.getDefaultsTo()))
 				list.add(fontDefinition);
 		}
-		return (FontDefinition[]) list.toArray(new FontDefinition[list.size()]);
+		return list.toArray(new FontDefinition[list.size()]);
 	}
 
 	private FontDefinition getFontAncestor(FontDefinition definition) {
@@ -1152,7 +1147,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		String id = definition.getId();
 		FontData[] updatedFD = fontPreferencesToSet.get(definition);
 		if (updatedFD == null) {
-			updatedFD = (FontData[]) fontValuesToSet.get(id);
+			updatedFD = fontValuesToSet.get(id);
 			if (updatedFD == null)
 				updatedFD = currentTheme.getFontRegistry().getFontData(id);
 		}
@@ -1328,10 +1323,8 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			if (definition.getValue() != null) { // value-based color
 				if (colorPreferencesToSet.get(definition).equals(definition.getValue()))
 					return true;
-			} else {
-				if (colorPreferencesToSet.get(definition).equals(getColorAncestorValue(definition)))
-					return true;
-			}
+			} else if (colorPreferencesToSet.get(definition).equals(getColorAncestorValue(definition)))
+				return true;
 		} else if (colorValuesToSet.containsKey(id)) {
 			if (definition.getValue() != null) { // value-based color
 				if (colorValuesToSet.get(id).equals(definition.getValue()))
@@ -1340,16 +1333,14 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 				if (colorValuesToSet.get(id).equals(getColorAncestorValue(definition)))
 					return true;
 			}
+		} else if (definition.getValue() != null) { // value-based color
+			if (getPreferenceStore().isDefault(createPreferenceKey(definition)))
+				return true;
 		} else {
-			if (definition.getValue() != null) { // value-based color
-				if (getPreferenceStore().isDefault(createPreferenceKey(definition)))
-					return true;
-			} else {
-				// a descendant is default if it's the same value as its ancestor
-				RGB rgb = getColorValue(definition);
-				if (rgb != null && rgb.equals(getColorAncestorValue(definition)))
-					return true;
-			}
+			// a descendant is default if it's the same value as its ancestor
+			RGB rgb = getColorValue(definition);
+			if (rgb != null && rgb.equals(getColorAncestorValue(definition)))
+				return true;
 		}
 		return false;
 	}
@@ -1368,26 +1359,24 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			}
 		} else if (fontValuesToSet.containsKey(id)) {
 			if (definition.getValue() != null) { // value-based font
-				if (Arrays.equals((FontData[]) fontValuesToSet.get(id), definition.getValue()))
+				if (Arrays.equals(fontValuesToSet.get(id), definition.getValue()))
 					return true;
 			} else {
 				FontData[] ancestor = getFontAncestorValue(definition);
-				if (Arrays.equals((FontData[]) fontValuesToSet.get(id), ancestor))
+				if (Arrays.equals(fontValuesToSet.get(id), ancestor))
 					return true;
 			}
 
+		} else if (definition.getValue() != null) { // value-based font
+			if (getPreferenceStore().isDefault(createPreferenceKey(definition)))
+				return true;
 		} else {
-			if (definition.getValue() != null) { // value-based font
-				if (getPreferenceStore().isDefault(createPreferenceKey(definition)))
-					return true;
-			} else {
-				FontData[] ancestor = getFontAncestorValue(definition);
-				if (ancestor == null)
-					return true;
-				// a descendant is default if it's the same value as its ancestor
-				if (Arrays.equals(getFontValue(definition), ancestor))
-					return true;
-			}
+			FontData[] ancestor = getFontAncestorValue(definition);
+			if (ancestor == null)
+				return true;
+			// a descendant is default if it's the same value as its ancestor
+			if (Arrays.equals(getFontValue(definition), ancestor))
+				return true;
 		}
 		return false;
 	}
@@ -1395,7 +1384,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 	/**
 	 * Apply the dialog font to the control and store it for later so that it can be
 	 * used for a later update.
-	 * 
+	 *
 	 * @param control
 	 */
 	private void myApplyDialogFont(Control control) {
@@ -1618,7 +1607,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Updates the working registry.
-	 * 
+	 *
 	 * @param definition
 	 * @param newRGB
 	 */
@@ -1632,7 +1621,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Returns the preview for the category.
-	 * 
+	 *
 	 * @param category the category
 	 * @return the preview for the category, or its ancestors preview if it does not
 	 *         have one.
@@ -1660,13 +1649,13 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Update for a change in the dialog font.
-	 * 
+	 *
 	 * @param newFont
 	 */
 	private void updateForDialogFontChange(Font newFont) {
-		Iterator iterator = dialogFontWidgets.iterator();
+		Iterator<Control> iterator = dialogFontWidgets.iterator();
 		while (iterator.hasNext()) {
-			((Control) iterator.next()).setFont(newFont);
+			iterator.next().setFont(newFont);
 		}
 
 		// recalculate the fonts for the tree
@@ -1687,7 +1676,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		}
 		Composite previewControl = null;
 		if (category != null) { // check if there is a preview for it
-			previewControl = (Composite) previewMap.get(category);
+			previewControl = previewMap.get(category);
 			if (previewControl == null) {
 				try {
 					IThemePreview preview = getThemePreview(category);
@@ -1727,7 +1716,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Restore the selection state of the tree.
-	 * 
+	 *
 	 * @since 3.1
 	 */
 	private void restoreTreeSelection() {
@@ -1742,7 +1731,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Save the selection state of the tree.
-	 * 
+	 *
 	 * @since 3.1
 	 */
 	private void saveTreeSelection() {
@@ -1757,7 +1746,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Restore the expansion state of the tree.
-	 * 
+	 *
 	 * @since 3.1
 	 */
 	private void restoreTreeExpansion() {
@@ -1768,7 +1757,7 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 		if (expandedElementIDs.length == 0)
 			return;
 
-		List elements = new ArrayList(expandedElementIDs.length);
+		List<IThemeElementDefinition> elements = new ArrayList<>(expandedElementIDs.length);
 		for (String expandedElementID : expandedElementIDs) {
 			IThemeElementDefinition def = findElementFromMarker(expandedElementID);
 			if (def != null)
@@ -1809,12 +1798,12 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 
 	/**
 	 * Saves the expansion state of the tree.
-	 * 
+	 *
 	 * @since 3.1
 	 */
 	private void saveTreeExpansion() {
 		Object[] elements = tree.getViewer().getExpandedElements();
-		List elementIds = new ArrayList(elements.length);
+		List<String> elementIds = new ArrayList<>(elements.length);
 
 		StringBuilder buffer = new StringBuilder();
 		for (Object object : elements) {
@@ -1827,8 +1816,8 @@ public final class ColorsAndFontsPreferencePage extends PreferencePage implement
 			buffer.setLength(0);
 		}
 
-		for (Iterator i = elementIds.iterator(); i.hasNext();) {
-			String id = (String) i.next();
+		for (Iterator<String> i = elementIds.iterator(); i.hasNext();) {
+			String id = i.next();
 			buffer.append(id);
 			if (i.hasNext()) {
 				buffer.append(EXPANDED_ELEMENTS_TOKEN);
