@@ -18,13 +18,13 @@ package org.eclipse.ui.internal.themes;
  *
  * @since 3.0
  */
-public interface ICategorizedThemeElementDefinition extends
-        IThemeElementDefinition {
+public interface ICategorizedThemeElementDefinition extends IThemeElementDefinition {
 
-    /**
-     * Returns the category of this element.
-     *
-     * @return the category of this element, or <code>null</code> if it does not belong to one.
-     */
-    String getCategoryId();
+	/**
+	 * Returns the category of this element.
+	 *
+	 * @return the category of this element, or <code>null</code> if it does not
+	 *         belong to one.
+	 */
+	String getCategoryId();
 }
