@@ -63,7 +63,7 @@ public final class NonLocalUndoUserApprover implements IOperationApprover {
 
 	private Object[] elements;
 
-	private Class affectedObjectsClass;
+	private Class<?> affectedObjectsClass;
 
 	private ArrayList elementsAndAdapters;
 
@@ -96,7 +96,7 @@ public final class NonLocalUndoUserApprover implements IOperationApprover {
 	 *                                 necessary for the comparison.
 	 */
 	public NonLocalUndoUserApprover(IUndoContext context, IEditorPart part, Object[] affectedObjects,
-			Class preferredComparisonClass) {
+			Class<?> preferredComparisonClass) {
 		super();
 		this.context = context;
 		this.part = part;
@@ -268,8 +268,8 @@ public final class NonLocalUndoUserApprover implements IOperationApprover {
 				}
 			}
 		}
-		for (int i = 0; i < elementsAndAdapters.size(); i++) {
-			if (elementsAndAdapters.get(i).equals(someObject)) {
+		for (Object elementOrAdapter : elementsAndAdapters) {
+			if (elementOrAdapter.equals(someObject)) {
 				return true;
 			}
 		}
