@@ -40,15 +40,9 @@ public class Snippet009TableViewer {
 	public static void main(String[] args) {
 		final Display display = Display.getDefault();
 
-		// In an RCP application, the threading Realm will be set for you
-		// automatically by the Workbench. In an SWT application, you can do
-		// this once, wrpping your binding method call.
 		Realm.runWithDefault(DisplayRealm.getRealm(display), () -> {
+			Shell shell = new View(new ViewModel()).createShell();
 
-			ViewModel viewModel = new ViewModel();
-			Shell shell = new View(viewModel).createShell();
-
-			// The SWT event loop
 			while (!shell.isDisposed()) {
 				if (!display.readAndDispatch()) {
 					display.sleep();
@@ -57,41 +51,38 @@ public class Snippet009TableViewer {
 		});
 	}
 
-	// Minimal JavaBeans support
+	/** Helper class for implementing JavaBeans support. */
 	public static abstract class AbstractModelObject {
-		private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(
-				this);
+		private PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
 
 		public void addPropertyChangeListener(PropertyChangeListener listener) {
 			propertyChangeSupport.addPropertyChangeListener(listener);
 		}
 
-		public void addPropertyChangeListener(String propertyName,
-				PropertyChangeListener listener) {
-			propertyChangeSupport.addPropertyChangeListener(propertyName,
-					listener);
+		public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener) {
+			propertyChangeSupport.addPropertyChangeListener(propertyName, listener);
 		}
 
 		public void removePropertyChangeListener(PropertyChangeListener listener) {
 			propertyChangeSupport.removePropertyChangeListener(listener);
 		}
 
-		public void removePropertyChangeListener(String propertyName,
-				PropertyChangeListener listener) {
-			propertyChangeSupport.removePropertyChangeListener(propertyName,
-					listener);
+		public void removePropertyChangeListener(String propertyName, PropertyChangeListener listener) {
+			propertyChangeSupport.removePropertyChangeListener(propertyName, listener);
 		}
 
-		protected void firePropertyChange(String propertyName, Object oldValue,
-				Object newValue) {
-			propertyChangeSupport.firePropertyChange(propertyName, oldValue,
-					newValue);
+		protected void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
+			propertyChangeSupport.firePropertyChange(propertyName, oldValue, newValue);
 		}
 	}
 
-	// The data model class. This is normally a persistent class of some sort.
+	/**
+	 * The data model class.
+	 * <p>
+	 * This example implements full JavaBeans bound properties so that changes to
+	 * instances of this class will automatically be propagated to the UI.
+	 */
 	static class Person extends AbstractModelObject {
-		// A property...
 		String name = "John Smith";
 
 		public Person(String name) {
@@ -109,14 +100,11 @@ public class Snippet009TableViewer {
 		}
 	}
 
-	// The View's model--the root of our Model graph for this particular GUI.
-	//
-	// Typically each View class has a corresponding ViewModel class.
-	// The ViewModel is responsible for getting the objects to edit from the
-	// data access tier. Since this snippet doesn't have any persistent objects
-	// ro retrieve, this ViewModel just instantiates a model object to edit.
+	/**
+	 * The View's model--the root of our Model graph for this particular GUI.
+	 */
 	static class ViewModel {
-		// The model to bind
+		/** The model to bind. */
 		private List<Person> people = new LinkedList<>();
 		{
 			people.add(new Person("Steve Northover"));
@@ -133,7 +121,7 @@ public class Snippet009TableViewer {
 		}
 	}
 
-	// The GUI view
+	/** The GUI view. */
 	static class View {
 		private ViewModel viewModel;
 		private Table committers;
@@ -151,14 +139,13 @@ public class Snippet009TableViewer {
 			committers.setLinesVisible(true);
 			TableColumn column = new TableColumn(committers, SWT.NONE);
 
-			// Set up data binding.
+			// Set up data binding
 			TableViewer peopleViewer = new TableViewer(committers);
 			ViewerSupport.bind(peopleViewer, new WritableList<>(viewModel.getPeople(), Person.class),
 					BeanProperties.value(Person.class, "name"));
 
 			column.pack();
 
-			// Open and return the Shell
 			shell.setSize(100, 300);
 			shell.open();
 			return shell;
