@@ -39,7 +39,7 @@ import org.eclipse.swt.widgets.TableColumn;
  */
 public class Snippet004HideSelection {
 
-	public class MyModel {
+	public static class MyModel {
 		public int counter;
 
 		public MyModel(int counter) {
