@@ -39,7 +39,7 @@ import org.eclipse.swt.widgets.TableColumn;
 public class Snippet013TableViewerNoMandatoryLabelProvider {
 
 
-	public class MyModel {
+	public static class MyModel {
 		public int counter;
 
 		public MyModel(int counter) {
@@ -52,7 +52,7 @@ public class Snippet013TableViewerNoMandatoryLabelProvider {
 		}
 	}
 
-	public class MyLabelProvider extends LabelProvider implements
+	public static class MyLabelProvider extends LabelProvider implements
 			ITableLabelProvider, ITableFontProvider, ITableColorProvider {
 		FontRegistry registry = new FontRegistry();
 
