@@ -49,7 +49,7 @@ public class Snippet035TableCursorCellHighlighter {
 
 	public static boolean flag = true;
 
-	private class MyModel {
+	private static class MyModel {
 		public int counter;
 
 		public MyModel(int counter) {
@@ -93,7 +93,7 @@ public class Snippet035TableCursorCellHighlighter {
 
 	}
 
-	private class MyColumnLabelProvider extends ColumnLabelProvider {
+	private static class MyColumnLabelProvider extends ColumnLabelProvider {
 		FontRegistry registry = JFaceResources.getFontRegistry();
 		private String columnIndex;
 
