@@ -170,7 +170,7 @@ public class Snippet056BooleanCellEditor {
 		display.dispose();
 	}
 
-	private final class MyEditingSupport extends EditingSupport {
+	private static final class MyEditingSupport extends EditingSupport {
 		private final TreeViewer v;
 		private final TextCellEditor textCellEditor;
 
@@ -203,7 +203,7 @@ public class Snippet056BooleanCellEditor {
 		}
 	}
 
-	private final class MyColumnLabelProvider extends ColumnLabelProvider {
+	private static final class MyColumnLabelProvider extends ColumnLabelProvider {
 		private String prefix;
 
 		public MyColumnLabelProvider(String prefix) {
@@ -216,7 +216,7 @@ public class Snippet056BooleanCellEditor {
 		}
 	}
 
-	private class MyContentProvider implements ITreeContentProvider {
+	private static class MyContentProvider implements ITreeContentProvider {
 
 		@Override
 		public Object[] getElements(Object inputElement) {
@@ -251,7 +251,7 @@ public class Snippet056BooleanCellEditor {
 
 	}
 
-	public class MyModel {
+	public static class MyModel {
 
 		public MyModel parent;
 		public List<MyModel> child = new ArrayList<>();
