@@ -45,7 +45,7 @@ import org.eclipse.swt.widgets.TableColumn;
 public class Snippet031TableStaticTooltip {
 	private static Image[] images;
 
-	public class MyModel {
+	public static class MyModel {
 		public int counter;
 
 		public MyModel(int counter) {
@@ -58,7 +58,7 @@ public class Snippet031TableStaticTooltip {
 		}
 	}
 
-	public class MyLabelProvider extends LabelProvider implements
+	public static class MyLabelProvider extends LabelProvider implements
 			ITableLabelProvider {
 
 		@Override
