@@ -16,7 +16,6 @@ package org.eclipse.ui.examples.multipageeditor;
 import java.io.StringWriter;
 import java.text.Collator;
 import java.util.ArrayList;
-import java.util.Collections;
 import java.util.List;
 import java.util.StringTokenizer;
 
@@ -225,10 +224,10 @@ public class MultiPageEditorExample extends MultiPageEditorPart implements
 			editorWords.add(tokenizer.nextToken());
 		}
 
-		Collections.sort(editorWords, Collator.getInstance());
+		editorWords.sort(Collator.getInstance());
 		StringWriter displayText = new StringWriter();
-		for (int i = 0; i < editorWords.size(); i++) {
-			displayText.write((editorWords.get(i)));
+		for (String editorWord : editorWords) {
+			displayText.write((editorWord));
 			displayText.write("\n"); //$NON-NLS-1$
 		}
 		text.setText(displayText.toString());
