@@ -16,35 +16,32 @@ package org.eclipse.e4.ui.css.swt.helpers;
 
 import static org.eclipse.e4.ui.css.swt.helpers.CSSSWTColorHelper.COLOR_DEFINITION_MARKER;
 import static org.eclipse.e4.ui.css.swt.helpers.CSSSWTFontHelper.FONT_DEFINITION_MARKER;
-import static org.junit.Assert.fail;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 
 import org.eclipse.e4.ui.css.core.css2.CSS2FontHelper;
 import org.eclipse.e4.ui.css.core.dom.properties.css2.CSS2FontProperties;
 import org.eclipse.e4.ui.css.core.impl.dom.CSSValueImpl;
-import org.eclipse.e4.ui.internal.css.swt.CSSActivator;
 import org.eclipse.e4.ui.internal.css.swt.definition.IColorAndFontProvider;
 import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.graphics.RGB;
+import org.osgi.framework.FrameworkUtil;
 import org.w3c.dom.DOMException;
 import org.w3c.dom.css.CSSPrimitiveValue;
 import org.w3c.dom.css.CSSValue;
 
 public abstract class CSSSWTHelperTestCase {
+
 	protected static final String CSS_ITALIC = CSS2FontHelper.getFontStyle(true);
 	protected static final String CSS_BOLD = CSS2FontHelper.getFontWeight(true);
 
-	protected void registerFontProviderWith(String expectedSymbolicName,
-			String family, int size, int style) {
+	protected void registerFontProviderWith(String expectedSymbolicName, String family, int size, int style) {
 		IColorAndFontProvider provider = mock(IColorAndFontProvider.class);
-		doReturn(new FontData[] { new FontData(family, size, style) }).when(
-				provider).getFont(expectedSymbolicName);
+		doReturn(new FontData[] { new FontData(family, size, style) }).when(provider).getFont(expectedSymbolicName);
 		registerProvider(provider);
 	}
 
-	protected void registerColorProviderWith(String expectedSymbolicName,
-			RGB rgb) {
+	protected void registerColorProviderWith(String expectedSymbolicName, RGB rgb) {
 		IColorAndFontProvider provider = mock(IColorAndFontProvider.class);
 		doReturn(rgb).when(provider).getColor(expectedSymbolicName);
 		registerProvider(provider);
@@ -52,25 +49,15 @@ public abstract class CSSSWTHelperTestCase {
 	}
 
 	private void registerProvider(final IColorAndFontProvider provider) {
-		try {
-			new CSSActivator() {
-				@Override
-				public IColorAndFontProvider getColorAndFontProvider() {
-					return provider;
-				}
-			}.start(null);
-		} catch (Exception e) {
-			fail();
-		}
-
+		FrameworkUtil.getBundle(getClass()).getBundleContext().registerService(IColorAndFontProvider.class, provider,
+				null);
 	}
 
 	protected CSS2FontProperties fontProperties(String family) {
 		return fontProperties(family, null, null, null);
 	}
 
-	protected CSS2FontProperties fontProperties(String family, Object size,
-			Object style, Object weight) {
+	protected CSS2FontProperties fontProperties(String family, Object size, Object style, Object weight) {
 		CSS2FontProperties result = mock(CSS2FontProperties.class);
 		doReturn(valueImpl(family)).when(result).getFamily();
 		if (size != null) {
