@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2014 IBM Corporation and others.
+ * Copyright (c) 2014, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,12 +16,12 @@ package org.eclipse.e4.ui.css.swt.properties.preference;
 
 import static org.eclipse.e4.ui.css.swt.helpers.EclipsePreferencesHelper.PROPS_OVERRIDDEN_BY_CSS_PROP;
 import static org.eclipse.e4.ui.css.swt.properties.preference.EclipsePreferencesHandler.PREFERENCES_PROP;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
-import static org.junit.Assert.fail;
-import static org.mockito.Matchers.any;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.spy;
@@ -32,22 +32,21 @@ import org.eclipse.core.internal.preferences.EclipsePreferences;
 import org.eclipse.core.runtime.preferences.IEclipsePreferences;
 import org.eclipse.e4.ui.css.core.engine.CSSEngine;
 import org.eclipse.e4.ui.css.swt.dom.preference.EclipsePreferencesElement;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 import org.w3c.dom.css.CSSValue;
 import org.w3c.dom.css.CSSValueList;
 
 public class EclipsePreferencesHandlerTest {
 
 	@Test
-	public void testApplyCSSProperty() {
+	void testApplyCSSProperty() {
 		// given
 		CSSEngine engine = mock(CSSEngine.class);
 
 		IEclipsePreferences preferences = new EclipsePreferences();
 
-		EclipsePreferencesElement element = new EclipsePreferencesElement(
-				preferences, engine);
+		EclipsePreferencesElement element = new EclipsePreferencesElement(preferences, engine);
 
 		CSSValue value = mock(CSSValue.class);
 		doReturn(CSSValue.CSS_PRIMITIVE_VALUE).when(value).getCssValueType();
@@ -67,17 +66,15 @@ public class EclipsePreferencesHandlerTest {
 	}
 
 	@Test
-	public void testApplyCSSPropertyWhenCssValueList() {
+	void testApplyCSSPropertyWhenCssValueList() {
 		// given
 		CSSEngine engine = mock(CSSEngine.class);
 
 		IEclipsePreferences preferences = new EclipsePreferences();
 
-		EclipsePreferencesElement element = new EclipsePreferencesElement(
-				preferences, engine);
+		EclipsePreferencesElement element = new EclipsePreferencesElement(preferences, engine);
 
-		CSSValue[] values = new CSSValue[] { mock(CSSValue.class),
-				mock(CSSValue.class) };
+		CSSValue[] values = new CSSValue[] { mock(CSSValue.class), mock(CSSValue.class) };
 
 		CSSValueList listValue = mock(CSSValueList.class);
 		doReturn(CSSValue.CSS_VALUE_LIST).when(listValue).getCssValueType();
@@ -96,15 +93,14 @@ public class EclipsePreferencesHandlerTest {
 		}
 
 		// then
-		verify(handler, times(2)).overrideProperty(
-				any(IEclipsePreferences.class), any(CSSValue.class));
+		verify(handler, times(2)).overrideProperty(any(IEclipsePreferences.class), any(CSSValue.class));
 		verify(handler, times(1)).overrideProperty(preferences, values[0]);
 		verify(handler, times(1)).overrideProperty(preferences, values[1]);
 		engine.dispose();
 	}
 
 	@Test
-	public void testOverridePropertyWithCSSValue() {
+	void testOverridePropertyWithCSSValue() {
 		// given
 		IEclipsePreferences preferences = new EclipsePreferences();
 
@@ -121,14 +117,12 @@ public class EclipsePreferencesHandlerTest {
 		handler.overridePropertyUnMocked(preferences, value2);
 
 		// then
-		verify(handler, times(1)).overrideProperty(preferences, "name1",
-				"value1");
-		verify(handler, times(1)).overrideProperty(preferences, "name2",
-				"value2");
+		verify(handler, times(1)).overrideProperty(preferences, "name1", "value1");
+		verify(handler, times(1)).overrideProperty(preferences, "name2", "value2");
 	}
 
 	@Test
-	public void testOverridePropertyWithNameAndValueSplit() {
+	void testOverridePropertyWithNameAndValueSplit() {
 		// given
 		IEclipsePreferences preferences = new EclipsePreferences();
 
@@ -139,13 +133,12 @@ public class EclipsePreferencesHandlerTest {
 
 		// then
 		assertEquals("value", preferences.get("name", null));
-		assertTrue(preferences.get(PROPS_OVERRIDDEN_BY_CSS_PROP, "").contains(
-				"name"));
+		assertTrue(preferences.get(PROPS_OVERRIDDEN_BY_CSS_PROP, "").contains("name"));
 	}
 
 	@Test
-	@Ignore("Failing on Hudson, see Bug 501875")
-	public void testOverridePropertyWithNameAndValueSplitAndNameAlreadyAddedByUser() {
+	@Disabled("Failing on Hudson, see Bug 501875")
+	void testOverridePropertyWithNameAndValueSplitAndNameAlreadyAddedByUser() {
 		// given
 		IEclipsePreferences preferences = new EclipsePreferences();
 		// pref is already set that means that user has overridden it with the
@@ -163,7 +156,7 @@ public class EclipsePreferencesHandlerTest {
 	}
 
 	@Test
-	public void testCustomizePreferenceOverriddenByCSS() {
+	void testCustomizePreferenceOverriddenByCSS() {
 		// given
 		IEclipsePreferences preferences = new EclipsePreferences();
 
@@ -172,36 +165,29 @@ public class EclipsePreferencesHandlerTest {
 		// when
 		handler.overridePropertyUnMocked(preferences, "name", "value");
 		assertEquals("value", preferences.get("name", null));
-		assertTrue(preferences.get(PROPS_OVERRIDDEN_BY_CSS_PROP, "").contains(
-				"name"));
+		assertTrue(preferences.get(PROPS_OVERRIDDEN_BY_CSS_PROP, "").contains("name"));
 
 		preferences.put("name", "customizedValue");
 
 		// then
 		assertEquals("customizedValue", preferences.get("name", null));
-		assertFalse(preferences.get(PROPS_OVERRIDDEN_BY_CSS_PROP, "").contains(
-				"name"));
+		assertFalse(preferences.get(PROPS_OVERRIDDEN_BY_CSS_PROP, "").contains("name"));
 	}
 
-	public static class EclipsePreferencesHandlerTestable extends
-	EclipsePreferencesHandler {
+	public static class EclipsePreferencesHandlerTestable extends EclipsePreferencesHandler {
 		@Override
-		public void overrideProperty(IEclipsePreferences preferences,
-				CSSValue value) {
+		public void overrideProperty(IEclipsePreferences preferences, CSSValue value) {
 		}
 
-		public void overridePropertyUnMocked(IEclipsePreferences preferences,
-				CSSValue value) {
+		public void overridePropertyUnMocked(IEclipsePreferences preferences, CSSValue value) {
 			super.overrideProperty(preferences, value);
 		}
 
 		@Override
-		public void overrideProperty(IEclipsePreferences preferences,
-				String name, String value) {
+		public void overrideProperty(IEclipsePreferences preferences, String name, String value) {
 		}
 
-		public void overridePropertyUnMocked(IEclipsePreferences preferences,
-				String name, String value) {
+		public void overridePropertyUnMocked(IEclipsePreferences preferences, String name, String value) {
 			super.overrideProperty(preferences, name, value);
 		}
 	}
