@@ -14,11 +14,11 @@
  ******************************************************************************/
 package org.eclipse.e4.ui.tests.css.swt;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertFalse;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
-import static org.junit.Assert.assertTrue;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertFalse;
+import static org.junit.jupiter.api.Assertions.assertNotNull;
+import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 
 import org.eclipse.e4.ui.css.core.engine.CSSEngine;
 import org.eclipse.e4.ui.css.swt.dom.CTabItemElement;
@@ -34,9 +34,9 @@ import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Shell;
-import org.junit.After;
-import org.junit.Ignore;
-import org.junit.Test;
+import org.junit.jupiter.api.AfterEach;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
 
 public class CTabItemTest extends CSSSWTTestCase {
 
@@ -44,7 +44,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	private Shell shell;
 
 	@Override
-	@After
+	@AfterEach
 	public void tearDown() {
 		if (shell != null) {
 			shell.dispose();
@@ -115,7 +115,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testFontRegular() {
+	void testFontRegular() {
 		CTabFolder folder = createTestTabFolder("Button { font-family: Verdana; font-size: 12 }\n"
 				+ "CTabItem { font-family: Verdana; font-size: 16 }");
 		spinEventLoop();
@@ -140,7 +140,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testFontBold() {
+	void testFontBold() {
 		CTabFolder folder = createTestTabFolder("Button { font-weight: bold }\n"
 				+ "CTabItem { font-weight: bold }");
 		spinEventLoop();
@@ -162,7 +162,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testFontItalic() {
+	void testFontItalic() {
 		CTabFolder folder = createTestTabFolder("Button { font-weight: bold }\n"
 				+ "CTabItem { font-style: italic }");
 		spinEventLoop();
@@ -197,7 +197,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectedFontBold() {
+	void testSelectedFontBold() {
 		CTabFolder folder = createTestTabFolder("CTabItem:selected { font-weight: bold }");
 		spinEventLoop();
 		for (int i = 0; i < folder.getItemCount(); i++) {
@@ -206,7 +206,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectedFontMerged() {
+	void testSelectedFontMerged() {
 		CTabFolder folder = createTestTabFolder("CTabItem { font-weight: normal; font-style: italic }\n"
 				+ "CTabItem:selected { font-weight: bold }");
 		spinEventLoop();
@@ -222,7 +222,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectedFontMerged2() {
+	void testSelectedFontMerged2() {
 		CTabFolder folder = createTestTabFolder("CTabItem { font-style: italic }\n"
 				+ "CTabItem:selected { font-weight: bold }");
 		spinEventLoop();
@@ -238,7 +238,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectedFontMerged3() {
+	void testSelectedFontMerged3() {
 		CTabFolder folder = createTestTabFolder("CTabItem { font-weight: bold }\n"
 				+ "CTabItem:selected { font-style: italic; font-weight: normal }");
 		spinEventLoop();
@@ -265,17 +265,17 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testShowCloseFalse() {
+	void testShowCloseFalse() {
 		testShowClose(false);
 	}
 
 	@Test
-	public void testShowCloseTrue() {
+	void testShowCloseTrue() {
 		testShowClose(true);
 	}
 
 	@Test
-	public void testShowClose() {
+	void testShowClose() {
 		CTabFolder folder = createTestTabFolder("CTabItem { show-close: true }");
 		for (int i = 0; i < folder.getItemCount(); i++) {
 			assertEquals(true, folder.getItem(i).getShowClose());
@@ -290,7 +290,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testShowClose2() {
+	void testShowClose2() {
 		CTabFolder folder = createTestTabFolder();
 		CTabFolder folder2 = createFolder(folder.getShell());
 		engine = createEngine("CTabItem { swt-show-close: true }", folder
@@ -334,7 +334,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectedShowClose() {
+	void testSelectedShowClose() {
 		CTabFolder folder = createTestTabFolder("CTabItem:selected { show-close: true }");
 		for (int i = 0; i < folder.getItemCount(); i++) {
 			testSelectedShowClose(folder, i);
@@ -348,7 +348,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectedShowClose2() {
+	void testSelectedShowClose2() {
 		CTabFolder folder = createTestTabFolder("CTabItem { show-close: false }\n"
 				+ "CTabItem:selected { show-close: true }");
 		for (int i = 0; i < folder.getItemCount(); i++) {
@@ -356,9 +356,9 @@ public class CTabItemTest extends CSSSWTTestCase {
 		}
 	}
 
-	@Ignore("test was commented before bug 443094")
+	@Disabled("test was commented before bug 443094")
 	@Test
-	public void testClassSelectedShowClose() {
+	void testClassSelectedShowClose() {
 		CTabFolder folder = createTestTabFolder();
 		WidgetElement.setCSSClass(folder, "editorStack");
 
@@ -370,9 +370,9 @@ public class CTabItemTest extends CSSSWTTestCase {
 		}
 	}
 
-	@Ignore("test was commented before bug 443094")
+	@Disabled("test was commented before bug 443094")
 	@Test
-	public void testFontsEditorStackClass() {
+	void testFontsEditorStackClass() {
 		CTabFolder folder = createTestTabFolder(false);
 		CTabFolder folder2 = createFolder(folder.getShell());
 
@@ -427,9 +427,9 @@ public class CTabItemTest extends CSSSWTTestCase {
 		}
 	}
 
-	@Ignore("test was commented before bug 443094")
+	@Disabled("test was commented before bug 443094")
 	@Test
-	public void testFontsEditorStackClass2() {
+	void testFontsEditorStackClass2() {
 		CTabFolder folder = createTestTabFolder(false);
 		CTabFolder folder2 = createFolder(folder.getShell());
 
@@ -487,9 +487,9 @@ public class CTabItemTest extends CSSSWTTestCase {
 		}
 	}
 
-	@Ignore("test was commented before bug 443094")
+	@Disabled("test was commented before bug 443094")
 	@Test
-	public void testShowCloseEditorStack() {
+	void testShowCloseEditorStack() {
 		CTabFolder folder = createTestTabFolder(false);
 		CTabFolder folder2 = createFolder(folder.getShell());
 
@@ -529,9 +529,9 @@ public class CTabItemTest extends CSSSWTTestCase {
 		}
 	}
 
-	@Ignore("test was commented before bug 443094")
+	@Disabled("test was commented before bug 443094")
 	@Test
-	public void testShowCloseViewStack() {
+	void testShowCloseViewStack() {
 		CTabFolder folder = createTestTabFolder(false);
 		CTabFolder folder2 = createFolder(folder.getShell());
 
@@ -577,7 +577,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testBackground() {
+	void testBackground() {
 		CTabFolder folder = createTestTabFolder("CTabItem { background-color: #0000ff }", false);
 		assertEquals(new RGB(0, 0, 255), folder.getBackground().getRGB());
 
@@ -587,7 +587,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testBackground2() {
+	void testBackground2() {
 		CTabFolder folder = createTestTabFolder(false);
 		Color preStyledSelectionBackground = folder.getSelectionBackground();
 
@@ -613,7 +613,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectionBackground() {
+	void testSelectionBackground() {
 		CTabFolder folder = createTestTabFolder("CTabItem:selected { background-color: #00ff00 }", false);
 		assertEquals(new RGB(0, 255, 0), folder.getSelectionBackground().getRGB());
 
@@ -623,7 +623,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testForeground() {
+	void testForeground() {
 		CTabFolder folder = createTestTabFolder("CTabItem { color: #0000ff }", false);
 		assertEquals(new RGB(0, 0, 255), folder.getForeground().getRGB());
 
@@ -633,7 +633,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testForeground2() {
+	void testForeground2() {
 		CTabFolder folder = createTestTabFolder(false);
 		Color preStyledSelectionForeground = folder.getSelectionForeground();
 
@@ -660,7 +660,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testSelectionForeground() {
+	void testSelectionForeground() {
 		CTabFolder folder = createTestTabFolder("CTabItem:selected { color: #00ff00 }", false);
 		assertEquals(new RGB(0, 255, 0), folder.getSelectionForeground().getRGB());
 
@@ -670,7 +670,7 @@ public class CTabItemTest extends CSSSWTTestCase {
 	}
 
 	@Test
-	public void testParent() {
+	void testParent() {
 		CTabFolder folder = createTestTabFolder("CTabItem:selected { color: #00ff00 }", false);
 		for (int i = 0; i < folder.getItemCount(); i++) {
 			CTabItemElement element = (CTabItemElement) engine.getElement(folder.getItem(i));
