@@ -30,11 +30,10 @@ import org.eclipse.core.databinding.observable.value.WritableValue;
 import org.eclipse.core.internal.databinding.observable.StalenessObservableValue;
 import org.eclipse.jface.databinding.conformance.ObservableValueContractTest;
 import org.eclipse.jface.databinding.conformance.delegate.AbstractObservableValueContractDelegate;
+import org.eclipse.jface.databinding.conformance.util.TestCollection;
 import org.eclipse.jface.tests.databinding.AbstractDefaultRealmTestCase;
 import org.junit.Test;
 
-import junit.framework.TestSuite;
-
 /**
  * Tests for StalenessObservableValue
  *
@@ -74,8 +73,8 @@ public class StalenessObservableValueTest extends AbstractDefaultRealmTestCase {
 		assertEquals(2, nrStaleEvents.get());
 	}
 
-	public static void addConformanceTest(TestSuite suite) {
-		suite.addTest(ObservableValueContractTest.suite(new Delegate()));
+	public static void addConformanceTest(TestCollection suite) {
+		suite.addTest(ObservableValueContractTest.class, new Delegate());
 	}
 
 	static class ObservableStub extends AbstractObservable {
