@@ -15,13 +15,12 @@
 package org.eclipse.core.tests.internal.databinding.validation;
 
 import java.math.BigDecimal;
+import java.text.NumberFormat;
 
-import org.eclipse.core.databinding.conversion.StringToNumberConverter;
+import org.eclipse.core.databinding.conversion.text.StringToNumberConverter;
 import org.eclipse.core.databinding.validation.IValidator;
 import org.eclipse.core.internal.databinding.validation.StringToDoubleValidator;
 
-import com.ibm.icu.text.NumberFormat;
-
 /**
  * @since 1.1
  */
@@ -30,7 +29,7 @@ public class StringToDoubleValidatorTest extends
 
 	@Override
 	protected Number getInRangeNumber() {
-		return new Double(1);
+		return Double.valueOf(1);
 	}
 
 	@Override
