@@ -15,12 +15,16 @@
 
 package org.eclipse.jface.tests.internal.databinding.swt;
 
+import static org.junit.Assert.assertEquals;
+
 import org.eclipse.core.databinding.observable.IObservable;
 import org.eclipse.core.databinding.observable.Realm;
 import org.eclipse.core.databinding.observable.value.IObservableValue;
 import org.eclipse.jface.databinding.conformance.ObservableDelegateTest;
 import org.eclipse.jface.databinding.conformance.delegate.AbstractObservableValueContractDelegate;
 import org.eclipse.jface.databinding.conformance.swt.SWTMutableObservableValueContractTest;
+import org.eclipse.jface.databinding.conformance.swt.SWTObservableValueContractTest;
+import org.eclipse.jface.databinding.conformance.util.TestCollection;
 import org.eclipse.jface.databinding.swt.DisplayRealm;
 import org.eclipse.jface.databinding.swt.typed.WidgetProperties;
 import org.eclipse.swt.SWT;
@@ -30,8 +34,6 @@ import org.eclipse.swt.widgets.Shell;
 import org.junit.Before;
 import org.junit.Test;
 
-import junit.framework.TestSuite;
-
 /**
  * @since 3.2
  */
@@ -43,11 +45,7 @@ public class ScaleObservableValueMaxTest extends ObservableDelegateTest {
 	private IObservableValue observable;
 
 	public ScaleObservableValueMaxTest() {
-		this(null);
-	}
-
-	public ScaleObservableValueMaxTest(String testName) {
-		super(testName, new Delegate());
+		super(new Delegate());
 	}
 
 	@Override
@@ -80,8 +78,9 @@ public class ScaleObservableValueMaxTest extends ObservableDelegateTest {
 		assertEquals(max, scale.getMaximum());
 	}
 
-	public static void addConformanceTest(TestSuite suite) {
-		suite.addTest(SWTMutableObservableValueContractTest.suite(new Delegate()));
+	public static void addConformanceTest(TestCollection suite) {
+		suite.addTest(SWTMutableObservableValueContractTest.class, new Delegate());
+		suite.addTest(SWTObservableValueContractTest.class, new Delegate());
 	}
 
 	/* package */static class Delegate extends
