@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2014 IBM Corporation and others.
+ * Copyright (c) 2000, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -26,8 +26,8 @@ public class AddFilterAction extends TestBrowserAction {
 	@Override
 	public void run() {
 		Viewer viewer = getBrowser().getViewer();
-		if (viewer instanceof StructuredViewer) {
-			((StructuredViewer) viewer).addFilter(new Filter());
+		if (viewer instanceof StructuredViewer sViewer) {
+			sViewer.addFilter(new Filter());
 		}
 	}
 }
