@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2017 IBM Corporation and others.
+ * Copyright (c) 2007, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -54,7 +54,7 @@ import org.eclipse.swt.widgets.Shell;
  */
 public class StyledCellLabelProviderTests {
 
-	private static int IMAGE_SIZE= 16;
+	private static int IMAGE_SIZE = 16;
 
 	private static Image IMAGE1;
 	private static Image IMAGE2;
@@ -63,17 +63,19 @@ public class StyledCellLabelProviderTests {
 
 		Display display = new Display();
 
-		JFaceResources.getColorRegistry().put(JFacePreferences.COUNTER_COLOR, new RGB(0,127,174));
+		JFaceResources.getColorRegistry().put(JFacePreferences.COUNTER_COLOR, new RGB(0, 127, 174));
 
-		IMAGE1= new Image(display, display.getSystemImage(SWT.ICON_WARNING).getImageData().scaledTo(IMAGE_SIZE, IMAGE_SIZE));
-		IMAGE2= new Image(display, display.getSystemImage(SWT.ICON_ERROR).getImageData().scaledTo(IMAGE_SIZE, IMAGE_SIZE));
+		IMAGE1 = new Image(display,
+				display.getSystemImage(SWT.ICON_WARNING).getImageData().scaledTo(IMAGE_SIZE, IMAGE_SIZE));
+		IMAGE2 = new Image(display,
+				display.getSystemImage(SWT.ICON_ERROR).getImageData().scaledTo(IMAGE_SIZE, IMAGE_SIZE));
 
-		Shell shell= new Shell(display , SWT.CLOSE | SWT.RESIZE);
+		Shell shell = new Shell(display, SWT.CLOSE | SWT.RESIZE);
 		shell.setSize(400, 600);
 		shell.setLayout(new GridLayout(1, false));
 
-		StyledCellLabelProviderTests example= new StyledCellLabelProviderTests();
-		Control composite= example.createPartControl(shell);
+		StyledCellLabelProviderTests example = new StyledCellLabelProviderTests();
+		Control composite = example.createPartControl(shell);
 		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true, 1, 1));
 
 		shell.open();
@@ -94,11 +96,11 @@ public class StyledCellLabelProviderTests {
 	}
 
 	public Composite createPartControl(Composite parent) {
-		Composite composite= new Composite(parent, SWT.NONE);
+		Composite composite = new Composite(parent, SWT.NONE);
 
 		composite.setLayout(new GridLayout(1, true));
 
-		final Label label= new Label(composite, SWT.NONE);
+		final Label label = new Label(composite, SWT.NONE);
 		label.setLayoutData(new GridData(SWT.BEGINNING, SWT.CENTER, false, false));
 		label.setText("Operations per second: xxxxx"); //$NON-NLS-1$
 
@@ -106,7 +108,7 @@ public class StyledCellLabelProviderTests {
 
 		final Button timeButton = new Button(composite, SWT.CHECK);
 		timeButton.setText("Time");
-		timeButton.addSelectionListener(new SelectionAdapter(){
+		timeButton.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				setTimer(timeButton.getDisplay(), timeButton.getSelection(), operation, label);
@@ -131,11 +133,11 @@ public class StyledCellLabelProviderTests {
 		final Button rightButton = new Button(composite, SWT.RADIO);
 		rightButton.setText("align right");
 
-		final TableViewer tableViewer= new TableViewer(composite, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
+		final TableViewer tableViewer = new TableViewer(composite, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL);
 		tableViewer.getTable().setHeaderVisible(true);
-		FontData[] boldFontData= getModifiedFontData(tableViewer.getTable().getFont().getFontData(), SWT.BOLD);
+		FontData[] boldFontData = getModifiedFontData(tableViewer.getTable().getFont().getFontData(), SWT.BOLD);
 		Font boldFont = new Font(Display.getCurrent(), boldFontData);
-		final ExampleLabelProvider labelProvider= new ExampleLabelProvider(boldFont);
+		final ExampleLabelProvider labelProvider = new ExampleLabelProvider(boldFont);
 
 		createColumn(tableViewer, SWT.LEFT, labelProvider);
 
@@ -157,12 +159,13 @@ public class StyledCellLabelProviderTests {
 
 		operation[0] = () -> tableViewer.refresh();
 
-		SelectionAdapter adapter = new SelectionAdapter(){
+		SelectionAdapter adapter = new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
-				if (((Button)e.getSource()).getSelection()) {
+				if (((Button) e.getSource()).getSelection()) {
 					column.getColumn().dispose();
-					int style = e.getSource() == leftButton ? SWT.LEFT : (e.getSource() == centerButton ? SWT.CENTER : SWT.RIGHT);
+					int style = e.getSource() == leftButton ? SWT.LEFT
+							: (e.getSource() == centerButton ? SWT.CENTER : SWT.RIGHT);
 					createColumn(tableViewer, style, labelProvider);
 				}
 			}
@@ -171,11 +174,11 @@ public class StyledCellLabelProviderTests {
 		centerButton.addSelectionListener(adapter);
 		rightButton.addSelectionListener(adapter);
 
-		TestContentProvider contentProvider= new TestContentProvider();
+		TestContentProvider contentProvider = new TestContentProvider();
 
 		tableViewer.setContentProvider(contentProvider);
 
-		stylingButton.addSelectionListener(new SelectionAdapter(){
+		stylingButton.addSelectionListener(new SelectionAdapter() {
 			@Override
 			public void widgetSelected(SelectionEvent e) {
 				labelProvider.setOwnerDrawEnabled(stylingButton.getSelection());
@@ -183,8 +186,7 @@ public class StyledCellLabelProviderTests {
 			}
 		});
 
-
-		GridData data= new GridData(GridData.FILL, GridData.FILL, true, true);
+		GridData data = new GridData(GridData.FILL, GridData.FILL, true, true);
 		tableViewer.getControl().setLayoutData(data);
 		tableViewer.setInput(new Object());
 
@@ -204,7 +206,8 @@ public class StyledCellLabelProviderTests {
 	int numOperations;
 	DecimalFormat decimalFormat = new DecimalFormat("##.#");
 
-	protected void setTimer(final Display display, boolean selection, final Runnable[] operation, final Label resultLabel) {
+	protected void setTimer(final Display display, boolean selection, final Runnable[] operation,
+			final Label resultLabel) {
 		timerOn = selection;
 		if (timerOn) {
 			startTime = System.currentTimeMillis();
@@ -223,7 +226,7 @@ public class StyledCellLabelProviderTests {
 					long elapsedTime = currentTime - startTime;
 					if (elapsedTime >= 1000) {
 						double timePerOperation = elapsedTime / 1000.0 / numOperations;
-						double operationsPerSecond = 1.0/timePerOperation;
+						double operationsPerSecond = 1.0 / timePerOperation;
 						resultLabel.setText("Operations per second: " + decimalFormat.format(operationsPerSecond));
 						numOperations = 0;
 						startTime = System.currentTimeMillis();
@@ -253,10 +256,10 @@ public class StyledCellLabelProviderTests {
 		private final Styler fItalicStylerViaFontStyle;
 
 		public ExampleLabelProvider(final Font boldFont) {
-			fBoldStyler= new Styler() {
+			fBoldStyler = new Styler() {
 				@Override
 				public void applyStyles(TextStyle textStyle) {
-					textStyle.font= boldFont;
+					textStyle.font = boldFont;
 				}
 			};
 			fItalicStylerViaFontStyle = new Styler() {
@@ -269,11 +272,9 @@ public class StyledCellLabelProviderTests {
 
 		@Override
 		public void update(ViewerCell cell) {
-			Object element= cell.getElement();
-
-			if (element instanceof File) {
-				File file= (File) element;
+			Object element = cell.getElement();
 
+			if (element instanceof File file) {
 				Styler style = null;
 				if (file.isDirectory()) {
 					if (useBold) {
@@ -282,7 +283,7 @@ public class StyledCellLabelProviderTests {
 				} else if (useItalicViaFontStyleAttribute) {
 					style = fItalicStylerViaFontStyle;
 				}
-				StyledString styledString= new StyledString(file.getName(), style);
+				StyledString styledString = new StyledString(file.getName(), style);
 				String decoration = MessageFormat.format(" ({0} bytes)", Long.valueOf(file.length())); //$NON-NLS-1$
 				styledString.append(decoration, StyledString.COUNTER_STYLER);
 
@@ -337,56 +338,32 @@ public class StyledCellLabelProviderTests {
 
 		@Override
 		public Object[] getElements(Object element) {
-			return new File[]{
-					new File("asdfkjghfasdkjasdfhjgasdfkjhg", 2348, false),
-					new File("sdafkuyasdfkljh", 2348, false),
-					new File("asdklufhalsdkhlkjhnklj hlh", 2348, true),
-					new File("asdfasdf asdf ", 2348, false),
-					new File("fds sdf", 2348, true),
-					new File(" sdafuh lsdfahj alsdfk hl", 2348, false),
-					new File("sdfahj sdfajk hsdfjkh", 2348, false),
+			return new File[] { new File("asdfkjghfasdkjasdfhjgasdfkjhg", 2348, false),
+					new File("sdafkuyasdfkljh", 2348, false), new File("asdklufhalsdkhlkjhnklj hlh", 2348, true),
+					new File("asdfasdf asdf ", 2348, false), new File("fds sdf", 2348, true),
+					new File(" sdafuh lsdfahj alsdfk hl", 2348, false), new File("sdfahj sdfajk hsdfjkh", 2348, false),
 					new File("sdafkja sdfjkh asdfkhj", 2348, false),
-					new File("sdfakj hasdfljkha sdfljkh sdfa", 348, true),
-					new File("hj ka g", 1334, true),
-					new File("asdfjk hsdfaljkh", 2348, false),
-					new File("asdh gasdflhg ", 3348, true),
-					new File("asd ghasdfkjg sdfkyug ", 4345, false),
-					new File("asdf hjasdflkjh sdfal", 5345, false),
-					new File("asdlfuh afsdhjg fdsalhj", 6648, false),
-					new File("uiy viuh vhj v", 7448, true),
-					new File("sdfauighsdvpyu ghasjkn", 8848, true),
-					new File("asduih cuia ;nac", 9548, false),
-					new File("chju kljhuuklh jk;", 348, false),
-					new File("cdailukhu l;hj .n", 448, false),
-					new File("auihy akl;h l;j", 2348, false),
-					new File("caiugh j l;kjlh jcd", 2328, true),
-					new File("auio;h jkh lhjl h ljjhbvj", 2348, true),
-					new File("ajklkja kj lkjh jklh ", 2248, false),
-					new File("asdfkjghfasdkjasdfhjgasdfkjhg", 2348, true),
-					new File("sdafkuyasdfkljh", 2348, false),
-					new File("asdklufhalsdkhlkjhnklj hlh", 2348, true),
-					new File("asdfasdf asdf ", 2348, false),
-					new File("fds sdf", 2348, true),
-					new File(" sdafuh lsdfahj alsdfk hl", 2348, true),
-					new File("sdfahj sdfajk hsdfjkh", 2348, false),
-					new File("sdafkja sdfjkh asdfkhj", 2348, true),
-					new File("sdfakj hasdfljkha sdfljkh sdfa", 348, true),
-					new File("hj ka g", 1334, false),
-					new File("asdfjk hsdfaljkh", 2348, false),
-					new File("asdh gasdflhg ", 3348, true),
-					new File("asd ghasdfkjg sdfkyug ", 4345, true),
-					new File("asdf hjasdflkjh sdfal", 5345, true),
-					new File("asdlfuh afsdhjg fdsalhj", 6648, false),
-					new File("uiy viuh vhj v", 7448, false),
-					new File("sdfauighsdvpyu ghasjkn", 8848, true),
-					new File("asduih cuia ;nac", 9548, false),
-					new File("chju kljhuuklh jk;", 348, true),
-					new File("cdailukhu l;hj .n", 448, true),
-					new File("auihy akl;h l;j", 2348, false),
-					new File("caiugh j l;kjlh jcd", 2328, true),
+					new File("sdfakj hasdfljkha sdfljkh sdfa", 348, true), new File("hj ka g", 1334, true),
+					new File("asdfjk hsdfaljkh", 2348, false), new File("asdh gasdflhg ", 3348, true),
+					new File("asd ghasdfkjg sdfkyug ", 4345, false), new File("asdf hjasdflkjh sdfal", 5345, false),
+					new File("asdlfuh afsdhjg fdsalhj", 6648, false), new File("uiy viuh vhj v", 7448, true),
+					new File("sdfauighsdvpyu ghasjkn", 8848, true), new File("asduih cuia ;nac", 9548, false),
+					new File("chju kljhuuklh jk;", 348, false), new File("cdailukhu l;hj .n", 448, false),
+					new File("auihy akl;h l;j", 2348, false), new File("caiugh j l;kjlh jcd", 2328, true),
+					new File("auio;h jkh lhjl h ljjhbvj", 2348, true), new File("ajklkja kj lkjh jklh ", 2248, false),
+					new File("asdfkjghfasdkjasdfhjgasdfkjhg", 2348, true), new File("sdafkuyasdfkljh", 2348, false),
+					new File("asdklufhalsdkhlkjhnklj hlh", 2348, true), new File("asdfasdf asdf ", 2348, false),
+					new File("fds sdf", 2348, true), new File(" sdafuh lsdfahj alsdfk hl", 2348, true),
+					new File("sdfahj sdfajk hsdfjkh", 2348, false), new File("sdafkja sdfjkh asdfkhj", 2348, true),
+					new File("sdfakj hasdfljkha sdfljkh sdfa", 348, true), new File("hj ka g", 1334, false),
+					new File("asdfjk hsdfaljkh", 2348, false), new File("asdh gasdflhg ", 3348, true),
+					new File("asd ghasdfkjg sdfkyug ", 4345, true), new File("asdf hjasdflkjh sdfal", 5345, true),
+					new File("asdlfuh afsdhjg fdsalhj", 6648, false), new File("uiy viuh vhj v", 7448, false),
+					new File("sdfauighsdvpyu ghasjkn", 8848, true), new File("asduih cuia ;nac", 9548, false),
+					new File("chju kljhuuklh jk;", 348, true), new File("cdailukhu l;hj .n", 448, true),
+					new File("auihy akl;h l;j", 2348, false), new File("caiugh j l;kjlh jcd", 2328, true),
 					new File("auio;h jkh lhjl h ljjhbvj", 2348, false),
-					new File("ajklkja kj lkjh jklh ", 2248, true),
-			};
+					new File("ajklkja kj lkjh jklh ", 2248, true), };
 		}
 
 		@Override
