@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright (c) 2018 SAP SE and others.
+* Copyright (c) 2018, 2021 SAP SE and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
@@ -315,10 +315,10 @@ public class UriSchemeHandlerPreferencePageTest {
 	private void assertScheme(TableItem tableItem, boolean checked, ISchemeInformation information) {
 		// check pojo
 		UiSchemeInformation uiInformation = (UiSchemeInformation) tableItem.getData();
-		assertEquals(checked, uiInformation.checked);
-		assertEquals(information.getName(), uiInformation.information.getName());
-		assertEquals(information.getDescription(), uiInformation.information.getDescription());
-		assertEquals(information.getHandlerInstanceLocation(), uiInformation.information.getHandlerInstanceLocation());
+		assertEquals(checked, uiInformation.isChecked());
+		assertEquals(information.getName(), uiInformation.getName());
+		assertEquals(information.getDescription(), uiInformation.getDescription());
+		assertEquals(information.getHandlerInstanceLocation(), uiInformation.getHandlerInstanceLocation());
 
 		// check UI
 		assertEquals(checked, tableItem.getChecked());
@@ -338,7 +338,7 @@ public class UriSchemeHandlerPreferencePageTest {
 	private void assertLoadingScheme(TableItem tableItem, ISchemeInformation information) {
 		// check pojo
 		UiSchemeInformation uiInformation = (UiSchemeInformation) tableItem.getData();
-		assertFalse(uiInformation.checked);
+		assertFalse(uiInformation.isChecked());
 		assertEquals(information.getName(), uiInformation.getName());
 		assertEquals(information.getDescription(), uiInformation.getDescription());
 		assertEquals(IDEWorkbenchMessages.UrlHandlerPreferencePage_LoadingText,
