@@ -21,6 +21,7 @@ import static org.junit.Assert.fail;
 
 import java.util.HashSet;
 import java.util.Set;
+import java.util.function.BooleanSupplier;
 
 import org.eclipse.core.resources.IProject;
 import org.eclipse.core.resources.IResource;
@@ -250,6 +251,25 @@ public class NavigatorTestBase {
 		DisplayHelper.sleep(50);
 	}
 
+	/**
+	 * Wait for up to 1 minute for a condition to be met.
+	 *
+	 * @param description A description of the condition (for debugging purposes).
+	 * @param condition   The condition to be met.
+	 */
+	protected void waitForCondition(String description, BooleanSupplier condition) {
+		for (int i = 1; i <= 1200; i++) {
+
+			if (condition.getAsBoolean()) {
+				System.out.println("The condition '" + description + "' was met in " + (i * 50) + " ms or less");
+				return;
+			}
+			DisplayHelper.sleep(50);
+		}
+
+		fail("The condition '" + description + "' was never met");
+	}
+
 	protected void showNavigator() {
 		try {
 			EditorTestHelper.showView(_navigatorInstanceId, true);
@@ -411,5 +431,27 @@ public class NavigatorTestBase {
 		}
 	}
 
+	/**
+	 * Wait up to 60 seconds for a test label provider to be initialized.
+	 *
+	 * @param tlp the label provider.
+	 */
+	protected void waitForInitialization(TestLabelProvider tlp) {
+
+		for (int i = 0; i < 1200; i++) {
+			TreeItem[] rootItems = _viewer.getTree().getItems();
+
+			if (tlp != null && rootItems[0].getBackground(0).equals(tlp.backgroundColor)) {
+				System.out.println("The label provider '" + tlp.getClass().getCanonicalName()
+						+ "' was initialized after "
+						+ (i * 50) + " ms");
+				return;
+			}
+
+			DisplayHelper.sleep(50);
+		}
+
+		fail("The label provider was not initialized.");
+	}
 
 }
