@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2003, 2015 IBM Corporation and others.
+ * Copyright (c) 2003, 2023 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -74,7 +74,7 @@ public class OpenTest extends NavigatorTestBase {
 
 		TreeItem[] items = _viewer.getTree().getItems();
 
-		assertTrue("There should be NO items.", items.length == 0); //$NON-NLS-1$
+		assertEquals("There should be NO items.", 0, items.length); //$NON-NLS-1$
 
 		_contentService.getActivationService().deactivateExtensions(new String[] {}, true);
 
