@@ -25,8 +25,11 @@ import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.swt.widgets.TreeItem;
 import org.eclipse.ui.tests.harness.util.DisplayHelper;
+import org.eclipse.ui.tests.harness.util.TestRunLogUtil;
 import org.eclipse.ui.tests.navigator.extension.TestPipelineProvider;
+import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TestWatcher;
 
 /**
  * @since 3.3
@@ -34,8 +37,10 @@ import org.junit.Test;
  */
 public class PipelineChainTest extends NavigatorTestBase {
 
-	private static final boolean SLEEP_LONG = false;
+	@Rule
+	public TestWatcher LOG_TESTRUN = TestRunLogUtil.LOG_TESTRUN;
 
+	private static final boolean SLEEP_LONG = false;
 
 	public PipelineChainTest() {
 		_navigatorInstanceId = TEST_VIEWER_PIPELINE;
@@ -52,8 +57,7 @@ public class PipelineChainTest extends NavigatorTestBase {
 				TEST_CONTENT_PIPELINE + ".F",
 				TEST_CONTENT_PIPELINE + ".G"
 		};
-		_contentService.bindExtensions(EXTENSIONS, false);
-		_contentService.getActivationService().activateExtensions(EXTENSIONS, true);
+		activateAndWait(EXTENSIONS);
 	}
 
 	private void _initContentWithLabel() {
@@ -68,8 +72,17 @@ public class PipelineChainTest extends NavigatorTestBase {
 				TEST_CONTENT_PIPELINE + ".G",
 				TEST_CONTENT_PIPELINE + ".label"
 		};
-		_contentService.bindExtensions(EXTENSIONS, false);
-		_contentService.getActivationService().activateExtensions(EXTENSIONS, true);
+		activateAndWait(EXTENSIONS);
+	}
+
+	private void activateAndWait(String[] extensionIds) {
+		_contentService.bindExtensions(extensionIds, false);
+		_contentService.getActivationService().activateExtensions(extensionIds, true);
+
+		for (String extensionId : extensionIds) {
+			waitForCondition("Wait for content pipelines",
+					() -> _contentService.getActivationService().isNavigatorExtensionActive(extensionId));
+		}
 	}
 
 	@Test
