@@ -14,11 +14,19 @@
 package org.eclipse.ui.tests.navigator.extension;
 
 import org.eclipse.jface.viewers.IToolTipProvider;
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.widgets.Display;
 
 /**
  * @since 3.3
  */
 public class TestLabelProviderTooltips extends TestLabelProvider implements IToolTipProvider {
+
+	@Override
+	protected void initSubclass() {
+		backgroundColor = Display.getCurrent().getSystemColor(SWT.COLOR_BLACK);
+		backgroundColorName = "Black";
+	}
 	@Override
 	public String getToolTipText(Object element) {
 		return "ToolTip " + getText(element);
