@@ -33,7 +33,6 @@ import org.eclipse.core.runtime.FileLocator;
 import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.NullProgressMonitor;
-import org.eclipse.core.runtime.Path;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.FrameworkUtil;
 
@@ -58,7 +57,7 @@ public class ProjectUnzipUtil {
 		} catch (IOException e) {
 			e.printStackTrace();
 		}
-		return new Path(url.getPath());
+		return IPath.fromOSString(url.getPath());
 	}
 
 	public boolean createProjects() {
@@ -145,7 +144,7 @@ public class ProjectUnzipUtil {
 	private void buildProjects() throws IOException, CoreException {
 		for (String projectName : projectNames) {
 			IWorkspace workspace = ResourcesPlugin.getWorkspace();
-			IPath projectPath = new Path("/" + projectName + "/" + META_PROJECT_NAME); //$NON-NLS-1$//$NON-NLS-2$
+			IPath projectPath = IPath.fromOSString("/" + projectName + "/" + META_PROJECT_NAME); //$NON-NLS-1$//$NON-NLS-2$
 			IPath path = rootLocation.append(projectPath);
 			IProject project = ResourcesPlugin.getWorkspace().getRoot().getProject(projectName);
 			IProjectDescription description = workspace.loadProjectDescription(path);
