@@ -32,8 +32,10 @@ public abstract class TestWidgetFactory {
 		}
 		return Geometry.getSize(parent.getClientArea());
 	}
-	public void init() throws CoreException, WorkbenchException {}
-	public void done() throws CoreException, WorkbenchException {}
+
+	public abstract void init() throws WorkbenchException;
+
+	public abstract void done();
 	public abstract String getName();
 	public abstract Composite getControl() throws CoreException, WorkbenchException;
 }
