@@ -14,17 +14,23 @@
 
 package org.eclipse.ui.tests.activities;
 
+import static org.junit.Assert.assertEquals;
+
 import java.util.Collections;
 
 import org.eclipse.jface.preference.IPreferenceStore;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.activities.IActivityManager;
 import org.eclipse.ui.internal.WorkbenchPlugin;
-import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
 /**
  * @since 3.1
  */
-public class ActivityPreferenceTest extends UITestCase {
+@RunWith(JUnit4.class)
+public class ActivityPreferenceTest {
 	/**
 	 * Preference prefix - must match the one specified in ActivityPreferenceHelper
 	 */
@@ -34,24 +40,19 @@ public class ActivityPreferenceTest extends UITestCase {
 	 */
 	private static String ID = "org.eclipse.ui.PT.A2"; //$NON-NLS-1$
 
-	/**
-	 * @param testName
-	 */
-	public ActivityPreferenceTest(String testName) {
-		super(testName);
-	}
-
 	/**
 	 * Tests whether activity preferences are persisted as soon as the activity set changes.
 	 */
+	@Test
 	public void testActivityPreference() {
-		IActivityManager manager = fWorkbench.getActivitySupport().getActivityManager();
+		IActivityManager manager = PlatformUI.getWorkbench().getActivitySupport().getActivityManager();
 
 		boolean initialState = manager.getEnabledActivityIds().contains(ID);
 		IPreferenceStore store = WorkbenchPlugin.getDefault().getPreferenceStore();
 		assertEquals(initialState, store.getBoolean(PREFIX + ID));
 
-		fWorkbench.getActivitySupport().setEnabledActivityIds(initialState ? Collections.EMPTY_SET : Collections.singleton(ID));
+		PlatformUI.getWorkbench().getActivitySupport()
+				.setEnabledActivityIds(initialState ? Collections.emptySet() : Collections.singleton(ID));
 		assertEquals(!initialState, store.getBoolean(PREFIX + ID));
 	}
 
