@@ -451,14 +451,16 @@ public class DynamicTest {
 
 		});
 
-		String ACTIVITY = "<plugin><extension point=\"org.eclipse.ui.activities\">"
-				+ "<category id=\"dynamic.category\" name=\"Dynamic Activity Category\"/>"
-				+ "<activity id=\"dynamic.activity\" name=\"Dynamic Activity\"/>"
-				+ "<activity id=\"dynamic.parent\" name=\"Dynamic Parent Activity\"/>"
-				+ "<activityRequirementBinding requiredActivityId = \"dynamic.parent\" activityId = \"dynamic.activity\" />"
-				+ "<categoryActivityBinding categoryId = \"dynamic.category\" activityId = \"dynamic.activity\" />"
-				+ "<activityPatternBinding activityId=\"dynamic.activity\"  pattern=\"dynamic.activity/.*\"/>"
-				+ "<defaultEnablement id=\"dynamic.activity\"/>" + "</extension></plugin>";
+		String ACTIVITY = """
+			<plugin><extension point="org.eclipse.ui.activities">\
+			<category id="dynamic.category" name="Dynamic Activity Category"/>\
+			<activity id="dynamic.activity" name="Dynamic Activity"/>\
+			<activity id="dynamic.parent" name="Dynamic Parent Activity"/>\
+			<activityRequirementBinding requiredActivityId = "dynamic.parent" activityId = "dynamic.activity" />\
+			<categoryActivityBinding categoryId = "dynamic.category" activityId = "dynamic.activity" />\
+			<activityPatternBinding activityId="dynamic.activity"  pattern="dynamic.activity/.*"/>\
+			<defaultEnablement id="dynamic.activity"/>\
+			</extension></plugin>""";
 		byte[] bytes = ACTIVITY.getBytes(StandardCharsets.UTF_8);
 		InputStream is = new ByteArrayInputStream(bytes);
 		IContributor contrib = ContributorFactoryOSGi.createContributor(TestPlugin.getDefault().getBundle());
