@@ -146,9 +146,10 @@ public class UIJobTest extends UITestCase {
 			Assert.assertTrue("We tried to sleep the UI thread, but it woke up too early. ",
 					finalTime - currentTime >= 200);
 
-			Assert.assertTrue("Background thread did not start, so there was no possibility "
-					+ "of testing whether its behavior was correct. This is not a test failure. "
-					+ "It means we were unable to run the test. ",
+			Assert.assertTrue("""
+				Background thread did not start, so there was no possibility\s\
+				of testing whether its behavior was correct. This is not a test failure.\s\
+				It means we were unable to run the test.\s""",
 					backgroundThreadStarted);
 
 			Assert.assertFalse("A UI job somehow ran to completion while the UI thread was blocked", uiJobFinished);
