@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.commands;
 
+import static org.junit.Assert.assertTrue;
+
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
@@ -21,33 +23,35 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
+import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.commands.ExecutionException;
 import org.eclipse.ui.commands.ICommand;
 import org.eclipse.ui.commands.IWorkbenchCommandSupport;
 import org.eclipse.ui.commands.NotHandledException;
 import org.eclipse.ui.internal.Workbench;
-import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.After;
+import org.junit.Test;
 
 /**
  * A test for whether the select all handler will send a selection event.
  *
  * @since 3.1
  */
-public final class Bug74982Test extends UITestCase {
+public final class Bug74982Test {
 
 	/**
 	 * Whether the selection event has been fired.
 	 */
 	private boolean selectionEventFired = false;
 
-	/**
-	 * Constructs a new instance of <code>Bug74982Test</code>.
-	 *
-	 * @param name
-	 *            The name of the test
-	 */
-	public Bug74982Test(final String name) {
-		super(name);
+	private Shell dialog;
+
+	@After
+	public void doTearDown() throws Exception {
+		if (dialog != null) {
+			dialog.dispose();
+		}
 	}
 
 	/**
@@ -63,11 +67,12 @@ public final class Bug74982Test extends UITestCase {
 	 *             <code>WorkbenchCommandSupport</code> class is broken in
 	 *             some way.
 	 */
+	@Test
 	public final void testSelectAllHandlerSendsSelectionEvent()
 			throws ExecutionException, NotHandledException {
 		// Create a dialog with a text widget.
-		final Shell dialog = new Shell(fWorkbench.getActiveWorkbenchWindow()
-				.getShell());
+		IWorkbench fWorkbench = PlatformUI.getWorkbench();
+		dialog = new Shell(fWorkbench.getActiveWorkbenchWindow().getShell());
 		dialog.setLayout(new GridLayout());
 		final Text text = new Text(dialog, SWT.SINGLE);
 		text.setText("Mooooooooooooooooooooooooooooo");
