@@ -18,6 +18,9 @@ import org.eclipse.ui.contexts.IContextManager;
 import org.eclipse.ui.contexts.IWorkbenchContextSupport;
 import org.eclipse.ui.contexts.NotDefinedException;
 import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
 
 /**
  * The test case for reading in elements from the extension point. This verifies
@@ -27,17 +30,15 @@ import org.eclipse.ui.tests.harness.util.UITestCase;
  *
  * @since 3.0
  */
+@RunWith(JUnit4.class)
 public class ExtensionTestCase extends UITestCase {
 
 	/**
 	 * Constructs a new instance of <code>ExtensionTestCase</code> with the
 	 * given name.
-	 *
-	 * @param testName
-	 *            The name of the test; may be <code>null</code>.
 	 */
-	public ExtensionTestCase(final String testName) {
-		super(testName);
+	public ExtensionTestCase() {
+		super(ExtensionTestCase.class.getSimpleName());
 	}
 
 	/**
@@ -48,6 +49,7 @@ public class ExtensionTestCase extends UITestCase {
 	 *             This shouldn't really be possible, as the test should fail
 	 *             gracefully before this could happen.
 	 */
+	@Test
 	public final void testAcceleratorScopes() throws NotDefinedException {
 		final IWorkbenchContextSupport contextSupport = fWorkbench
 				.getContextSupport();
@@ -86,6 +88,7 @@ public class ExtensionTestCase extends UITestCase {
 	 *             This shouldn't really be possible, as the test should fail
 	 *             gracefully before this could happen.
 	 */
+	@Test
 	public final void testCommandsScopes() throws NotDefinedException {
 		final IWorkbenchContextSupport contextSupport = fWorkbench
 				.getContextSupport();
@@ -123,6 +126,7 @@ public class ExtensionTestCase extends UITestCase {
 	 *             This shouldn't really be possible, as the test should fail
 	 *             gracefully before this could happen.
 	 */
+	@Test
 	public final void testContexts() throws NotDefinedException {
 		final IWorkbenchContextSupport contextSupport = fWorkbench
 				.getContextSupport();
