@@ -14,23 +14,27 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.decorators;
 
+import org.junit.Test;
+import org.junit.runner.RunWith;
+import org.junit.runners.JUnit4;
+
 /**
  * @version 1.0
  */
+@RunWith(JUnit4.class)
 public class LightweightDecoratorTestCase extends DecoratorEnablementTestCase {
 
 	/**
 	 * Constructor for DecoratorTestCase.
-	 *
-	 * @param testName
 	 */
-	public LightweightDecoratorTestCase(String testName) {
-		super(testName);
+	public LightweightDecoratorTestCase() {
+		super(LightweightDecoratorTestCase.class.getSimpleName());
 	}
 
 	/**
 	 * Refresh the test decorator.
 	 */
+	@Test
 	public void testRefreshContributor() {
 		updated = false;
 		getDecoratorManager().clearCaches();
