@@ -22,7 +22,7 @@ import java.io.IOException;
 import java.util.Properties;
 
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.Path;
+import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.PluginVersionIdentifier;
 import org.eclipse.core.runtime.Preferences;
@@ -79,7 +79,7 @@ public abstract class PreferenceMutator {
 		}
 
 		// Attempt to import the key binding.
-		Preferences.importPreferences(new Path(file.getAbsolutePath()));
+		Preferences.importPreferences(IPath.fromOSString(file.getAbsolutePath()));
 	}
 
 }
