@@ -34,7 +34,6 @@ import org.eclipse.core.runtime.IPath;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.NullProgressMonitor;
-import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.preference.PreferenceDialog;
 import org.eclipse.jface.preference.PreferencePage;
@@ -104,7 +103,7 @@ public class LargeFileLimitsPreferenceHandlerTest extends UITestCase {
 		testProject = workspaceRoot.getProject("SomeProject");
 		testProject.create(monitor);
 		testProject.open(monitor);
-		IPath path = new Path("/" + testProject.getName() + "/test_file" + "." + TXT_EXTENSION);
+		IPath path = IPath.fromOSString("/" + testProject.getName() + "/test_file" + "." + TXT_EXTENSION);
 		temporaryFile = workspaceRoot.getFile(path);
 		String content = String.join(System.lineSeparator(), "some line 1", "some line 2");
 		boolean force = true;
